# -*- coding: utf-8 -*-

#!/usr/bin/env python
#

import matplotlib
matplotlib.use('Template')
import matplotlib.pyplot as plt
import matplotlib.colors as clr
import matplotlib.font_manager as fm
import matplotlib.gridspec as grid
from matplotlib.patches import Rectangle
from matplotlib.collections import LineCollection
from matplotlib.patches import Polygon
from matplotlib.collections import PatchCollection
from matplotlib.patches import PathPatch
from matplotlib.colors import LightSource
import matplotlib as mpl
import pandas as pd
import numpy as np
import datetime as dt
import locale
import scipy as sp
from scipy import stats as st
import glob as gb
from netCDF4 import Dataset
from osgeo import gdal, osr
from osgeo.gdalconst import *                                       # shell utility module to work with os
import os, sys, time
from matplotlib.mlab import griddata
from mpl_toolkits.axes_grid1 import host_subplot
import mpl_toolkits.axisartist as AA
from mpl_toolkits.axes_grid1 import make_axes_locatable
from mpl_toolkits.basemap import Basemap, addcyclic, shiftgrid
from mpl_toolkits.mplot3d import axes3d
from matplotlib.offsetbox import OffsetImage, AnnotationBbox
from dateutil.relativedelta import relativedelta
import MySQLdb
import psycopg2
import pickle
from windrose import WindroseAxes
#Reportlab
from reportlab.lib import colors
from reportlab.lib.pagesizes import letter, landscape, inch
from reportlab.lib.enums import TA_JUSTIFY, TA_LEFT
from reportlab.platypus import Image, Paragraph, SimpleDocTemplate, Table, TableStyle
from reportlab.lib.styles import getSampleStyleSheet, ParagraphStyle
from reportlab.pdfgen import canvas
from reportlab.pdfbase import pdfmetrics
from reportlab.pdfbase.ttfonts import TTFont
from StringIO import StringIO
import scipy.ndimage
from reportlab.lib.enums import TA_JUSTIFY
from pyPdf import PdfFileWriter, PdfFileReader
from PDFImageSIATA import PdfImageSIATA
from pyPdf import PdfFileWriter, PdfFileReader

locale.setlocale(locale.LC_TIME, ('es_co','utf-8'))

reload (sys)
sys.setdefaultencoding('utf8')

prop = fm.FontProperties(fname='/home/calidadaire/ModuloAire/Tools/AvenirLTStd-Heavy.ttf',)
prop_1 = fm.FontProperties(fname='/home/calidadaire/ModuloAire/Tools/AvenirLTStd-Book.ttf',)
prop_2 = fm.FontProperties(fname='/home/calidadaire/ModuloAire/Tools/AvenirLTStd-Black.ttf',)


#  FUNCTION FOR OPEN PICKLE DATA
def open_pklfiles(path_pkldata):
    open_pkl = open(path_pkldata, 'rb')
    data = pickle.load(open_pkl)
    open_pkl.close()
    return data

# FUNCTION FOR MAKE AN PKL DATA
def make_pickle(path_out, name_pkl, df_pkl):
    output_file = open(path_out+name_pkl+'.pkl', 'wb')
    pickle.dump(df_pkl, output_file)
    output_file.close()

def reconoce_netcdf(nc_fid):
    nc_vars=[var for var in nc_fid.variables]
    nc_dims=[dim for dim in nc_fid.dimensions]
    nc_prop=nc_fid.ncattrs()
    return nc_vars,nc_dims,nc_prop

#####################################################################################
#-------------------------------Consultas-------------------------------------------#

class Air:
	EstR = pd.read_csv('/home/calidadaire/ModuloAire/Tools/EstacionesRuido.txt',index_col=0).sort_values(by='Latitud',ascending=False)

	def __init__(self,Variable=None,Estaciones=None,Fechai=None, Fechaf=None,Freq=5):
#	def __init__(self,Variable=None,Estaciones=None,Fechai='2017-11-01 01:00', Fechaf='2017-12-31 23:00',Freq=5):
		#os.system('mkdir Figuras')

		self.idx               = pd.IndexSlice
		self.freq = Freq
		self.Fechai      = (dt.datetime.now()-relativedelta(months=1)).strftime('%Y-%m-')+'01 00:00' if (Fechaf == None) else Fechai
		self.Fechaf      = (pd.to_datetime(self.Fechai)+ relativedelta(months=1)-dt.timedelta(hours=1)).strftime('%Y-%m-%d %H:%M') if (Fechaf == None) else Fechaf #
		self.AutomaticManual = (Fechaf == None)
		self.nombre_contaminantes = ['PM2.5', 'PM10', 'NO', 'NO2', 'NOx', 'Ozono', 'CO', 'SO2']
		self.nombre_meteorologicas = ['P_SSR','PLiquida_SSR','TAire10_SSR','RGlobal_SSR','HAire10_SSR','VViento_SSR','DViento_SSR']
		self.codigo_meteorologicas = [ 3,  6, 11, 12, 25, 28, 31, 37, 38, 40, 41, 44, 48]
		self.norma        = {'D':{'PM10':100,'PM2.5':50,'PM10M':100,'PM2.5M':50,'SO2':250,'NO2':150},
							'1h':{'CO':40000,'Ozono':120,'NO2':200},
							'3h':{'SO2':750},
							'8h':{'CO':10000,'Ozono':80},
							'Y':{'PM10':50,'PM2.5':25,'PM10M':50,'PM2.5M':25,'SO2':80,'NO2':100}}
		self.limC         = {'Y':{'PM10':(35,75),'PM2.5':(10,60),'SO2':(10,85),'NO2':(10,110)},
							'D':{'PM10':(0,161),'PM2.5':(0,84),'SO2':(0,281),'NO2':(0,203),'Ozono':(0,161),'NO':(0,203),'NOx':(0,281),'CO':(0,56000)},
							'1h':{'PM10M':(0,140),'PM2.5M':(10,70),'PM10':(0,140),'PM2.5':(10,70),'SO2':(0,84),'NO2':(0,119),'Ozono':(0,161),'NO':(0,161),'NOx':(0,315),'CO':(200,8000),'TAire10_SSR':(10,35),'RGlobal_SSR':(0,900),'HAire10_SSR':(0,100), 'P_SSR':(800,900),'PLiquida_SSR':(0,10),'VViento_SSR':(0,10),'DViento_SSR':(0,360),'U':(-5,5),'V':(-5,5),'D':(0,360),'S':(0,8),'dm':(0,360),'sm':(0,8)},
							'3h':{'SO2':(0,800)},
							'8h':{'CO':(0,11200),'Ozono':(0,112)},
							'm':{'PM10M':(0,140),'PM2.5M':(0,91),'PM10':(0,140),'PM2.5':(0,91),'SO2':(0,112),'NO2':(0,119),'Ozono':(0,100),'NO':(0,100),'NOx':(0,200),'CO':(200,4000),'TAire10_SSR':(10,35),'RGlobal_SSR':(0,600),'HAire10_SSR':(0,100), 'P_SSR':(800,900),'PLiquida_SSR':(0,700),'VViento_SSR':(0,4),'DViento_SSR':(0,360), 'U':(-5,5),'V':(-5,5),'D':(0,360),'S':(0,8),'dm':(0,360),'sm':(0,8)},
							'w':{'PM2.5M':(0,35),'PM10M':(10,60),'PM2.5':(15,55),'PM10':(25,75),'SO2':(0,20),'NO2':(10,65),'Ozono':(5,35),'NO':(0,45),'NOx':(15,140),'CO':(450,2200),'TAire10_SSR':(10,35),
								'RGlobal_SSR':(0,900),'HAire10_SSR':(0,100), 'P_SSR':(800,900),'PLiquida_SSR':(0,15),'VViento_SSR':(0,10),'DViento_SSR':(0,360),
								'U':(-5,5),'V':(-5,5),'D':(0,360),'S':(0,8),'dm':(0,360),'sm':(0,8)}}

		self.norma_ruido = {'CEN-TRAF': ['C', 70, 55],'GIR-BOTJ': ['C', 70, 55], 'GIR-SOSN': ['B', 65, 50], 'BEL-ALCA': ['C', 70, 55], 'MED-PLMA': ['C', 80, 70], 'MED-ITMR': ['C', 80, 70], 'MED-PJIR': ['B', 65, 50], 'ITA-CODI': ['C', 70, 55], 'SAB-SEMS': ['C', 70, 55], 'MED-ITMR': ['C', 80, 70], 'MED-SIAT': ['C', 70, 55],}

		self.label       = {'PM10M':ur'Concentración PM10 $[\mu g /m^{3}]$', 'PM2.5M':ur'Concentración PM2.5 $[\mu g /m^{3}]$',
			'PM10':ur'Concentración PM10 $[\mu g /m^{3}]$', 'PM2.5':ur'Concentración PM2.5 $[\mu g /m^{3}]$',
			'Ozono':ur'Concentración Ozono $[\mu g /m^{3}]$', 'NO':ur'Concentración NO $[\mu g /m^{3}]$',
			'NO2':ur'Concentración NO2 $[\mu g /m^{3}]$','NOx':ur'Concentración NOx $[ppb]$',
			'SO2':ur'Concentración SO2 $[\mu g /m^{3}]$', 'CO':ur'Concentración CO $[\mu g /m^{3}]$',
			'P_SSR':ur'Presión $[hPa]$', 'PLiquida_SSR':ur'PPT$[mm]$', 
			'TAire10_SSR':ur'Temp.$[C^{\circ}]$', 'RGlobal_SSR':ur'Radiación Solar Global $[W/m^{2}]$',
			'HAire10_SSR':ur'Hum. Rel. $[\%]$', 	'VViento_SSR':ur'Velocidad del Viento $[m/s]$',
			'DViento_SSR':ur'Dirección del Viento $[Deg]$','U':ur'U $[m/s]$','V':ur'V $[m/s]$',
			'S':ur'Velocidad del Viento $[m/s]$','D':'Dirección del Viento $[Deg]$',
			'sm':ur'Velocidad del Viento $[m/s]$','dm':'Dirección del Viento $[Deg]$','Ruido':ur'Nivel de Presión Sonora $dB(A)$'} #$[\frac{\mu g} {m^{3}}]$

		self.labelx       = {'PM10M':ur'Concentración Promedio %s PM10 $[\mu g /m^{3}]$', 'PM2.5M':ur'Concentración Promedio %s PM2.5 $[\mu g /m^{3}]$' ,
			'PM10':ur'Concentración Promedio %s PM10 $[\mu g /m^{3}]$', 'PM2.5':ur'Concentración Promedio %s PM2.5 $[\mu g /m^{3}]$' ,
			'Ozono':ur'Concentración Promedio %s Ozono $[\mu g /m^{3}]$', 'NO':ur'Concentración Promedio %s NO $[\mu g /m^{3}]$',
			'NO2':ur'Concentración Promedio %s NO2 $[\mu g /m^{3}]$','NOx':ur'Concentración Promedio %s NOx $[ppb]$',
			'SO2':ur'Concentración Promedio %s SO2 $[\mu g /m^{3}]$', 'CO':ur'Concentración Promedio %s CO $[\mu g /m^{3}]$',
			'P_SSR':ur'Presión Atmosférica Promedio %s $[hPa]$', 'PLiquida_SSR':ur'Precipitación Acumulada %s $[mm]$' ,
			'TAire10_SSR':ur'Temperatura del Aire a 10m Promedio %s $[C^{\circ}]$' , 'RGlobal_SSR':ur'Radiación Solar Global Promedio %s $[\frac {W}{m^{2}}]$',
			'HAire10_SSR':ur'Humedad Relativa a 10m Promedio %s $[\%%]$' , 'VViento_SSR':ur'Velocidad del Viento Promedio %s $[\frac {m}{s}]$' ,
			'DViento_SSR':ur'Dirección del Viento %s $[^{\circ}]$','Ruido':ur'Nivel de Presión Sonora $dB(A)$'}

		"""
		self.RangosICA  = {"CO-8h":    {"Ilo":[0.0,  50.0,  101.0, 150.0, 201.0, 301.0, 401.0], "Ihi":[50.0,  101.0, 150.0, 201.0, 301.0, 401.0, 501.0], "Bplo":[0.0,  4.5, 9.5, 12.5, 15.5, 30.5, 40.5 ], "Bphi":[4.5, 9.5, 12.5, 15.5, 30.5, 40.5, 50.5 ], "color":[(0,0.605,0),  "yellow", "orange",   "red", "purple", "brown", "brown"]},
			"NO2-1h":   {"Ilo":[0.0,  51.0,  101.0, 151.0, 201.0, 301.0, 401.0], "Ihi":[51.0,  101.0, 151.0, 201.0, 301.0, 401.0, 501.0], "Bplo":[0.0,  0.054,  0.101,   0.361,  0.65,  1.25,  1.65 ], "Bphi":[0.054,  0.101,   0.361,  0.65, 1.25, 1.65, 2.05 ], "color":[(0,0.605,0),   "yellow",  "orange", "red", "purple", "brown", "brown"]},
			"Ozono-1h":  {"Ilo":[0.0,  51.0,  101.0, 151.0, 201.0, 301.0, 401.0], "Ihi":[51.0,  101.0, 151.0, 201.0, 301.0, 401.0, 501.0], "Bplo":[0.0,  0.0, 0.125, 0.165, 0.205, 0.405, 0.505 ], "Bphi":[0.125, 0.125, 0.165, 0.205, 0.405,        0.505,        0.605 ], "color":["w",   "w", "orange",   "red", "purple", "brown", "brown"]},
			"Ozono-8h":  {"Ilo":[0.0,  51.0,  101.0, 151.0, 201.0, 301.0, 401.0], "Ihi":[51.0,  101.0, 151.0, 201.0, 301.0, 401.0, 501.0], "Bplo":[0.0, 0.06, 0.076, 0.096, 0.116, 0.375, 0.375 ], "Bphi":[0.06, 0.076, 0.096, 0.116, 0.375, float("inf"), float("inf") ], "color":[(0,0.605,0),  "yellow", "orange",   "red", "purple",  "w",  "w"]},
			"PM10-D":  {"Ilo":[0.0,  51.0,  101.0, 151.0, 201.0, 301.0, 401.0], "Ihi":[51.0,  101.0, 151.0, 201.0, 301.0, 401.0, 501.0], "Bplo":[0.0, 55.0, 155.0, 255.0, 355.0, 425.0, 505.0 ], "Bphi":[55.0,  155.0, 255.0, 355.0, 425.0, 505.0, 605.0 ], "color":[(0,0.605,0),  "yellow", "orange",   "red", "purple", "brown", "brown"]},
			"PM10M-D":  {"Ilo":[0.0,  51.0,  101.0, 151.0, 201.0, 301.0, 401.0], "Ihi":[51.0,  101.0, 151.0, 201.0, 301.0, 401.0, 501.0], "Bplo":[0.0, 55.0, 155.0, 255.0, 355.0, 425.0, 505.0 ], "Bphi":[55.0,  155.0, 255.0, 355.0, 425.0, 505.0, 605.0 ], "color":[(0,0.605,0),  "yellow", "orange",   "red", "purple", "brown", "brown"]},
			"PM2.5-D": {"Ilo":[0.0,  51.0,  101.0, 151.0, 201.0, 301.0, 401.0], "Ihi":[51.0,  101.0, 151.0, 201.0, 301.0, 401.0, 501.0], "Bplo":[0.0, 12.0,  35.5,  55.5, 150.5, 250.5, 350.5 ], "Bphi":[12.0,   35.5,  55.5, 150.5, 250.5,350.5,500.5 ], "color":[(0,0.605,0),  "yellow", "orange",   "red", "purple", "brown", "brown"]},
			"PM2.5M-D": {"Ilo":[0.0,  51.0,  101.0, 151.0, 201.0, 301.0, 401.0], "Ihi":[51.0,  101.0, 151.0, 201.0, 301.0, 401.0, 501.0], "Bplo":[0.0, 12.0,  35.5,  55.5, 150.5, 250.5, 350.5 ], "Bphi":[12.0,   35.5,  55.5, 150.5, 250.5,        350.5,        500.5 ], "color":[(0,0.605,0),  "yellow", "orange",   "red", "purple", "brown", "brown"]},
			'SO2-D':   {"Ilo":[0.0,  51.0,  101.0, 151.0, 201.0, 301.0, 401.0], "Ihi":[51.0,  101.0, 151.0, 201.0, 301.0, 401.0, 501.0], "Bplo":[0.0, 0.035, 0.145, 0.225, 0.305, 0.605,  0.805, ],         "Bphi":[0.035,   0.145, 0.225, 0.305, 0.605, 0.805,  1.005 ], "color":[(0,0.605,0),  "yellow", "orange",   "red", "purple", "brown", "brown"]}}
		"""

                self.RangosICA  = {"CO-8h":    {"Ilo":[0.0,  50.0,  101.0, 150.0, 201.0, 301.0], "Ihi":[50.0,  101.0, 150.0, 201.0, 301.0, 501.0], "Bplo":[0.0,   4.450265697595929,   9.4508095874363,  12.451135921340525,  15.45058879779674,  30.45134700986985], "Bphi": [4.450178351851128, 9.4507222416915, 12.451048575595722,15.45050145205194,  30.45125966412505, 50.40111512235091], "color":[(0,0.605,0),  "yellow", "orange",   "red", "purple", "brown"]},
                        "NO2-1h":   {"Ilo":[0.0,  51.0,  101.0, 151.0, 201.0, 301.0], "Ihi":[51.0,  101.0, 151.0, 201.0, 301.0, 501.0], "Bplo":[0.0, 0.053711354219218584, 0.1010411614024904, 0.3605574075309921, 0.649854206493912, 1.2497196278729077], "Bphi":[0.05365817466058569, 0.10098798184385752, 0.36050422797235915, 0.6498010269352791, 1.2496664483142748, 2.0490083941252397], "color":[(0,0.605,0),   "yellow",  "orange", "red", "purple", "brown"]},
                        "Ozono-1h":  {"Ilo":[0.0,  51.0,  101.0, 151.0, 201.0, 301.0], "Ihi":[51.0,  101.0, 151.0, 201.0, 301.0, 501.0], "Bplo":[0.0,  0.0,  0.12487620966824983, 0.16514241605107324, 0.20489892361892423, 0.4051595880215991], "Bphi":[0.12487620966824983, 0.12487620966824983, 0.165091446169576, 0.20484795373742695, 0.4051595880215991, 0.6039930957423513 ], "color":["w",   "w", "orange",   "red", "purple", "brown"]},
                        "Ozono-8h":  {"Ilo":[0.0,  51.0,  101.0, 151.0, 201.0, 301.0], "Ihi":[51.0,  101.0, 151.0, 201.0, 301.0, 501.0], "Bplo":[0.0, 0.05453777320205197,  0.07084813528117032, 0.08562940091537131, 0.10601735351426925, 0.20082133309914463 ], "Bphi":[0.05448680332055473, 0.07079716539967307, 0.08557843103387408, 0.10596638363277201, 0.20077036321764738, float("inf")], "color":[(0,0.605,0),  "yellow", "orange",   "red", "purple",  "w"]},
                        "PM10-D":  {"Ilo":[0.0,  51.0,  101.0, 151.0, 201.0, 301.0], "Ihi":[51.0,  101.0, 151.0, 201.0, 301.0, 501.0], "Bplo":[0.0, 55.0,  155.0, 255.0, 355.0, 425.0], "Bphi":[54.9999999,  154.9999999, 254.9999999, 354.9999999, 424.9999999, 604.0], "color":[(0,0.605,0),  "yellow", "orange",   "red", "purple",  "brown"]},
                        "PM10M-D":  {"Ilo":[0.0,  51.0,  101.0, 151.0, 201.0, 301.0], "Ihi":[51.0,  101.0, 151.0, 201.0, 301.0, 501.0], "Bplo":[0.0, 55.0,  155.0, 255.0, 355.0, 425.0], "Bphi":[54.9999999,  154.9999999, 254.9999999, 354.9999999, 424.9999999, 604.0], "color":[(0,0.605,0),  "yellow", "orange",   "red", "purple", "brown"]},
                        "PM2.5-D": {"Ilo":[0.0,  51.0,  101.0, 151.0, 201.0, 301.0], "Ihi":[51.0,  101.0, 151.0, 201.0, 301.0, 501.0], "Bplo":[0.0, 13.0, 38.0, 56.0, 151.0, 251.0], "Bphi":[12.9999999, 37.9999999, 55.9999999, 149.9999999, 250.9999999, 500.0], "color":[(0,0.605,0),  "yellow", "orange",   "red", "purple", "brown"]},
                        "PM2.5M-D": {"Ilo":[0.0,  51.0,  101.0, 151.0, 201.0, 301.0], "Ihi":[51.0,  101.0, 151.0, 201.0, 301.0, 501.0], "Bplo":[0.0, 13.0, 38.0, 56.0, 151.0, 251.0], "Bphi":[12.9999999, 37.9999999, 55.9999999, 149.9999999, 250.9999999, 500.0], "color":[(0,0.605,0),  "yellow", "orange",   "red", "purple", "brown"]},
                        'SO2-D':   {"Ilo":[0.0,  51.0,  101.0, 151.0, 201.0, 301.0], "Ihi":[51.0,  101.0, 151.0, 201.0, 301.0, 501.0], "Bplo":[0.000, 0.03589674793425041,  0.07561229884022959, 0.18597570472319097, 0.30474047714395563, 0.6048983907218367 ], "Bphi":[0.03585855990453313,  0.07557411081051231, 0.18593751669347366, 0.30470228911423836, 0.6048602026921195, 1.003963301267493], "color":[(0,0.605,0),  "yellow", "orange",   "red", "purple", "brown"]}}

		self.dias_es 		= {'1':'L','2':'M','3':'Mi','4':'J','5':'V','6':'S','0':'D','7':'D'}
		self.mes_es 		= {1:'Enero',2:'Febrero',3:'Marzo',4:'Abril',5:'Mayo',6:'Junio',7:'Julio',8:'Agosto',9:'Septiembre',10:'Octubre',11:'Noviembre',12:'Diciembre'}
		self.unidadesC		= {'PM10':'ug/m3', 'PM2.5':'ug/m3','NO':'ug/m3', 'NO2':'ug/m3', 'NOx':'ug/m3', 'Ozono':'ug/m3', 'CO':'ug/m3', 'SO2':'ug/m3'}
		self.unidadesC2		= {'PM10':'ug/m3', 'PM2.5':'ug/m3','NO':'ppb', 'NO2':'ppb', 'NOx':'ppb', 'Ozono':'ppb', 'CO':'ppm', 'SO2':'ppb'}
		self.unidadesMeteo	= {'P_SSR':'hPa','PLiquida_SSR':'mm','TAire10_SSR':'C','RGlobal_SSR':'W/m2','HAire10_SSR':'%','VViento_SSR':'m/s','DViento_SSR':'Deg'}
#		self.EstR = pd.read_csv('/home/calidadaire/ModuloAire/Tools/EstacionesRuido.txt',index_col=0).sort_values(by='Latitud',ascending=False)

		self.Est			= pd.read_csv('/home/calidadaire/ModuloAire/Tools/Estaciones.txt',index_col=0).sort_values(by='Latitud',ascending=False)
		#self.Est.loc[self.Est[self.Est['Vaisala']==1].index,'Nombre']=self.Est[self.Est['Vaisala']==1]['Nombre'].astype(int)

		self.EstV			= pd.read_csv('/home/calidadaire/ModuloAire/Tools/Estaciones_Vaisala.txt',index_col=0).sort_values(by='Latitud',ascending=False)
		self.EstV.loc[self.EstV[self.EstV['Vaisala']==1].index,'Nombre']=self.EstV[self.EstV['Vaisala']==1]['Nombre'].astype(int)

		self.var			= Variable
		self.Contaminante	= None
		self.resol 			= 'D'
		self.run			= False
		self.path			= os.getcwd()

		self.labelica = ['Buena','Moderada','Dañina a grupos sensibles','Dañina a la salud']
		self.frec_ruido = {'20 Hz':'dato_20', '25 Hz':'dato_25', '32 Hz':'dato_32', '40 Hz':'dato_40', '50 Hz':'dato_50', '63 Hz':'dato_63', '80 Hz':'dato_80', '100 Hz':'dato_100', '125 Hz':'dato_125', '160 Hz':'dato_160', '200 Hz':'dato_200', '250 Hz':'dato_250', '315 Hz':'dato_315', '400 Hz':'dato_400','500 Hz':'dato_500', '630 Hz':'dato_630', '800 Hz':'dato_800', '1k Hz':'dato_1000', '1k25 Hz':'dato_1025', '1k6 Hz':'dato_1600', '2k Hz':'dato_2000', '2k5 Hz':'dato_2500', '3k15 Hz':'dato_3150', '4k Hz':'dato_4000', '5k Hz':'dato_5000', '6k3 Hz':'dato_6300', '8k Hz':'dato_8000', '10k Hz':'dato_10000', '12k5 Hz':'dato_12500', '16k Hz':'dato_16000', '20k Hz':'dato_20000' }

		self.frecuencias = ['20 Hz', '25 Hz', '32 Hz', '40 Hz', '50 Hz', '63 Hz', '80 Hz', '100 Hz', '125 Hz', '160 Hz', '200 Hz', '250 Hz', '315 Hz', '400 Hz','500 Hz', '630 Hz', '800 Hz', '1k Hz', '1k25 Hz', '1k6 Hz', '2k Hz', '2k5 Hz', '3k15 Hz', '4k Hz', '5k Hz', '6k3 Hz', '8k Hz', '10k Hz', '12k5 Hz', '16k Hz', '20k Hz']

		self.AjusteZ = {'20 Hz':50.5, '25 Hz':44.7, '31,5 Hz':39.4, '40 Hz':34.6, '50 Hz':30.2, '63 Hz':26.2, '80 Hz':22.5, '100 Hz':19.1, '125 Hz':16.1, '160 Hz':13.4, '200 Hz':10.9, '250 Hz':8.6, '315 Hz':6.6, '400 Hz':4.8, '500 Hz':3.2, '630 Hz':1.9, '800 Hz':0.8, '1k Hz':0.0, '1,25k Hz':-0.6, '1,6k Hz':-1.0, '2k Hz':-1.2, '2,5k Hz':-1.3, '3,15k Hz':-1.2, '4k Hz':-1.0, '5k Hz':-0.5, '6,3k Hz':0.1, '8k Hz':1.1, '10k Hz':2.5}

		self.colors = {'PLiquida_SSR':((0.421,0.566,0.664),(0.359,0.515,0.625),(0.1757,0.375,0.507),(0.109,0.293,0.445),(0.45, 0.45, 0.45)),'P_SSR':((0.417,0.7617,0.769),(0.339,0.675,0.6875),(0.17,0.5,0.51),(0.105,0.433,0.449),(0.45, 0.45, 0.45)),'TAire10_SSR':((0.7539,0.5625,0.433),(0.7539,0.5117,0.335),(0.324,0.4375,0.203),(0.707,0.39,0.085),(0.45, 0.45, 0.45)),'RGlobal_SSR':((0.765,0.422,0.422),(0.687,0.34,0.34),(0.51,0.17,0.17),(0.445,0.109,0.109),(0.45, 0.45, 0.45)),'HAire10_SSR':((0.6757,0.429, 0.6679),( 0.6367,0.359,0.6289),(0.492,0.171,0.512),(0.44,0.136,0.445),(0.45, 0.45, 0.45)),'PM2.5M':((0.6757,0.429, 0.6679),( 0.6367,0.359,0.6289),(0.492,0.171,0.512),(0.44,0.136,0.445),(0.45, 0.45, 0.45)),'PM2.5':((0.6757,0.429, 0.6679),( 0.6367,0.359,0.6289),(0.492,0.171,0.512),(0.44,0.136,0.445),(0.45, 0.45, 0.45)), 'Ozono':((0.765,0.422,0.422),(0.687,0.34,0.34),(0.51,0.17,0.17),(0.445,0.109,0.109),(0.45, 0.45, 0.45)),'PM10M':((0.429,0.667,0.4375),(0.355,0.625,0.367),(0.17,0.51,0.207),(0.1679,0.449,0.191),(0.45, 0.45, 0.45)),'PM10':((0.429,0.667,0.4375),(0.355,0.625,0.367),(0.17,0.51,0.207),(0.1679,0.449,0.191),(0.45, 0.45, 0.45)),'NOx':((0.417,0.7617,0.769),(0.339,0.675,0.6875),(0.17,0.5,0.51),(0.105,0.433,0.449),(0.45, 0.45, 0.45)),'NO2':((0.417,0.7617,0.769),(0.339,0.675,0.6875),(0.17,0.5,0.51),(0.105,0.433,0.449),(0.45, 0.45, 0.45)),'NO':((0.417,0.7617,0.769),(0.339,0.675,0.6875),(0.17,0.5,0.51),(0.105,0.433,0.449),(0.45, 0.45, 0.45)),'CO':((0.421,0.566,0.664),(0.359,0.515,0.625),(0.1757,0.375,0.507),(0.109,0.293,0.445),(0.45, 0.45, 0.45)),'SO2':((0.7539,0.5625,0.433),(0.7539,0.5117,0.335),(0.324,0.4375,0.203),(0.707,0.39,0.085),(0.45, 0.45, 0.45))}

	def Aire_db(self,*args,**kwargs):
		""" Consulta los datos de siataRedAire en diferentes estaciones
		de una variable meteorológica, los contaminantes se devuelven en
		ug/m3"""

		print '-------------------------------------------'
		print 'Lectura Datos Estaciones '
		print '-------------------------------------------'
		print '\n'
		self.Variable		= kwargs.get('Variable',None)
		self.Estaciones		= kwargs.get('Estaciones',None)
		self.Flags			= kwargs.get('Flags',False)
		self.Crudos			= kwargs.get('Crudos',False)
		self.Validado		= kwargs.get('Validado',False)
		self.ValidadoSiata	= kwargs.get('ValidadoSiata',False)
		self.Meteorologicas	= kwargs.get('Meteorologicas',False)
		self.Manual			= kwargs.get('Manual',False)
		self.Ruido			= kwargs.get('Ruido',False)
		self.query			= kwargs.get('query',None)
		self.filtro			= kwargs.get('filtro',False)
		self.Vaisala		= kwargs.get('Vaisala',False)
		self.Pluviometro	= kwargs.get('Pluviometro',False)
		self.PluviometroJAL	= kwargs.get('PluviometroJAL',False)
		self.varvaisala		= kwargs.get('varvaisala',['sm','dm'])
		self.varpluvio		= kwargs.get('varpluvio',['p1','p2'])
		self.thiess            = kwargs.get('thiess',False)
   		self.varthiess		= kwargs.get('varthiess',['vv','dv','p'])
		self.LRAdiario		= kwargs.get('LRAdiario',False)
		self.LRAhorario		= kwargs.get('LRAhorario',False)
		self.MeteoRuido		= kwargs.get('MeteoRuido',False)

		if (type(self.var) ==type(None)) & (type(self.Variable)==type(None)):
			print 'Definir Variable: self.var="X"'
		#	self.var=='Ruido'
		elif self.Variable!=None:
			self.var= self.Variable
		else:
			pass

		print self.var
		print '\n'

		self.host   = kwargs.get('host',"192.168.1.74")
		self.user   = kwargs.get('user',"siataRedAire_C")
		self.passwd = kwargs.get('passwd',"CalidadA1r3_C0nsult4")
		self.dbname = kwargs.get('dbname',"siataRedAire" )
		
		if self.Vaisala or self.thiess:
			calidad_siata={'TAire10_SSR':[153,1513,1534,1535,1536,15134,15135,15136,15345,15346,15356,151,253,2513,2534,2535,2536,25134,25135,25136,25345,25346,25356,251],
			        'PLiquida_SSR':[1511,1513,1514,1515,1516,15134,15135,15136,15145,15146,15156,151,2511,2513,2514,2515,2516,25134,25135,25136,25145,25146,25156,251],
			        'P_SSR':[155,1515,1535,1545,1556,15135,15145,15156,15345,15356,15456,151,255,2515,2535,2545,2556,25135,25145,25156,25345,25356,25456,251],
			        'HAire10_SSR':[154,1514,1534,1545,1546,15134,15145,15146,15345,15346,15356,151,254,2514,2534,2545,2546,25134,25145,25146,25345,25346,25356,251],
			        'VViento_SSR':[156,1516,1536,1546,1556,15136,15146,15156,15346,15456,15356,151,256,2516,2536,2546,2556,25136,25146,25156,25346,25456,25356,251],
			        'DViento_SSR':[156,1516,1536,1546,1556,15136,15146,15156,15346,15456,15356,151,256,2516,2536,2546,2556,25136,25146,25156,25346,25456,25356,251]}
			
		if self.Estaciones==None:
			if self.LRAdiario or self.LRAhorario or self.Ruido:
				self.Estaciones=self.EstR['Ruido'][self.EstR['Ruido']==1].index.values
				self.Estacion = str(list(self.Estaciones)).strip('[]')
			else:
				try:
					self.Estaciones   = self.Est[self.var][self.Est[self.var]==1].index.values if ((self.Estaciones == None) & (self.var != None)) else self.Estaciones
					self.Estacion = str(list(self.Estaciones)).strip('[]')
				except:pass
		try:
			self.Estacion = str(list(self.Estaciones)).strip('[]')
		except:pass
		if self.query != None:
			self.query_1= self.query

		elif self.Vaisala:
			self.user 		= 'siata_Consulta'
			self.passwd 	= 'si@t@64512_C0nsult4'
			self.dbname		= 'siata'
			Analoga={'pa':'P_SSR','rc':'PLiquida_SSR','ta':'TAire10_SSR','ua':'HAire10_SSR','sm':'VViento_SSR','dm':'DViento_SSR'}
			#self.Estacion 	= self.EstV[self.EstV['Vaisala']==1].index.values
			self.Estacion 	= str(self.Estaciones).strip("[]").replace("'","")
			varcalidad= Analoga[self.varvaisala[0]] if self.varvaisala not in ['dm','sm'] else 'VViento_SSR'
			#self.query_1	=  "SELECT fecha_hora,concat(fecha,' ',hora),cliente,%s FROM vaisala WHERE cliente in (%s) AND calidad not in (%s) AND fecha_hora BETWEEN '%s' AND '%s' order by fecha_hora" %(str(list(self.varvaisala)).strip("[]").replace("'",""),self.Estacion,str(calidad_siata[varcalidad]).strip("[]"),self.Fechai,self.Fechaf)
			self.query_1	=  "SELECT fecha_hora,concat(fecha,' ',hora),cliente,%s FROM vaisala WHERE cliente in (%s) AND calidad not in (%s) AND fecha BETWEEN '%s' AND '%s' AND hora BETWEEN '00:00:00' AND '23:59:00' order by concat(fecha,' ',hora)" %(str(list(self.varvaisala)).strip("[]").replace("'",""),self.Estacion,str(calidad_siata[varcalidad]).strip("[]"),self.Fechai[:11],self.Fechaf[:11])
			print self.query_1
		elif self.Pluviometro:
			print 'Datos Pluviometros'
			self.user 	= 'siata_Consulta'
			self.passwd 	= 'si@t@64512_C0nsult4'
			self.dbname	= 'siata'
			self.query_1=  "SELECT concat(fecha,' ',hora),cliente,%s FROM datos WHERE cliente in (%s) AND calidad = 1 AND fecha BETWEEN '%s' AND '%s' AND SUBSTR(fecha, 6, 2) BETWEEN '01' AND '12' AND SUBSTR(fecha,9,2) BETWEEN '01' AND '31' AND SUBSTR(hora, 1, locate(':',hora)-1) BETWEEN 00 AND 24 order by fecha, hora" %(str(list(self.varpluvio)).strip("[]").replace("'",""),self.Estacion.strip("[]"),self.Fechai,self.Fechaf)

                elif self.PluviometroJAL:
                        print 'Datos Pluviometros'
			self.host	= "192.168.1.100"
                        self.user       = 'siata_Consulta'
                        self.passwd     = 'si@t@64512_C0nsult4'
                        self.dbname     = 'siata'
                        self.query_1=  "SELECT concat(fecha,' ',hora),cliente,%s FROM datos WHERE cliente in (%s) AND calidad = 1 AND fecha BETWEEN '%s' AND '%s' AND SUBSTR(fecha, 6, 2) BETWEEN '01' AND '12' AND SUBSTR(fecha,9,2) BETWEEN '01' AND '31' AND SUBSTR(hora, 1, locate(':',hora)-1) BETWEEN 00 AND 24 order by fecha, hora" %(str(list(self.varpluvio)).strip("[]").replace("'",""),self.Estacion.strip("[]"),self.Fechai,self.Fechaf)


		elif self.thiess:
			print 'Datos Thiess'
			self.user 	= 'siata_Consulta'
			self.passwd 	= 'si@t@64512_C0nsult4'
			self.dbname	= 'siata'
			Analoga={'pr':'P_SSR','p':'PLiquida_SSR','t':'TAire10_SSR','h':'HAire10_SSR','vv':'VViento_SSR','dv':'DViento_SSR'}
			varcalidad= Analoga[self.varthiess[0]] if self.varthiess not in ['dv','vv'] else 'VViento_SSR'
			self.query_1=  "SELECT fecha_hora,cliente,%s FROM meteo_thiess WHERE cliente in (%s) AND calidad not in (%s) AND fecha_hora BETWEEN '%s' AND '%s' order by fecha_hora" %(str(list(self.varthiess)).strip("[]").replace("'",""),self.Estacion.strip("[]"),str(calidad_siata[varcalidad]).strip("[]"),self.Fechai,self.Fechaf) # self.Fechai[:10],self.Fechaf[:10]

		elif self.Validado:
			print 'Datos validados'
			self.query_1 = "SELECT fecha_hora,codigoserial,%s FROM redAireDataValidado WHERE CodigoSerial in (%s) AND fecha_hora \
				BETWEEN '%s' AND '%s' order by fecha_hora" %(('pm25' if self.var=='PM2.5' else self.var),self.Estacion,self.Fechai,self.Fechaf)
			self.fechaum = "SELECT fecha_hora,codigoserial,fechaultimamodificacion from redAireDataValidado WHERE CodigoSerial in (%s) \
				AND fecha_hora BETWEEN '%s' AND '%s' order by fecha_hora" %(self.Estacion,self.Fechai,self.Fechaf)

		elif self.Manual:
			print 'Datos Estaciones Manuales'
			if self.var=='PM2.5M':
				self.var1 = 'pm25'
			elif self.var=='PM10M':
				self.var1 = 'pm10'

			self.Estaciones =  self.Est[self.Est[self.var]==1]['Nombre'].values
			self.Estacion = str(list(self.Estaciones)).strip('[]').replace('59',"'EST-MAGO'").replace('73',"'COP-IATO'")
			self.query_1 = "SELECT fecha_hora,nombrecorto,%s FROM redAireDataManual WHERE nombrecorto in (%s) AND fecha_hora \
				BETWEEN '%s' AND '%s' order by fecha_hora" %(self.var1,self.Estacion,self.Fechai,(dt.datetime.strptime(self.Fechaf, '%Y-%m-%d %H:%M') - dt.timedelta(hours=1)).strftime('%Y-%m-%d %H:%M') if self.AutomaticManual else self.Fechaf)
			self.fechaum = "SELECT fecha_hora,nombrecorto,fechaultimamodificacion from redAireDataManual WHERE nombrecorto in (%s) \
				AND fecha_hora BETWEEN '%s' AND '%s' order by fecha_hora" %(self.Estacion,self.Fechai,(dt.datetime.strptime(self.Fechaf, '%Y-%m-%d %H:%M') - dt.timedelta(hours=1)).strftime('%Y-%m-%d %H:%M') if self.AutomaticManual else self.Fechaf)

		elif (self.ValidadoSiata) | (self.Meteorologicas & self.ValidadoSiata):
			print 'Datos validados Siata'
			### Para que lea sólo meteorológia de ruido
			#self.Estacion= '3,6,17,60,70,76' if self.Meteorologicas else self.Estacion
			self.Estacion= self.Estacion
			self.var1=('pm25' if self.var=='PM2.5' else self.var)
			self.query_1 = "SELECT fecha_hora,codigoserial,%s FROM redAireDataValidadoSIATA WHERE CodigoSerial in (%s) AND calidad_%s<2.6 AND fecha_hora \
				BETWEEN '%s' AND '%s' order by fecha_hora" %(self.var1,self.Estacion,self.var1,self.Fechai,self.Fechaf) # %var
			self.fechaum = "SELECT fecha_hora,codigoserial,fechaultimamodificacion from redAireDataValidadoSIATA WHERE CodigoSerial in (%s) AND fecha_hora BETWEEN '%s' AND '%s' order by fecha_hora" %(self.Estacion,self.Fechai,self.Fechaf)

		elif self.Crudos:
			print 'Datos sin validar'
			print 'Datos sin validar'
			self.query_1 = "SELECT fecha_hora,codigoserial,valor FROM redAireData WHERE variable_name='%s' AND codigoSerial in (%s) AND fecha_hora \
				BETWEEN '%s' AND '%s' order by fecha_hora" %(self.var,self.Estacion,self.Fechai,self.Fechaf)
			self.fechaum = "SELECT fecha_hora,codigoserial,fechaultimamodificacion FROM redAireData WHERE variable_name='%s' AND codigoSerial in (%s) \
				AND fecha_hora BETWEEN '%s' AND '%s' order by fecha_hora" %(self.var,self.Estacion,self.Fechai,self.Fechaf)

		elif self.Ruido:
			print 'Datos Ruido'
			self.calidad = str(map(lambda x: 'calidad_%s = 1 or' %x, self.frec_ruido.values())).strip('[]').replace("'","").replace(",","")[:-3]
			#self.query_1 ="SELECT fecha_hora,%s FROM redAireDataRuido WHERE fecha_hora BETWEEN '%s' AND '%s' \
			#	AND (%s) order by fecha_hora " %(str(self.frec_ruido.values()).strip('[]').replace("'",""),self.Fechai,self.Fechaf,self.calidad)

			self.query_1 ="SELECT fecha_hora,%s FROM redAireDataRuido WHERE codigoserial in (%s) AND fecha_hora BETWEEN '%s' AND '%s' \
				AND (%s) order by fecha_hora " %(str(self.frec_ruido.values()).strip('[]').replace("'",""),self.Estacion,self.Fechai,self.Fechaf,self.calidad)
			print self.query_1
		elif self.LRAdiario and self.Flags:
			self.query_1 ="SELECT fecha_hora,CodigoSerial, calidad_%s from redAireDataRuidoDiario where fecha_hora between '%s' and '%s' order by fecha_hora"\
				 %(self.var[0],self.Fechai,self.Fechaf)
			self.query_2 ="SELECT fecha_hora,CodigoSerial, calidad_%s from redAireDataRuidoDiario where fecha_hora between '%s' and '%s' order by fecha_hora"\
				 %(self.var[1],self.Fechai,self.Fechaf)
			self.query_3 ="SELECT fecha_hora,CodigoSerial, calidad_%s from redAireDataRuidoDiario where fecha_hora between '%s' and '%s' order by fecha_hora"\
				 %(self.var[2],self.Fechai,self.Fechaf)

		elif self.LRAdiario:
			print 'Datos LRAdiario'
			if len(self.Estacion)>10:#20
				#self.query_1 ="SELECT fecha_hora,CodigoSerial, %s from redAireDataRuidoDiario where CodigoSerial in (%s) and calidad_%s<2.6 and calidad_%s<2.6 and calidad_%s<2.6 and fecha_hora between '%s' and '%s' order by fecha_hora"\
				#	 %(str(self.var).strip('[]').replace("'",""), self.Estacion, self.var[0],self.var[1],self.var[2],self.Fechai,self.Fechaf)

				self.query_1 ="SELECT fecha_hora,CodigoSerial, %s from redAireDataRuidoDiario where calidad_%s<3 and fecha_hora between '%s' and '%s' order by fecha_hora"\
					 %(self.var[0], self.var[0],self.Fechai,self.Fechaf)
				self.query_2 ="SELECT fecha_hora,CodigoSerial, %s from redAireDataRuidoDiario where calidad_%s<3 and fecha_hora between '%s' and '%s' order by fecha_hora"\
					 %(self.var[1], self.var[1],self.Fechai,self.Fechaf)
				self.query_3 ="SELECT fecha_hora,CodigoSerial, %s from redAireDataRuidoDiario where calidad_%s<3 and fecha_hora between '%s' and '%s' order by fecha_hora"\
					 %(self.var[2], self.var[2],self.Fechai,self.Fechaf)
				'''
				self.query_1 ="SELECT fecha_hora,CodigoSerial, %s from redAireDataRuidoDiario where CodigoSerial in (%s) and calidad_%s>0 and fecha_hora between '%s' and '%s' order by fecha_hora"\
					 %(self.var[0], self.Estacion, self.var[0],self.Fechai,self.Fechaf)
				self.query_2 ="SELECT fecha_hora,CodigoSerial, %s from redAireDataRuidoDiario where CodigoSerial in (%s) and calidad_%s>0 and fecha_hora between '%s' and '%s' order by fecha_hora"\
					 %(self.var[1], self.Estacion, self.var[1],self.Fechai,self.Fechaf)
				self.query_3 ="SELECT fecha_hora,CodigoSerial, %s from redAireDataRuidoDiario where CodigoSerial in (%s) and calidad_%s>0 and fecha_hora between '%s' and '%s' order by fecha_hora"\
					 %(self.var[2], self.Estacion, self.var[2],self.Fechai,self.Fechaf)
				'''
			else:
				self.calidadLR = str(map(lambda x:'and calidad_'+x+'<3' ,self.var)).strip('[]').replace("'","").replace(",","")
				#self.query_1 ="SELECT fecha_hora, %s, %s from redAireDataRuidoDiario where nombreCorto=%s and fecha_hora between '%s' and '%s' order by fecha_hora"\
				#	 %(str(self.var).strip('[]').replace("'",""),self.calidadLR, self.Estacion, self.Fechai,self.Fechaf)

				self.query_1 ="SELECT fecha_hora, %s from redAireDataRuidoDiario where CodigoSerial in (%s) %s and fecha_hora between '%s' and '%s' order by fecha_hora"\
					 %(str(self.var).strip('[]').replace("'",""),self.Estacion,self.calidadLR, self.Fechai,self.Fechaf)

			print self.query_1

		elif self.LRAhorario and self.Flags:
			print 'Datos LRAhorario'

			self.query_1="SELECT fecha_hora, CodigoSerial,calidad_LRAeqH from redAireDataRuidoHorario where fecha_hora between '%s' and '%s' order by fecha_hora"\
        	                  %(self.Fechai,self.Fechaf)
		elif self.LRAhorario:
			print 'Datos LRAhorario'

			self.query_1="SELECT fecha_hora, CodigoSerial, LRAeqH from redAireDataRuidoHorario where calidad_LRAeqH<3 and fecha_hora between '%s' and '%s' order by fecha_hora"\
        	                  %(self.Fechai,self.Fechaf)
		elif self.MeteoRuido:
			self.var1=self.var
			for c in range(2):
				if c==0:
					#self.query_2 = "SELECT fecha_hora,nombreCorto,%s FROM redAireDataRuidoMeteorologiaPCE WHERE nombreCorto in ('CEN-TRAF', 'MED-PJIR','ITA-ACUA') AND fecha_hora \
					#	BETWEEN '%s' AND '%s' order by fecha_hora" %(self.var1,self.Fechai,self.Fechaf) # %var
					self.query_2 = "SELECT fecha_hora,nombreCorto,%s FROM redAireDataRuidoMeteorologiaPCE WHERE nombreCorto in %s AND fecha_hora BETWEEN '%s' AND '%s' order by fecha_hora" %(self.var1,str(tuple(self.EstR.loc[(self.EstR['PCE']>0)&(self.EstR.Ruido==1),]['Nombre'].values)),self.Fechai,self.Fechaf)
				else:
					#self.query_1 = "SELECT fecha_hora,nombreCorto,%s FROM redAireDataRuidoMeteorologiaDavis WHERE nombreCorto in ('GIR-BOTJ', 'SAB-SEMS', 'MED-ZOOL', 'MED-SIAT','ITA-SAMA') AND fecha_hora \
					#	BETWEEN '%s' AND '%s' order by fecha_hora" %(self.var1,self.Fechai,self.Fechaf) # %var
					self.query_1 = "SELECT fecha_hora,nombreCorto,%s FROM redAireDataRuidoMeteorologiaDavis WHERE nombreCorto in %s AND fecha_hora BETWEEN '%s' AND '%s' order by fecha_hora" %(self.var1,str(tuple(self.EstR.loc[(self.EstR['Davis']>0)&(self.EstR.Ruido==1),]['Nombre'].values)),self.Fechai,self.Fechaf)

		elif (self.Flags | (self.Meteorologicas & self.Flags)):
			print 'Flags validados Siata'
			self.var1=('pm25' if self.var=='PM2.5' else self.var)
			self.query_1 = "SELECT fecha_hora,codigoserial,calidad_%s FROM redAireDataValidadoSIATA WHERE CodigoSerial in (%s) AND fecha_hora \
				BETWEEN '%s' AND '%s' order by fecha_hora" %(self.var1,self.Estacion,self.Fechai,self.Fechaf) # %var
			self.fechaum = "SELECT fecha_hora,codigoserial,fechaultimamodificacion from redAireDataValidadoSIATA WHERE CodigoSerial in (%s) \
				AND fecha_hora BETWEEN '%s' AND '%s' order by fecha_hora" %(self.Estacion,self.Fechai,self.Fechaf)
		elif kwargs.get('RWP',False):
			self.host   = "192.168.1.74"
			self.user   = "postgres"
			self.passwd = "b-5Z+cc.P"
			self.dbname = "newsiata"

			self.query_1 = "SELECT fecha_hora,ht,u,v,w FROM data_radar_vientos_06 WHERE AND fecha_hora \
				BETWEEN '%s' AND '%s' order by fecha_hora" %(self.Fechai,self.Fechaf)

		if 'RWP' not in kwargs.keys():		self.conn_db 		= MySQLdb.connect (self.host, self.user, self.passwd, self.dbname)
		else:								self.conn_db 		= psycopg2.connect("dbname='%s' user='%s' host='%s' password='%s'" %(self.dbname,self.user,self.host,self.paswwd))

		self.db_cursor 		= self.conn_db.cursor ()
		self.db_cursor.execute(self.query_1)
		if self.LRAdiario:
	                self.db_cursor2  = self.conn_db.cursor ()
	                self.db_cursor2.execute (self.query_2)
	                self.db_cursor3  = self.conn_db.cursor ()
	                self.db_cursor3.execute (self.query_3)




		if self.Vaisala:
			self.Data = pd.DataFrame(np.array(self.db_cursor.fetchall ()),columns=['Fechas','F','Estaciones']+self.varvaisala) #.dropna(subset=['Fechas']).set_index(['Fechas','Estaciones']).astype(float).unstack()
			self.Data['F'] = pd.to_datetime(self.Data['F'])
			self.Data = self.Data[map(lambda x,y: x==y,self.Data['Fechas'],self.Data['F'])].drop('F',axis=1).set_index(['Fechas','Estaciones']).astype(float).unstack()

			if 'sm' in self.varvaisala: self.Data.sm = self.Data.sm/10.
			if 'rc' in self.varvaisala: self.Data.rc = self.Data.rc/100.

		elif self.Pluviometro:
			self.Data = pd.DataFrame(np.array(self.db_cursor.fetchall ()),columns=['Fechas','Estaciones']+self.varpluvio)
			self.Data['Fechas'] = pd.to_datetime(self.Data['Fechas'])
			self.Data = self.Data.set_index(['Fechas','Estaciones']).astype(float).unstack().resample('1T').sum()/1000.

                elif self.PluviometroJAL:
                        self.Data = pd.DataFrame(np.array(self.db_cursor.fetchall ()),columns=['Fechas','Estaciones']+self.varpluvio)
                        self.Data['Fechas'] = pd.to_datetime(self.Data['Fechas'])
                        self.Data = self.Data.set_index(['Fechas','Estaciones']).astype(float).unstack().resample('1T').sum()/1000.

		elif self.thiess:
			self.Data = pd.DataFrame(np.array(self.db_cursor.fetchall ()),columns=['Fechas','Estaciones']+self.varthiess)
			self.Data['Fechas'] = pd.to_datetime(self.Data['Fechas'])
			#aaa.aaa
			self.Data = self.Data.set_index(['Fechas','Estaciones']).astype(float).unstack().resample('1T').sum()

              # Se quita el dividido 1000 para no afectar la Velocidad de Viento
 			if 'dv' not in self.varthiess:
			    self.Data[self.Data<0]=np.NaN
			else:
			    print 'puede haber valores negativos en las variables leidas'


		elif self.Ruido:
			self.Data = pd.DataFrame(np.array(self.db_cursor.fetchall ()),columns=['Fechas']+self.frec_ruido.keys())
			self.Data = self.Data.set_index('Fechas').astype(float)
			#Filtro2 =(self.Data==-9999)|(self.Data<0)
			#self.Data[Filtro2]=np.nan
			#self.Data = self.Data.dropna(axis=1,how='all')
		elif self.LRAdiario:
			if len(self.Estacion)>10:
				self.Data = {}
				self.Data[self.var[0]]=pd.DataFrame(np.array(self.db_cursor.fetchall ()),columns=['Fechas','Estacion',self.var[0]])
				self.Data[self.var[1]]=pd.DataFrame(np.array(self.db_cursor2.fetchall ()),columns=['Fechas','Estacion',self.var[1]])
				self.Data[self.var[2]]=pd.DataFrame(np.array(self.db_cursor3.fetchall ()),columns=['Fechas','Estacion',self.var[2]])

				#for i in range(3):
				#	Filtro2 =(self.Data[self.var[i]]==-9999)|(self.Data[self.var[i]]<0)
				#	self.Data[self.var[i]][Filtro2]=np.nan
				#	self.Data[self.var[i]] = self.Data[self.var[i]].dropna(axis=1,how='all')


				#EstRuido={3:'GIR-SOSN',6:'MED-PJIC',17:'ITA-CODI',60:'SAB-SEMS',70:'GIR-BOTJ',72:'MED-PLMA',76:'MED-SIAT'}
				for u in range(3):
					#for e in EstRuido.keys():
					EST=np.unique(self.Data[self.var[u]]['Estacion'])
					for e in EST:
						self.Data[self.var[u]]['Estacion'][self.Data[self.var[u]]['Estacion']==e]=self.EstR['Nombre'][self.EstR.index==e].values[0]

					self.Data[self.var[u]] = self.Data[self.var[u]].set_index(['Fechas','Estacion']).astype(float).unstack()
					self.Data[self.var[u]]=self.Data[self.var[u]][self.var[u]]
				for u in range(3):
					Filtro2 =(self.Data[self.var[u]]==-9999)|(self.Data[self.var[u]]<0)
					self.Data[self.var[u]][Filtro2]=np.nan
					self.Data[self.var[u]]=self.Data[self.var[u]].dropna(axis=1,how='all')
				'''
				self.Data = pd.DataFrame(np.array(self.db_cursor.fetchall ()))
				self.Data = self.Data.rename(columns={0:'Fechas',1:'Estacion',2:self.var[0],3:self.var[1],4:self.var[2]})
				self.Data = self.Data.set_index(['Fechas','Estacion']).astype(float).unstack()
				self.Data =self.Data[self.var]
				'''
			else:
				self.Data = pd.DataFrame(np.array(self.db_cursor.fetchall ()),columns=['Fechas']+self.var+self.calidadLR.split(', '))
        	                self.Data = self.Data.set_index('Fechas')

		elif self.LRAhorario:
			if len(self.Estacion)>10:
	                        self.Data = pd.DataFrame(np.array(self.db_cursor.fetchall ()),columns=['Fechas','Estacion','LRAeqH'])
				self.Data = self.Data.set_index(['Fechas','Estacion']).astype(float).unstack()
				self.Data=self.Data['LRAeqH']
				self.Data.columns= self.EstR['Nombre'].loc[self.Data.columns.values].values
			else:
	                        self.Data = pd.DataFrame(np.array(self.db_cursor.fetchall ()),columns=['Fechas','LRAeqH','calidad'])
	                        self.Data = self.Data.set_index('Fechas')
			Filtro2 =(self.Data==-9999)|(self.Data<0)
			self.Data[Filtro2]=np.nan
			self.Data = self.Data.dropna(axis=1,how='all')

		elif self.MeteoRuido:
			a0 = pd.DataFrame(np.array(self.db_cursor.fetchall ()))
			a0 = a0.set_index([0,1]).unstack().astype(float)
			self.db_cursor.execute (self.query_2)
			a2 = pd.DataFrame(np.array(self.db_cursor.fetchall ()))
			a2 = a2.set_index([0,1]).unstack().astype(float)
			if self.var=='PLiquida_SSR':
				a2=a2.resample('H').sum()
			else:
				a2=a2.resample('H').mean()
			a1=pd.concat([a0,a2],axis=1)
			self.Data					= a1
			self.Data.columns			= self.Data.columns.get_level_values(1)
			self.Data[self.Data ==-9999] 	= np.NaN
			self.Data[self.Data < 0 ] 		= np.NaN

		elif (self.query != None):
			self.Data = self.db_cursor.fetchall ()
		else: 
			a1 = pd.DataFrame(np.array(self.db_cursor.fetchall ()))
			#print a1
#			if self.var1 == "SO2":
#				return pd.DataFrame ()
#			if a1.size <= 0:
#				aaa.aaa
			print "----------------------------------------------------------------------------------------------"
			print self.var1
			print self.query_1
			print "----------------------------------------------------------------------------------------------"
			a1 = a1.set_index([0,1])
			a1 = a1.unstack()
			a1 = a1.astype(float)

			self.Data					= a1
			self.Data.columns			= self.Data.columns.get_level_values(1)
			self.Data[self.Data ==-9999]    = np.NaN
			self.Data[self.Data < 0 ]               = np.NaN

			if kwargs.get('fechaum',True) and self.MeteoRuido==False:
				self.db_cursor.execute(self.fechaum)
				self.fechaum 			= pd.DataFrame(np.array(self.db_cursor.fetchall ())).set_index([0,1]).unstack() #.astype(float)
				self.fechaum.columns	= self.fechaum.columns.get_level_values(1)

			if self.Manual != True and self.MeteoRuido==False:
				self.Data 					= self.Data.resample('1h').mean()
				self.Data.index 			= self.Data.index - dt.timedelta(hours=1)
				###ptc1
				if kwargs.get('fechaum',True): self.fechaum.columns		= self.Est['Nombre'].loc[self.fechaum.columns.values].values

		if self.Crudos:
			if ((self.var == 'PM2.5') & (48 in self.Estaciones)):

				self.query_2 = "SELECT fecha_hora,valor FROM redAireData WHERE CodigoSerial=48 AND fecha_hora BETWEEN '%s' AND '%s' \
						AND variable_name = 'TAire10_SSR' order by fecha_hora" % (self.Fechai,self.Fechaf)
				self.db_cursor.execute (self.query_2)
				self.Temp = pd.DataFrame(np.array(self.db_cursor.fetchall ())).set_index(0).astype(float) 
				self.Temp.index = self.Temp.index - dt.timedelta(hours=1)
				self.Data['T'] = (760.0/(628.4*298))*(self.Temp+273.15)

			if ((self.var == 'PM2.5') & (12 in self.Estaciones)):
				if self.Crudos:
					self.query_1 = "SELECT fecha_hora,valor FROM redAireData WHERE CodigoSerial=12 AND fecha_hora BETWEEN '%s' AND '%s' \
						AND variable_name= 'PM2.5_' order by fecha_hora" %(self.Fechai,self.Fechaf)
					self.db_cursor.execute (self.query_1)
					self.Temp = pd.DataFrame(np.array(self.db_cursor.fetchall ())).set_index(0).astype(float)*1000.
					self.Temp.index = self.Temp.index - dt.timedelta(hours=1)
					self.Data[12] = self.Temp

		if self.Vaisala:
			self.Data[self.Data>1500] = np.NaN
			self.Data[self.Data<0]   = np.NaN

		self.conn_db.close ()

		#Filtro del 75% de los datos y valores repetidos continuos
		if self.filtro:
			print 'Filtrando datos que no cumple con >75% datos diarios'

			self.filtro1 = self.Data.resample('D').count()/24.<.75

			for est in self.filtro1.columns.values:
				for date in self.filtro1[est][self.filtro1[est].values==True].index:
					self.Data[est].mask((self.Data.index >= date) & (self.Data.index < date +dt.timedelta(days=1)) , inplace=True)

		if (self.Meteorologicas) & (self.var == 'P_SSR') & (self.Flags == False):
			self.Data = self.Data*1.333224   #Conversión mmHg - hPa

		if self.Crudos:
			if (self.var == 'PM2.5') & (48 in self.Estaciones):
				self.Data[48] = self.Data['T']*self.Data[48]
				self.Data=self.Data.drop('T',axis=1)

		if self.Flags and (self.LRAdiario==False | self.LRAhorario==False) | self.Crudos | self.Validado | self.Meteorologicas | self.ValidadoSiata: 	self.Data.columns	= self.Est['Nombre'].loc[self.Data.columns.values].values

		self.runica = False
		if self.Flags != True:

			self.Dataica = 0
			if self.var == 'Ozono':
				self.Dataica = self.Data if self.Validado else self.Data/1000.
				self.Data = self.Data*1961.9429565557355 if self.Validado else self.Data* 1.9619429565557354
				self.runica = True
			elif self.var == 'NO':
				self.Dataica = self.Data/1000.
				self.Data = self.Data* 1.2264653130505272
				self.runica = True
			elif self.var == 'NO2':
				self.Dataica = self.Data/1000.
				self.Data = self.Data* 1.880421774282149
				self.runica = True
			elif self.var == 'NOx':
				self.Dataica = self.Data/1000.
				self.Data = self.Data
				self.runica = True
			elif self.var == 'SO2':
				self.Dataica = self.Data/1000.
				self.Data = self.Data* 2.618621613639578
				self.runica = True
			elif self.var == 'CO':
				self.Dataica = self.Data
				self.Data = self.Data* 1144.8754627734613
				self.runica = True
			elif self.var in ['PM10','PM2.5','PM10M','PM2.5M']:
				self.Dataica = self.Data
				self.runica = True

		#Formula para conversion de unidades ppb -> ug/m3: Po * M / ( T * R *10 ) [=] Po = 1013.25 hPa, T= 298.15 K, R = 8.31451 J/mol K, M = g/mol, 

		if self.runica: 		return self.Data,self.Dataica
		else: 					return self.Data

	def Read_db(self, *args,**kwargs):
		"""Permite leer todos los datos de las variables meteorologicas 
		de acuerdo a las fechas establecidas en el init"""

		self.Validado		= kwargs.get('Validado',False)
		self.ValidadoSiata	= kwargs.get('ValidadoSiata',False)
		self.Meteorologicas	= kwargs.get('Meteorologicas',False)
		self.MeteoRuido		= kwargs.get('MeteoRuido',False)
		self.Manual			= kwargs.get('Manual',False)
		self.filtro			= kwargs.get('filtro',False)
		self.Flags			= kwargs.get('Flags',False)
		self.Vaisala		= kwargs.get('Vaisala',False)

		self.ica = {}
		self.Fechaum = {}
		self.C = {}

		if self.Vaisala:
			self.C				= self.Aire_db(Vaisala=True,)
			self.Winds			= pd.concat({'U':self.Data.sm*np.cos(self.Data.dm*np.pi/180.),'V':self.Data.sm*np.sin(self.Data.dm*np.pi/180.)},axis=1).resample('1T',how='mean')
			self.Winds			= pd.concat([self.Winds,pd.concat({'D':(np.arctan2(self.Winds.V,self.Winds.U)*180./np.pi)%360,'S':(self.Winds.U**2+self.Winds.V**2)**.5},axis=1)],axis=1)

		if self.Meteorologicas:
			for var in self.nombre_meteorologicas:
				if self.Flags:
					self.var   = var
					self.C[var] = self.Aire_db(Meteorologicas=self.Meteorologicas,Flags=self.Flags) 
					self.Fechaum[var] = self.fechaum
				else:
					self.var   = var
					self.C[var] = self.Aire_db(Meteorologicas=self.Meteorologicas,ValidadoSiata=self.ValidadoSiata,fechaum=kwargs.get('fechaum',True)) if self.ValidadoSiata else self.Aire_db(Meteorologicas=self.Meteorologicas,fechaum=kwargs.get('fechaum',True)) 
					if kwargs.get('fechaum',True): self.Fechaum[var] = self.fechaum
		elif self.MeteoRuido:
			for var in ['P_SSR','PLiquida_SSR','TAire10_SSR','HAire10_SSR','VViento_SSR','DViento_SSR']:
				self.var   = var
				self.C[var] = self.Aire_db(MeteoRuido=self.MeteoRuido)
				self.Meteorologicas=True

		elif self.Manual:
			for var in ['PM2.5M','PM10M']:
				self.var=var
				self.C[var],self.ica[var]=self.Aire_db(Variable=var,Manual=True)
				self.Fechaum[var] = self.fechaum

		else:
			for var in self.nombre_contaminantes:
				self.var   = var
				if self.Validado:
					self.x = self.Aire_db(Validado=self.Validado,filtro=self.filtro)
				elif self.ValidadoSiata:
					self.x = self.Aire_db(ValidadoSiata=self.ValidadoSiata,filtro=self.filtro,fechaum=kwargs.get('fechaum',True))

				elif self.Flags:
					self.x = self.Aire_db(Flags=self.Flags,filtro=self.filtro)
				else:
					self.x = self.Aire_db(filtro=self.filtro)

				print 'Flags 1'
				self.Fechaum[var] = self.fechaum
				print 'Flags 2'
				try: self.C[var],self.ica[var] = self.x[0],self.x[1]
				except:
					self.C[var] = self.x
					pass

		if self.Meteorologicas:
			self.Meteo    					= pd.concat(self.C,axis=1)
			if kwargs.get('fechaum',True) and self.MeteoRuido==False:	self.FechaumM 					= pd.concat(self.Fechaum,axis=1)

		elif self.Manual:
			self.ContaminanteManual			= pd.concat(self.C,axis=1)
			self.DicaM						= pd.concat(self.ica,axis=1)
			if kwargs.get('fechaum',True):	self.FechaumMM					= pd.concat(self.Fechaum,axis=1)
		else:

			self.Contaminante	= pd.concat(self.C,axis=1)
			if self.Flags != True:
				print 'Flags 5'
				self.Dica			= pd.concat(self.ica,axis=1)
			print 'Flags 6'
			if kwargs.get('fechaum',True):	self.FechaumC = pd.concat(self.Fechaum,axis=1)


	def Read_pkl_RWP(self,*args,**kwargs):
		self.RWP 				= open_pklfiles(kwargs.get('path','/home/jhernandezv/Winds/RWP/RWP.pkl'))
		self.ht					= self.RWP.columns.levels[1].values
		self.fi					= self.Fechai
		self.ff					= self.Fechaf
		self.Fechai 			= (self.RWP.index[-1]+dt.timedelta(minutes=5)).strftime("%Y-%m-%d %H:%M")
		self.Fechaf 			= dt.datetime.now().strftime("%Y-%m-%d %H:") + str(int(dt.datetime.now().strftime("%M"))/5*5)

		if kwargs.get('update',False):
			self.Read_RWP(update=kwargs.get('update',False))
			self.RWP 			= pd.concat([self.RWP,self.RWP_add])
		if kwargs.get('Save',False): make_pickle('/home/jhernandezv/Winds/RWP/','RWP',self.RWP)
		#~ make_pickle(os.getcwd()+'/','RWP',self.RWP)

		#~ if kwargs.get('All',False):
			#~ self.RWP 	= self.RWP[self.Fechai:self.Fechaf]

		#~ self.RWP=pd.concat([self.RWP,pd.concat({'ADV':(self.RWP['U']**2+self.RWP['V']**2)**0.5},axis=1)])
		#~ cd=pd.concat([cd,adv])
		self.Fechai				= self.fi
		self.Fechaf				= self.ff

	def Read_RWP(self,*args,**kwargs): # Freq = 5 ó 60

		print '--------------------------------------------------'
		print 'Lectura de archivos del Radar Perfilador de Viento'
		print '--------------------------------------------------'

		self.Fecha_Inicio 	= (dt.datetime.strptime(self.Fechai, "%Y-%m-%d %H:%M") + dt.timedelta(hours = 5)) #[:16]
		self.Fecha_Inicio 	= (self.Fecha_Inicio - dt.timedelta(minutes= self.Fecha_Inicio.minute%5))
		self.Fecha_Fin    	= (dt.datetime.strptime(self.Fechaf, "%Y-%m-%d %H:%M") + dt.timedelta(hours = 5)) #[:16]
		self.Fecha_Fin 		= (self.Fecha_Fin - dt.timedelta(minutes= self.Fecha_Fin.minute%5))

		self.Fechas = pd.date_range(self.Fecha_Inicio, self.Fecha_Fin,  freq = "1H" if self.freq==60 else "5Min")

		self.TRWP = {}

		for i in range(self.Fechas.size):
			print self.Fechas[i]
			self.files 				= self.Fechas[i].strftime ("/mnt/ALMACENAMIENTO/RWP/%Y-%m/w%Y-%m-%d-%H-" +'%s' %("00_60.asd" if self.freq ==60 else '%M_06.asd' if self.Fechas[i].strftime('%Y-%m') < '2015-06' else '%M_05.asd') ) 
			os.system('scp jhernandezv@192.168.1.62:%s .' %self.files)

			try:
				self.read_file 	= open(self.files[32:],'r').readlines()
				self.loc		= lambda x,y: self.read_file[x:].index(y)
				self.begin 		= self.loc(0,'  57   1800   1800\n') + 1
				self.end		= self.loc(0,'$\n') -1
				self.temp 		= pd.read_csv(self.files[32:],sep='\s+',usecols =(0,4,5,6),skiprows=self.begin,nrows= self.end-self.begin,index_col=0,engine='python')

				self.begin		= self.loc(0, '  77   1800   1800\n') +1
				self.temp 		= self.temp.append( pd.read_csv(self.files[32:],sep='\s+',usecols =(0,4,5,6),skiprows=self.begin,nrows=self.loc(self.begin,'$\n')-1,index_col=0,engine='python') )
				self.temp.index = np.round(self.temp.index.values,decimals=0)

				self.TRWP[self.Fechas[i]]	= self.temp
			except:
				print 'Fail',self.files
				pass
			os.system('rm %s' %self.files[32:])

		self.TRWP = pd.concat(self.TRWP).unstack(1)
		#~ self.TRWP.set_levels(self.TRWP.index.levels[0])
		self.TRWP.index = self.TRWP.index - dt.timedelta (hours = 5)
		self.TRWP.mask((self.TRWP<-70) | (self.TRWP>70),inplace=True)
		self.TRWP.W.mask((self.TRWP.W<-20) | (self.TRWP.W>20),inplace=True)


		if kwargs.get('update',False):	self.RWP_add = self.TRWP
		else:							self.RWP     = self.TRWP
		self.TRWP = None


	def Calcula_ICA(self,*args,**kwargs):

		self.Manual =	kwargs.get('Manual', True)
		self.ICA = {}
		self.O3H = True
		for var in ['PM10','PM2.5','SO2','CO','Ozono','Ozono','NO2'] + ['PM10M','PM2.5M'] if self.Manual else ['PM10','PM2.5','SO2','CO','Ozono','Ozono','NO2']:
#		for var in ['PM10','PM2.5','CO','Ozono','Ozono','NO2'] + ['PM10M','PM2.5M'] if self.Manual else ['PM10','PM2.5','CO','Ozono','Ozono','NO2']:
			print var
			self.Base = self.DicaM if var in ['PM10M','PM2.5M'] else self.Dica

			if var in ['PM10','PM2.5','SO2','PM10M','PM2.5M']:
				self.resol = 'D'
			elif (var == 'CO'):
				self.resol = '8h'
			elif (var == 'Ozono'):
				self.resol = '8h' if self.O3H else '1h'
				self.O3H = False 
			else:
				self.resol ='1h'
			self.varresol = '%s-%s' %(var,self.resol)

			self.ica			= self.Base.resample(self.resol).mean() if self.resol != '8h' else self.Base.rolling(window=8,freq='1h').mean()
			self.icasave		= self.Base.resample(self.resol).mean() if self.resol != '8h' else self.Base.rolling(window=8,freq='1h').mean()

			for i in range(6):
				self.por = ( self.RangosICA[self.varresol]['Ihi'][i] - self.RangosICA[self.varresol]['Ilo'][i] ) / ( self.RangosICA[self.varresol]['Bphi'][i] - self.RangosICA[self.varresol]['Bplo'][i] )
				#if var == "SO2":
				#	continue
				self.bolean = (self.ica[var] >= self.RangosICA[self.varresol]['Bplo'][i]) & (self.ica[var] < self.RangosICA[self.varresol]['Bphi'][i])
				self.icasave[var][self.bolean]	=  (self.ica[var][self.bolean] - self.RangosICA[self.varresol]['Bplo'][i])*self.por + self.RangosICA[self.varresol]['Ilo'][i]
			#if var != "SO2":
			#	self.ICA['%s-%s' %(var,self.resol)] =self.icasave[var]
			#else:
				self.ICA['%s-%s' %(var,self.resol)] = None
			self.ICA['%s-%s' %(var,self.resol)] =self.icasave[var]
		self.ICA = pd.concat(self.ICA,axis=1)

	def Informe_Anual_Parametros(self,*args,**kwargs):
		
		#~ os.chdir('/home/jhernandezv/RedAire/Informe_Mensual/')
		self.Sisaire		= kwargs.get('Sisaire',False)
		self.Unal			= kwargs.get('Unal',False)
		self.Correo			= kwargs.get('Correo',False)
		self.Procuraduria	= kwargs.get('Procuraduria',False)
		self.AMVA			= kwargs.get('AMVA',False)
		self.read			= kwargs.get('read',True)
		self.Figuras		= kwargs.get('Figuras',True)
		self.Latex			= kwargs.get('Latex',True)
		self.filtro			= kwargs.get('filtro',True)
		
		if self.read:
			self.Read_db(filtro=self.filtro,ValidadoSiata=True)
			#self.Read_db(Meteorologicas=True,ValidadoSiata=True)
			#self.Read_db(Manual=True)
			#self.Calcula_ICA()
		
		
		self.path			= os.getcwd()
		self.path_U			= self.path+'/Correo'
		
		if self.Figuras:
			os.system('rm -rf Figuras/')
			os.system('mkdir Figuras/')
			#~ #Lee Datos Meteorología
			
			#~ os.system('mkdir Figuras/Meteorologia/')
			#~ os.system('mkdir Figuras/PLiquida_SSR/')
			#~ os.system('mkdir Figuras/Procuraduria/')
			os.system('mkdir Figuras/Ruido/')
			#~ os.system('rm Datos/*')
			
			#Lee datos Contaminantes
			
			#~ ######################################################################
			#~ #                        Ciclos Diurnos
			
			#for var in self.nombre_contaminantes +['PM2.5M','PM10M','P_SSR', 'TAire10_SSR', 'RGlobal_SSR', 'HAire10_SSR']:
			#	self.var = var
			#	os.system('mkdir Figuras/%s/' %('PM25' if self.var == 'PM2.5' else 'PM25M' if self.var == 'PM2.5M' else self.var))
				#~ if self.var not in ['P_SSR', 'TAire10_SSR', 'RGlobal_SSR', 'HAire10_SSR']:
					#~ self.Plot_CicloDiurno(Anual=True,title=False,legend=False)
					#~ self.Plot_CicloDiurno(Semanal=True,title=False,legend=False)
					
				#~ if self.var not in ['PM2.5M','PM10M']:
					#~ self.Plot_CicloDiurno(title=False,legend=False)
					#~ self.Plot_Promedio_Mensual()
				
			#	if var not in ['P_SSR', 'TAire10_SSR', 'RGlobal_SSR', 'HAire10_SSR','PM2.5M','PM10M']: self.Plot_Serie(title=False,legend=False)
			
			#~ ######################################################################
			#~ #                     PPT
			
			#~ self.var = 'PLiquida_SSR'
			#~ self.Plot_Precipitacion_Distribucion_Diurna()
			#~ self.Meteo[self.var]['ITA-CONC']['2016-11'] = np.NaN
			#~ self.Plot_Promedio_Mensual()
			
			#~ ######################################################################
			#~ #           ICA Barras totales y ciclos anuales
			
			#~ for var in ['PM10','PM2.5','SO2']:
				#~ self.var = var
				#~ self.Plot_ICA_Resumen()
				#~ self.Plot_ICA_Resumen(Mensual=True)
				#~ self.Plot_ICA_Anual()
			#~ for var in ['PM2.5M','PM10M']:
				#~ self.var = var
				#~ self.Plot_ICA_Hist(title=False,loc_text='top')
			#~ for var in ['Ozono','CO']:
				#~ self.var = var
				#~ self.Plot_ICA_Resumen(resolucion='8h')
				#~ self.Plot_ICA_Resumen(Mensual=True,resolucion='8h')
			#~ for var in ['Ozono','NO2']: #'CO'
				#~ self.var = var
				#~ self.Plot_ICA_Resumen(resolucion='1h')
				#~ self.Plot_ICA_Resumen(Mensual=True,resolucion='1h')
			
			#~ ######################################################################
			#~ #       Histogramas ICA
			
			#~ for var in ['PM10','PM2.5','SO2','PM2.5M','PM10M']:
				#~ self.var = var
				#~ self.Plot_ICA_Hist(title=False,title2=True,legend=True,loc_text='top')

			#~ for var in ['Ozono','CO']:
				#~ self.var = var
				#~ self.Plot_ICA_Hist(resolucion='8h',title=False,title2=True,legend=True,loc_text='top')

			#~ for var in ['Ozono','NO2']: #'CO'
				#~ self.var = var
				#~ self.Plot_ICA_Hist(resolucion='1h',title=False,title2=True,legend=True,loc_text='top')


			######################################################################
			#~ #                       Mapas
			#~ self.Mapas()
			
			#~ ######################################################################
			#~ #	         Histogrmas Meteorología
			
			#~ for var in ['P_SSR', 'PLiquida_SSR', 'TAire10_SSR', 'RGlobal_SSR', 'HAire10_SSR']:
				#~ self.var = var
				#~ self.Plot_Histogramas(title=False)
			
			#~ ######################################################################
			#~ #	         Tabla Estadisticas
			
			#~ C = pd.concat([self.Contaminante,self.Meteo,self.ContaminanteManual],axis=1)
			#~ for par in C.columns.levels[0].values:
				#par = 'PM2.5'
				#~ Tabla1 = C[par].describe().T
				#~ for resol in self.norma.keys():
					#~ if (par in self.norma[resol].keys()) & (resol != 'Y'):
						#~ var = C[par].resample('D').apply(lambda x: x.mean() if par != 'PLiquida_SSR' else x.sum()) if resol == 'D' else C[par].rolling(int(resol[0]),freq='1h').mean()
						#~ Tabla1['EXC-%s' %resol] = var[var > self.norma[resol][par]].count()/var.count()*100
					#~ Tabla1.to_csv('Datos/Estadisticas_%s.ods' %par)
			
			######################################################################
			#                 Tabla Maximos y Minimos

			#~ MM= pd.concat([self.Contaminante.resample('D').mean(),self.ContaminanteManual],axis=1)

			#~ c=0
			#~ Tabla2 = np.empty((MM.columns.size,6),dtype=object)

			#~ for var in MM.columns.levels[0].values:
				#~ for i in range(MM[var].max().index.size):
					#~ print var, '  ', MM[var].max().index[i]
					#~ maximo = MM[var][MM[var].max().index[i]][MM[var][MM[var].max().index[i]]==MM[var].max().values[i]]
					#~ minimo = MM[var][MM[var].min().index[i]][MM[var][MM[var].min().index[i]]==MM[var].min().values[i]]
					#~ Tabla2[c,:] = [var,maximo.name,maximo.index[0].strftime('%Y-%m-%d'),'%.2f' %maximo.values[0],minimo.index[0].strftime('%Y-%m-%d'),'%.2f' %minimo.values[0]]
					#~ c+=1

			#~ Tabla2=pd.DataFrame(Tabla2,columns=['Variable','Estación','Fecha Máximo','Valor Máximo','Fecha Mínimo','Valor Mínimo'])
			#~ Tabla2.to_csv('Datos/Minimos_Maximos.csv',index=False)


			#~ ######################################################################
			#~ #                      Rosas de Vientos
			
			#~ for est in self.Est[self.Est['VViento_SSR']==1]['Nombre'].values:
				#~ s=self.Meteo['VViento_SSR'][est]
				#~ d=self.Meteo['DViento_SSR'][est]
				#~ self.WindRose(d,s,textsave='%s_%s' %(est,'n'),bins=range(0,6,1),ylim=(0,40),yticks=range(10,41,10),yticklabels=range(10,41,10), legend=False, legend_fontsize='xx-large' ,InformeMensual=True,title=est)
				#~ self.WindRose(d[(d.index.hour >= 6) & (d.index.hour < 18)],s[(d.index.hour >= 6) & (d.index.hour < 18)], textsave='%s_dia_%s' %(est, 'n'),bins=range(0,6,1),ylim=(0,40),yticks=range(10,41,10),yticklabels=range(10,41,10), legend=False, legend_fontsize='xx-large' ,InformeMensual=True,title=est)
				#~ self.WindRose(d[(d.index.hour < 6) | (d.index.hour >= 18)],s[(d.index.hour < 6) | (d.index.hour >= 18)], textsave='%s_noche_%s' %(est,'l'),bins=range(0,6,1),ylim=(0,40),yticks=range(10,41,10),yticklabels=range(10,41,10), legend=True, legend_fontsize='xx-large' ,InformeMensual=True,title=est)
			
			######################################################################
			#~ #                      Ruido
			self.Fechai = '2017-01-01 00:00'
			self.Fechaf = '2017-12-31 23:59'
			
			self.Read_Noice_txt()
			self.Ajuste_Tonalidades()
			self.Filtro_Ruido()

			self.var='Ruido'
			self.Plot_Ruido_Semanal(textsave='_2017')

			self.Plot_Boxplot(df=self.LR.LRAeqD,title='LRAeqD',textsave='_Diurno',ylim=(47,102))
			self.Plot_Boxplot(df=self.LR.LRAeqN,title='LRAeqN',textsave='_Nocturno',ylim=(47,102))
			self.Plot_Boxplot(df=self.LR.LRAeqDN,title='LRAeqDN',textsave='_DiurnoNocturno',ylim=(47,102))
			
			#~ # Tabla Contraloría
		#	self.LR.describe().to_csv('Datos/Ruido_Estadisticas_2016.ods')

			#  TR = pd.DataFrame()
			#~ TR['LRAeqD'] = self.LR.LRAeqD.apply(lambda x: x[x>self.norma_ruido[x.name][1]].count()/float(x.count())*100)
			#~ TR['Norma_D'] = self.LR.LRAeqD.apply(lambda x: self.norma_ruido[x.name][1] )
			#~ TR['LRAeqN'] = self.LR.LRAeqN.apply(lambda x: x[x>self.norma_ruido[x.name][2]].count()/float(x.count())*100)
			#~ TR['Norma_N'] = self.LR.LRAeqN.apply(lambda x: self.norma_ruido[x.name][2] )
			#~ TR['Sector'] = self.LR.LRAeqD.apply(lambda x: self.norma_ruido[x.name][0])
			#~ TR.T.to_csv('Datos/Excedencias_Ruido.ods')

			
			#~ ######################################################################
			#~ #                       Comparativos Historicos
			
			#~ self.Fechai='2014-01-01 01:00'
			#~ self.Fechaf='%s-01-01 00:00' %dt.datetime.now().strftime('%Y')
			#~ self.Read_db(ValidadoSiata=True,filtro=True)
			#~ self.Read_db(Manual=True)
			#~ for var in self.nombre_contaminantes + ['PM2.5M','PM10M']:
				#~ self.var = var
				#~ self.Plot_Historico_Anual()
			
			#~ # Tablas de Frecuencia de Excedencias Historicas (media movil 24 h que supera la norma anual) para clasificación
			#~ years = ['2015','2016']
			#~ for year in years:
				#~ x = self.Contaminante[year].rolling(24,freq='1h').mean()[['PM10','PM2.5','SO2','NO2']]
				#~ x.apply(lambda x: x[x> self.norma['Y'][x.name[0]]].count()/float(x.count())*100).unstack(0).fillna(-9999).to_csv('Datos/Frecuencia_Excedencias-%s.csv' %year)

			#~ # Tablas de relacion porcentual entre marzo de 2016 y este mes en el 2015 y 2014
			
			#~ self.Contaminante.apply(lambda x: x['2016-03'].median()/x['2014-03'].median()*100).unstack(0).fillna(-9999).to_csv('Datos/Relacion_2016-03vs2014-03.csv')
			#~ self.Contaminante.apply(lambda x: x['2016-03'].median()/x['2015-03'].median()*100).unstack(0).fillna(-9999).to_csv('Datos/Relacion_2016-03vs2015-03.csv')

	def Informe_Mensual(self,*args,**kwargs):
		os.chdir('/home/calidadaire/ModuloAire/Informe_Mensual/')

		self.Correo				= kwargs.get('Correo',False)

		if kwargs.get('read',True):
			self.Read_db(filtro=kwargs.get('filtro',True),ValidadoSiata=True)
			self.Read_db(Meteorologicas=True,ValidadoSiata=True)
			self.Read_db(Manual=True)
			self.Calcula_ICA()

		self.date_monthly	= self.Contaminante.index[0].strftime('%B%Y')
		self.path			= os.getcwd()
		self.path_U			= self.path+'/Correo'

		if kwargs.get('Figuras',True):
			os.system('rm -rf Figuras/')
			os.system('mkdir Figuras/')

			#Lee Datos Meteorología
			os.system('mkdir Figuras/Meteorologia/')
			os.system('mkdir Figuras/PLiquida_SSR/')
			os.system('mkdir Figuras/Procuraduria/')
			os.system('mkdir Figuras/PM10M/')
			os.system('mkdir Figuras/PM25M/')
			self.Plot_Precipitacion()

			#Ciclos diurnos Temperatura, Humedad Relativa y Radiación Solar Global
			self.Plot_CD_HR_T_RG()

			#Lee datos Contaminantes
			#Ciclos Diurnos
			for var in self.nombre_contaminantes:
				self.var = var
				os.system('mkdir Figuras/%s/' %(var if var != 'PM2.5' else 'PM25'))
				self.Plot_CicloDiurno()
				if var not in ['NO','NOx']: self.Plot_Tabla_Resumen()

			#Excedencias, ICA, Histograma ICA
			for var in ['PM10','PM2.5','SO2','NO2']:
				self.var = var
				self.Plot_Imshow()
				if var=='PM2.5':
					self.Plot_Tabla_Resumen()
					self.Plot_Tabla_Resumen(Medellin = False)
				else:
					self.Plot_Tabla_Resumen()
				if var in ['PM10','PM2.5','SO2']:
					self.Plot_ICA()
					if var == 'PM2.5':
						self.Plot_ICA_Resumen(stacked=False)
						self.Plot_ICA_Resumen(stacked=False, Medellin = False)
					else:
						self.Plot_ICA_Resumen(stacked=False)
			for var in ['Ozono','CO']:
				self.var = var
				self.Plot_Tabla_Resumen()
				#~ #self.Plot_Imshow(resolucion='8h')
				self.Plot_ICA_Resumen(stacked=False,resolucion='8h')
			for var in ['Ozono','NO2']: #'CO'
				self.var = var
				self.Plot_ICA_Resumen(stacked=False,resolucion='1h')

			self.var = 'PM10M'
			self.Plot_Tabla_Resumen()

			#~ #Mapa
			self.Mapas()
			self.var='PM2.5'
			self.Plot_ICA(textsave='_'+self.date_monthly)

			#Rosas de Vientos
			self.Est['Latitud'][25]=self.Est['Latitud'][25]+0.004
			self.Est['Latitud'][12]=self.Est['Latitud'][12]-0.004
			self.Est['Longitud'][11]=self.Est['Longitud'][11]+0.007
			self.Est['Longitud'][3]=self.Est['Longitud'][3]-0.007

			self.Plot_WindRose_Map(S=self.Meteo['VViento_SSR'],D=self.Meteo['DViento_SSR'],textsave='_Total',Vaisala=False,spanish=True,add_Text='Total',path='CalidadAire/Figuras/Meteorologia/')
			self.Plot_WindRose_Map(S=self.Meteo['VViento_SSR'][(self.Meteo.index.hour >= 6) & (self.Meteo.index.hour < 18)],D=self.Meteo['DViento_SSR'][(self.Meteo.index.hour >= 6) & (self.Meteo.index.hour < 18)],textsave='_Diurno',Vaisala=False,spanish=True,add_Text='Diurno',path='CalidadAire/Figuras/Meteorologia/')
			self.Plot_WindRose_Map(S=self.Meteo['VViento_SSR'][(self.Meteo.index.hour < 6) | (self.Meteo.index.hour >= 18)],D=self.Meteo['DViento_SSR'][(self.Meteo.index.hour < 6) | (self.Meteo.index.hour >= 18)],textsave='_Nocturno',Vaisala=False,spanish=True,add_Text='Nocturno',path='CalidadAire/Figuras/Meteorologia/')

		if kwargs.get('Latex',True):
			os.system('rm -r Informes/Informe_%s' %self.date_monthly )
			os.system('mkdir Informes/Informe_%s' %self.date_monthly )

			print 'ln Informes/InformeMensualTru.py'
			os.system('ln -s /home/jhernandezv/Tools/InformeMensualTru.py /home/jhernandezv/RedAire/Informe_Mensual/Informes/Informe_%s/' %self.date_monthly)
			print 'cp -r Figuras/'
			os.system('cp -r Figuras/ Informes/Informe_%s/' %self.date_monthly)

			print 'cp -r /home/jhernandezv/Tools/Plantilla/ Informes/Descripcion_Red/'
			os.system('cp -r /home/jhernandezv/Tools/Plantilla/ /home/jhernandezv/Tools/Descripcion_Red/ Informes/Informe_%s/Figuras/' %self.date_monthly)
			print 'os.chdir'
			os.chdir(os.getcwd()+'/Informes/Informe_%s/' %self.date_monthly)
			print os.getcwd()
			print 'ipython InformeMensualTru.py'
			os.system('ipython InformeMensualTru.py "%s" "%s"' %(kwargs.get('Texto_Contaminante',''),kwargs.get('Texto_Meteorologia','')))
			print 'latex'

			os.system('rm *.py')
			os.system('pdflatex InformeMensual.tex')
			os.system('bibtex InformeMensual')
			os.system('pdflatex InformeMensual.tex')
			os.system('pdflatex InformeMensual.tex')
			os.system('scp InformeMensual.pdf jhernandezv@siata.gov.co:/var/www/CalidadAire/Informes_Operacion/F-GAA-RA-211_InformeOperacion_%s.pdf' %(self.date_monthly))
			os.chdir('/home/jhernandezv/RedAire/Informe_Mensual/')
			self.path		= os.getcwd()
			self.path_U		= self.path+'/Correo'

			os.system('rm Informes/Informe_%s/*.py' %self.date_monthly)
			os.system('rm Informes/Informe_%s/Air.pyc' %self.date_monthly)
			os.system('zip -r Informe_%s.zip Informes/Informe_%s/' %(self.date_monthly,self.date_monthly))
			os.system('mv Informe_%s.zip Informes/' %self.date_monthly)

			os.system('scp Informes/Informe_%s.zip jhernandezv@siata.gov.co:/var/www/CalidadAire/Informes_Operacion/' %self.date_monthly)

			if self.Correo: os.system("python %s/enviarCorreoElectronicoInformacion.py %s/mail.destino.informe.txt 'Informe Mensual' %s/mail.body.informe.html" %(self.path_U,self.path_U,self.path_U))

		if kwargs.get('Procuraduria',False): self.Informe_Procuraduria_Plots()

		if kwargs.get('read',True):
			self.Read_db(ValidadoSiata=True)

		#Datos Unal
		if kwargs.get('Unal',False):
			os.system('rm Datos/*')

			self.UnalDatos 				= self.Dica.stack(0).loc[self.idx[:,['PM2.5', 'NO', 'NO2', 'NOx', 'Ozono']],self.idx['MED-UNNV']].unstack(1)
			self.UnalDatos[['NO', 'NO2', 'NOx', 'Ozono']] = self.UnalDatos[['NO', 'NO2', 'NOx', 'Ozono']]*1000
			self.UnalDatos.index		= self.UnalDatos.index + dt.timedelta(hours=1)
			self.UnalDatos.index.name	='Fechas'
			self.UnalDatos 				= self.UnalDatos.reindex(pd.date_range(self.Fechai,self.Fechaf,freq='H')).fillna(-9999).to_csv('Datos/MED-UNNV_Contaminantes_%s.csv' %self.date_monthly)

			#~ Unal = self.Dica.stack(0).loc[self.idx[:,['PM10', 'NO', 'NO2', 'NOx']],self.idx['MED-UNFM']].unstack(1)
			#~ Unal.index.name='Fechas'
			#~ Unal[['NO', 'NO2', 'NOx']] = Unal[['NO', 'NO2', 'NOx']]*1000
			#~ Unal.index= Unal.index + dt.timedelta(hours=1)
			#~ Unal.reindex(pd.date_range(self.Fechai,self.Fechaf,freq='H')).fillna(-9999).to_csv('Datos/MED-UNFM_Contaminantes_%s.csv' %date_monthly)

			self.UnalDatos 				= self.Meteo.stack(0).loc[self.idx[:,:],self.idx['MED-UNNV']].unstack(1)
			self.UnalDatos.index.name	='Fechas'
			self.UnalDatos.reindex(pd.date_range(self.Fechai,self.Fechaf,freq='H')).fillna(-9999).to_csv('Datos/MED-UNNV_Meteorologia_%s.csv' %self.date_monthly)

			os.system('zip -r UNAL_Datos_%s.zip Datos' %(self.Contaminante.index[0].strftime('%B%Y')))
			os.system('mv UNAL_Datos_%s.zip Correo/' %(self.Contaminante.index[0].strftime('%B%Y')))

			#~ #Envia Correo
			if self.Correo: os.system("python %s/enviarCorreoElectronicoInformacion.py %s/mail.destino.unal.txt 'Datos de la Universidad Nacional' %s/mail.body.UNAL.html %s/UNAL_Datos_%s.zip" %(self.path_U,self.path_U,self.path_U,self.path_U,self.Contaminante.index[0].strftime('%B%Y')))

			#Diferentes Meses
			#~ os.system('zip -r UNAL_Datos_%s_a_%s.zip Datos' %(self.Contaminante.index[0].strftime('%B'),self.Contaminante.index[-1].strftime('%B-%Y')))
			#~ os.system('mv UNAL_Datos_%s_a_%s.zip Correo/' %(self.Contaminante.index[0].strftime('%B'),self.Contaminante.index[-1].strftime('%B-%Y')))

			#~ if Correo: os.system("python %s/enviarCorreoElectronicoInformacion.py %s/mail.destino.unal.txt 'Datos de la Universidad Nacional' %s/mail.body.UNAL.html %s/UNAL_Datos_%s_a_%s.zip" %(path_U,path_U,path_U,path_U,self.Contaminante.index[0].strftime('%B'),self.Contaminante.index[-1].strftime('%B-%Y')))

		#Datos SISAIRE
		if kwargs.get('Sisaire',False):
			os.system('rm Datos/*')
			for par in self.nombre_contaminantes:
				self.to_xls(parametros=[par],estaciones=self.Contaminante[par].columns.values,textsave=self.Contaminante.index[0].strftime('%Y-%m'))

			for par in self.nombre_meteorologicas:
				self.to_xls(parametros=[par],estaciones=self.Meteo[par].columns.values,textsave=self.Meteo.index[0].strftime('%Y-%m'))

			os.system('zip -r DatosValidados_%s.zip Datos' %(self.Contaminante.index[0].strftime('%B%Y')))
			#~ os.system('scp DatosValidados_%s.zip jhernandezv@siata.gov.co:/var/www/IDEAM/' %(self.Contaminante.index[0].strftime('%B%Y')))
			os.system('mv DatosValidados_%s.zip Correo/' %(self.Contaminante.index[0].strftime('%B%Y')))

			#~ #Envia Correo
			if self.Correo: os.system("python %s/enviarCorreoElectronicoInformacion.py %s/mail.destino.sisaire.txt 'Datos Validados Red de Calidad del Aire del Valle de Aburra' %s/mail.body.sisaire.html %s/DatosValidados_%s.zip" %(self.path_U,self.path_U,self.path_U,self.path_U,self.Contaminante.index[0].strftime('%B%Y')))

			#Diferentes Meses
			#~ os.system('zip -r DatosValidados_%s_a_%s.zip Datos' %(self.Contaminante.index[0].strftime('%B'),self.Contaminante.index[-1].strftime('%B-%Y')))
			#~ os.system('scp DatosValidados_%s_a_%s.zip jhernandezv@siata.gov.co:/var/www/IDEAM/' %(self.Contaminante.index[0].strftime('%B'),self.Contaminante.index[-1].strftime('%B-%Y')))
			#~ os.system('mv DatosValidados_%s_a_%s.zip Correo/' %(self.Contaminante.index[0].strftime('%B'),self.Contaminante.index[-1].strftime('%B-%Y')))

			#~ if Correo: os.system("python %s/enviarCorreoElectronicoInformacion.py %s/mail.destino.sisaire.txt 'Datos Validados Red de Calidad del Aire del Valle de Aburra' %s/mail.body.sisaire.html %s/DatosValidados_%s_a_%s.zip" %(path_U,path_U,path_U,path_U,self.Contaminante.index[0].strftime('%B'),self.Contaminante.index[-1].strftime('%B-%Y')))

		#~ for par in ['PM2.5', 'NO', 'NO2', 'NOx', 'Ozono']: self.to_xls(parametros=[par],estaciones=['MED-UNNV'],textsave=self.Contaminante.index[0].strftime('%Y-%m'))
		#~ for par in ['PM10', 'NO', 'NO2', 'NOx']:self.to_xls(parametros=[par],estaciones=['MED-UNFM'],textsave=self.Contaminante.index[0].strftime('%Y-%m'))
		#~ for par in self.nombre_meteorologicas:self.to_xls(parametros=[par],estaciones=['MED-UNNV'],textsave=self.Contaminante.index[0].strftime('%Y-%m'))

		if kwargs.get('AMVA',False):
			os.system('rm Datos/*')
			for var in self.Est[self.Est['Automatica']==1]['Nombre'].values:
				self.to_csv(var)

			for est in self.ContaminanteManual.columns.levels[1].values:
				self.x 				= self.ContaminanteManual.xs(est,axis=1,level=1).reindex(pd.date_range(self.Fechai,self.Fechaf,freq='D') - dt.timedelta(hours=1))
				self.x.columns 		= map(lambda x: '%s [%s]' %(x[:-1],self.unidadesC[x[:-1]]),self.x.columns.values)
				self.x.index.name 	= 'Fechas'
				self.x.to_csv('Datos/%s_Manual.csv' %est,na_rep=-9999)
			os.system('zip -r DatosValidados_%s.zip Datos' %(self.Contaminante.index[0].strftime('%Y-%m')))
			os.system('mv DatosValidados_%s.zip Correo/' %(self.Contaminante.index[0].strftime('%Y-%m')))

			#~ #Envia Correo
			if self.Correo: os.system("python %s/enviarCorreoElectronicoInformacion.py %s/mail.destino.AMVA.txt 'Datos Validados AMVA - UPB' %s/mail.body.AMVA.html %s/DatosValidados_%s.zip" %(self.path_U,self.path_U,self.path_U,self.path_U,self.Contaminante.index[0].strftime('%Y-%m')))

			#Diferentes Meses
			#~ os.system('zip -r DatosValidados_%s_a_%s.zip Datos' %(self.Contaminante.index[0].strftime('%m'),self.Contaminante.index[-1].strftime('%m_de_%Y')))
			#~ os.system('mv DatosValidados_%s_a_%s.zip Correo/' %(self.Contaminante.index[0].strftime('%m'),self.Contaminante.index[-1].strftime('%m_de_%Y')))

			#~ if Correo: os.system("python %s/enviarCorreoElectronicoInformacion.py %s/mail.destino.AMVA.txt 'Datos Validados AMVA - UPB' %s/mail.body.AMVA.html %s/DatosValidados_%s_a_%s.zip" %(path_U,path_U,path_U,path_U,self.Contaminante.index[0].strftime('%m'),self.Contaminante.index[-1].strftime('%m_de_%Y')))

	def Informe_Procuraduria_Plots(self,*args,**kwargs):
		"""Genera las consultas y las gráficas para el informe de la procuraduria
			mensual y las copia en calidadaire@mirror"""
		
		if kwargs.get('read',False):
			self.Read_db(filtro=True,ValidadoSiata=True)
			self.Read_db(Meteorologicas=True,ValidadoSiata=True)
			self.Read_db(Manual=True)
			self.Calcula_ICA()
			for var in self.nombre_contaminantes:
				self.var = var
				os.system('mkdir Figuras/%s/' %(var if var != 'PM2.5' else 'PM25'))
		os.system('mkdir Figuras/Procuraduria/')
		#Excedencias, ICA, Histograma ICA
		for var in ['PM10','PM2.5','SO2']:
			self.var = var
			self.Plot_ICA(Procuraduria=True)
			self.Plot_ICA_Resumen(stacked=False,Procuraduria=True)
			self.Plot_MMM(Procuraduria=True)
			self.Plot_Tabla_Resumen(Procuraduria=True)
			if var=='PM2.5':
				self.Plot_ICA(Procuraduria=True, Medellin = True)
				self.Plot_ICA(Procuraduria=True, Valle = True)
				self.Plot_ICA_Resumen(stacked=False,Procuraduria=True,Medellin=False)
				self.Plot_MMM(Procuraduria=True, Medellin = True)
				self.Plot_MMM(Procuraduria=True, Valle = True)
				self.Plot_Tabla_Resumen(Procuraduria=True, Medellin = False)
		self.var='NO2'
		self.Plot_MMM(Procuraduria=True)
		self.Plot_Tabla_Resumen(Procuraduria=True)
		for var in ['Ozono','CO']:
			self.var = var
			self.Plot_ICA_Resumen(stacked=False,resolucion='8h',Procuraduria=True)
			self.Plot_MMM(Procuraduria=True)
			self.Plot_Tabla_Resumen(Procuraduria=True)
		for var in ['Ozono','NO2']: #'CO'
			self.var = var
			self.Plot_ICA_Resumen(stacked=False,resolucion='1h',Procuraduria=True)
		
		for var in ['NO','NOx']:
			self.var=var
			self.Plot_MMM()
		
		self.var='PLiquida_SSR'
		self.Plot_Tabla_Resumen(Procuraduria=True)
		
		self.var = 'PM10M'
		self.Plot_Tabla_Resumen(Procuraduria=True)
			
		
		#Lee Datos bd Valida Siata
		self.Fechai_backup = self.Fechai
		self.Fechai		=	dt.datetime.strptime(self.Fechai, '%Y-%m-%d %H:%M').strftime('%Y-01-01 01:00')
		self.Read_db(ValidadoSiata=True,filtro=True)
				
		#Consulta valores promedio mensuales
		for var in self.Contaminante.columns.levels[0].values:
			self.var=var
			print var
			self.Plot_Promedio_Mensual(Procuraduria=True)

		self.Fechai = self.Fechai_backup

		if kwargs.get('Correo',False): 
			os.system("ssh calidadaire@192.168.1.10 'cd /home/calidadaire/Informe_Procuraduria && ./Informe_Procuraduria.sh'")
			os.system('scp calidadaire@192.168.1.10:/home/calidadaire/Informe_Procuraduria/Informe_Procuraduria.pdf Correo/Informe_Procuraduria_%s' %self.Contaminante.index[0].strftime('%B%Y'))
			self.path=os.getcwd()
			self.path_U=path+'/Correo'
			os.system("python %s/enviarCorreoElectronicoInformacion.py %s/mail.destino.informe.txt 'Informe Mensual Procuraduria' %s/mail.body.informe.html %s/Informe_Procuraduria_%s.pdf" %(self.path_U,self.path_U,self.path_U,self.path_U,self.Contaminante.index[0].strftime('%B%Y'),self.Contaminante.index[0].strftime('%B%Y')))

	def Read_DEM(self,*args,**kwargs):

		self.DataSet			= gdal.Open(kwargs.get('path','/home/calidadaire/ModuloAire/Tools/DemAM.tif'))
		self.GeoTransform		= self.DataSet.GetGeoTransform()
		self.DEM = pd.DataFrame(self.DataSet.ReadAsArray(),columns=np.array([self.GeoTransform[0]+0.5*self.GeoTransform[1]+i*self.GeoTransform[1] for i in range(self.DataSet.RasterXSize)]),index=np.array([self.GeoTransform[3]+0.5*self.GeoTransform[-1]+i*self.GeoTransform[-1] for i in range(self.DataSet.RasterYSize)]))
		self.DEM[self.DEM==-9999]= np.NaN
		self.DEM[self.DEM<0]= np.NaN
		if kwargs.get('ajustar',False): self.DEM = self.DEM.dropna(how='all').dropna(how='all',axis=1)

	def Imshow(self):

		for var in ['PM10','PM2.5','SO2','NO2']:
			self.var = var
			self.Plot_Imshow()
			if var in ['PM10','PM2.5','SO2']:
				self.Plot_ICA()
				self.Plot_ICA_Hist()
		for var in ['Ozono','CO']:
			self.var = var
			self.Plot_Imshow(resolucion='8h')
			self.Plot_ICA_Hist(resolucion='8h')
		for var in ['Ozono','NO2']: #'CO'
			self.var = var
			self.Plot_ICA_Hist(resolucion='1h')

	def Mapas(self):
		""" Genera los mapas con la localizacion de las estaciones en el Valle de Aburra
			para cada uno de los contaminantes de la Red, otro para las estaciones 
			meteorologicas y para las manuales"""

		self.Est['Latitud'][46]=self.Est['Latitud'][46]-0.009
		self.Est['Longitud'][11]=self.Est['Longitud'][11]+0.0045
		for var in self.nombre_contaminantes + ['P_SSR','PM2.5M','PM10M']:
			print '#############################################'
			print '            Mapa %s               ' %var
			print '#############################################'
			self.var = var
			self.Plot_Mapa3()

	def Plot_Barbs(self, *args,**kwargs):#ht,CDU,CDV,ADV,title,CDW,date,save,lines): 

		'daily_cycle 	= Compute daily cicle from dataframe self.RWP'
		'height 		= Define the highest level of profile winds bar chart'
		self.fontsize		= kwargs.get('fontsize',16)

		if 'monthly' not in kwargs.keys():
			if kwargs.get('daily_cycle',False): 
				self.df  			= kwargs.get('df',self.RWP).groupby(lambda x: x.hour).mean() 
			else:
				self.df  			= kwargs.get('df',self.RWP)
			self.u 			= self.df['U'].T.values #loc[idx[:],idx['U','U']].T.values 
			self.v			= self.df['V'].T.values #.loc[idx[:],idx[:,'V']].T.values
			self.w 			= self.df['W'].T.values #.loc[idx[:],idx[:,'W']].T.values
			self.adv		= (self.u**2+self.v**2)**0.5

		if 'ax' not in kwargs.keys():
			plt.close('all')
			self.fig 		= plt.figure(figsize=(15,8.5),facecolor=(.7,.7,.7))
			self.ax			= self.fig.add_axes((0.125,0.11,0.775,.77)) #self.fig.add_subplot(111)
			if kwargs.get('Barbas',True): 		self.ax1		= self.fig.add_axes((0.265,-0.005,0.5,0.025))
			if kwargs.get('Conveccion',True):	self.ax2		= self.fig.add_axes((0.915,.2,0.02,0.59))

			self.ax.spines['top'].set_visible(False)
			self.ax.spines['right'].set_visible(False)
			self.ax.spines['left'].set_color((0.45, 0.45, 0.45))
			self.ax.spines['bottom'].set_color((0.45, 0.45, 0.45))
			self.ax.tick_params(top='off', right='off',bottom='on',left='on',which='both',color=(0.45, 0.45, 0.45),labelsize=self.fontsize)
			self.ax.xaxis.label.set_color((0.45, 0.45, 0.45))
			self.ax.yaxis.label.set_color((0.45, 0.45, 0.45))
		else:
			self.ax 		= kwargs['ax']

		#~ if 'daily_cycle' not in kwargs.keys(): 
		self.ax.patch.set_facecolor((.75,.75,.75))
		self.divider 	= make_axes_locatable(self.ax)

		self.height		= np.abs(self.ht-kwargs.get('height',8000)).argmin() 
		self.i 			= self.height / 50 + 1
		self.j			= self.u.shape[1]/ 80 + 1
		self.X,self.Y	= np.meshgrid(np.arange(0,self.u[0,::+self.j].shape[0]),self.ht[:self.height][::+self.i])

		if kwargs.get('Conveccion',True): 
			self.custom_cmap = [[ 0.4275,  0.0078,  0.1255], [ 0.6745,  0.0863,  0.1647], [ 0.8   ,  0.298 ,  0.2667], [ 0.8824,  0.4706,  0.3765],  [ 0.949 ,  0.6314,  0.498 ], [ 0.9686,  0.9686,  0.9686],  [ 0.5529,  0.7608,  0.8627],  [ 0.3725,  0.6471,  0.8039], [ 0.2275,  0.5294,  0.7412], [ 0.1176,  0.3804,  0.6471], [ 0.0275,  0.2039,  0.4039]] # [ 1.,  0.5765,  0.4549], n, [ 0.9608,  0.6745,  0.5451],medio,[ 0.6078,  0.7882,  0.8784], n,[ 0.4941,  0.7216,  0.8431]

			self.cf		= self.ax.contourf(self.X,self.Y,self.w[:self.height][::+self.i,::+self.j], cmap = clr.LinearSegmentedColormap.from_list('custom96',self.custom_cmap if  kwargs.get('custom_cmap',True) else self.custom_cmap[6:])  ,levels=np.linspace(kwargs.get('wlim',[-1.5,1.5])[0],kwargs.get('wlim',[-1.5,1.5])[1],40 if  kwargs.get('custom_cmap',True) else 20),alpha=1,extend='both' if kwargs.get('custom_cmap',True) else 'neither')
			self.cf.cmap.set_over([ 0.02745098,  0.20392157,  0.40392157]  )
			self.cf.cmap.set_under([ 0.42745098,  0.00784314,  0.1254902 ])

			if ('ax' not in kwargs.keys()) | (kwargs.get('add_colorbar',False)): 
				self.cbar1=plt.colorbar(self.cf,cax=self.divider.append_axes("right", size="2%", pad='1%') if 'ax' in kwargs.keys() else self.ax2,format='%.2f')
				self.cbar1.set_label(r"$\omega\ [m/s]$", fontsize=self.fontsize,color=(0.45, 0.45, 0.45))
				self.cbar1.ax.tick_params(labelsize=self.fontsize,color=(0.45, 0.45, 0.45))
				self.cbar1.set_ticks(np.arange(kwargs.get('wlim',[-1.5,1.5])[0],kwargs.get('wlim',[-1.5,1.5])[1]*1.005,.5 if  kwargs.get('custom_cmap',True) else .3))

		if kwargs.get('Barbas',True):
			self.img		= self.ax.barbs(self.X, self.Y, self.u[:self.height][::+self.i,::+self.j], self.v[:self.height][::+self.i,::+self.j], self.adv[:self.height][::+self.i,::+self.j], cmap = mpl.cm.gist_earth if kwargs.get('Daltonic',False) else  clr.LinearSegmentedColormap.from_list('custom69',[(.0,.0,.0),[ 0.0706,  0.302 ,  0.4863],[ 0.    ,  0.5529,  0.4431],[ 0.251 ,  0.6588,  0.2902],[ 0.6471,  0.7255,  0.3451],[ 0.7882,  0.8314,  0.2039]] ) , length=5,norm=mpl.colors.Normalize(kwargs.get('advlim',[0,12])[0],kwargs.get('advlim',[0,12])[1]) ,fill_empty=True, rounding=True, sizes=dict(emptybarb=0.2, spacing=0.0, height=0.3) ,barb_increments={'half':0.514444,'full':1.02889,'flag':244.3611}) 

			self.img.cmap.set_over([ 0.7882,  0.8314,  0.2039])
			self.img.set_clim(kwargs.get('advlim',[0,12])[0],kwargs.get('advlim',[0,12])[1])

			if ('ax' not in kwargs.keys()) | (kwargs.get('add_colorbar',False)): 
				self.cbar2		= plt.colorbar(self.img,cax= self.divider.append_axes("bottom", size="3%", pad='12%') if 'ax' in kwargs.keys() else self.ax1, orientation='horizontal',extend='max' if  kwargs.get('custom_cmap',True) else 'neither')
				self.cbar2.set_label(r"Wind Speed $[m/s]$", fontsize=self.fontsize,color=(0.45, 0.45, 0.45))
				self.cbar2.ax.tick_params(labelsize=self.fontsize,color=(0.45, 0.45, 0.45))
		self.ax.set_xlim(-0.2,self.X.shape[1]-.5) #self.X.shape[0] 
		self.ax.set_ylim(0,self.ht[self.height]*1.001)
		self.ax.set_yticklabels(np.round((self.ax.get_yticks()+1500)/1000,decimals=1))
		self.ax.set_ylabel(r'Heigth $[km]$', fontsize=self.fontsize)

		if 'add_text' in kwargs.keys():
			self.ax.text(0,-self.ht[self.height]*.1,kwargs['add_text'],ha='center',va='center',color=(0.45, 0.45, 0.45),fontsize=self.fontsize,weight='bold')

		if kwargs.get('daily_cycle',False):
			self.ax.set_xticks(np.arange(0,24,2))
			self.ax.set_xlabel(r'Hour $[UTC-5]$', fontsize=self.fontsize)
		else:
			self.ticks = np.round(self.ax.get_xticks(),decimals=0)
			self.ax.set_xticklabels([self.df.index[::+self.j][int(k)].strftime('%H:%M \n%b-%d') for k in self.ticks[ (self.ticks<self.df.index[::+self.j].size)]]) 

		plt.savefig('Figuras/Barbs%s.%s' %(kwargs.get('textsave',''),kwargs.get('format','pdf')),bbox_inches="tight")
		if kwargs.get('scp',True): os.system("scp Figuras/Barbs%s.%s jhernandezv@siata.gov.co:/var/www/%s" %(kwargs.get('textsave',''),kwargs.get('format','pdf'),kwargs.get('path','jhernandezv/Winds/RWP/') ))

	def Plot_Barbs_MonthlyDC(self,*args,**kwargs):

		locale.setlocale(locale.LC_TIME, ('en_us','utf-8'))
		os.system('rm Figuras/*')

		self.df = kwargs.get('df',self.RWP)
		for i in range(1,13):
			print 'Making Barbs on',self.df[self.df.index.month==i].index[0].strftime('%B')
			self.u = self.df[self.df.index.month==i].groupby(lambda x: x.hour).mean()['U'].T.values 
			self.v = self.df[self.df.index.month==i].groupby(lambda x: x.hour).mean()['V'].T.values
			self.w = self.df[self.df.index.month==i].groupby(lambda x: x.hour).mean()['W'].T.values
			self.adv = (self.u**2+self.v**2)**0.5
			self.Plot_Barbs(textsave = self.df[self.df.index.month==i].index[0].strftime('_%m'),add_text=self.df[self.df.index.month==i].index[0].strftime('%B'), daily_cycle =True, monthly = True,height=kwargs.get('height',8000),scp=kwargs.get('scp',True))
		os.system('pdftk Figuras/Barbs_* cat output Figuras/Barbs_Monthly.pdf' )
		os.system('convert -delay 100 Figuras/Barbs_Monthly.pdf Figuras/Barbs_Monthly%s.gif' %kwargs.get('textsave','') )
		os.system('scp Figuras/Barbs_Monthly%s.gif jhernandezv@siata.gov.co:/var/www/%s' %(kwargs.get('textsave',''),kwargs.get('path','jhernandezv/Winds/RWP/')) )

		locale.setlocale(locale.LC_TIME, ('es_co','utf-8'))

	def Plot_Tabla_Resumen(self,*args,**kwargs):

		self.Procuraduria		= kwargs.get('Procuraduria',False)
		self.Medellin			= kwargs.get('Medellin',True)
		self.textsave			= kwargs.get('textsave',None)
		self.ExcedenciaDiaria	= kwargs.get('ExcedenciaDiaria',False)
		self.est_pm25Med		= ['MED-ARAN', 'MED-VILL', 'MED-SCRI', 'MED-UNNV', 'CEN-TRAF', 'MED-BEME', 'MED-ALTA', 'MED-PJIC(M)', 'MED-TESO', 'MED-LAYE']
 		self.est_pm25 			= ['BAR-TORR', 'GIR-SOSN', 'COP-CVID', 'BEL-FEVE', 'BEL-SESB(M)', 'ITA-CJUS', 'ENV-HOSP', 'ITA-CONC', 'SAB-JOFE', 'SUR-TRAF','EST-HOSP', 'CAL-LASA']
#Esta no se	self.est_pm25 			= ['BAR-TORR', 'GIR-SOSN', 'COP-CVID','BEL-SESB(M)', 'ITA-CJUS', 'ITA-CONC', 'SUR-TRAF','EST-HOSP', 'CAL-LASA']
		self.varsave			= self.var if self.var!='PM2.5' else 'PM25'
		if self.Medellin and (self.var=='PM2.5'):	self.varsave = self.varsave + 'Med'

		self.resol='D'
		self.how =	'sum' if self.var == 'PLiquida_SSR' else 'mean'
		self.runPV=True

		if self.var in ['PM10','PM2.5', 'SO2','NO2','PM10M']:
			self.C				= self.ContaminanteManual[self.var].resample('3D').mean()  if self.var=='PM10M' else self.Contaminante[self.var].resample(self.resol).mean() 
			self.Tabla			= pd.concat({'MAX':self.C.max(),'MEDIA':self.C.mean(),'MIN':self.C.min(),'CMD':self.C.count()},axis=1)
			self.Tabla['NEND']	= self.C[self.C > self.norma[self.resol][self.var]].count()

			if self.var in ['PM2.5']:
				self.C				= self.ContaminanteManual[self.var+'M'].resample(self.resol).mean()
				self.tt				= pd.concat({'MAX':self.C.max(),'MEDIA':self.C.mean(),'MIN':self.C.min(),'CMD':self.C.count()},axis=1)
				self.tt['NEND']		= self.C[self.C > self.norma[self.resol][self.var]].count()
				self.tt.index 		= map(lambda x: '%s(M)' %x,self.tt.index.values)
				self.Tabla 		= self.Tabla.append(self.tt)
				self.Tabla		= self.Tabla.loc[self.est_pm25Med] if self.Medellin else self.Tabla.loc[self.est_pm25]

			if self.var =='NO2':
				self.res='1h'
				self.Tabla['NEN1H'] = self.Contaminante[self.var][self.Contaminante[self.var] > self.norma[self.res][self.var]].count()

		elif self.var in ['Ozono','CO']:
			self.res			='1h'
			self.C 				= self.Contaminante[self.var]
			self.Tabla			= pd.DataFrame(self.C.max(),columns=['VM1H'])
			self.Tabla['NEN1H'] = self.C[self.C > self.norma[self.res][self.var]].count()

			self.res				='8h'
			self.C 					= self.Contaminante[self.var].rolling(8,freq='1h').mean()
			self.Tabla['VM8H'] 		= self.C.max()
			self.Tabla['NEN8H'] 	= self.C[self.C > self.norma[self.res][self.var]].count()

		elif self.var =='PLiquida_SSR':
			self.Tabla=pd.DataFrame(self.Meteo['PLiquida_SSR'].sum(),columns=['Mensual' if self.Meteo['PLiquida_SSR'].index.size >25 else 'Diaria'])
			self.runPV=False

		self.nodecimal=['CMD','NEND','NEN1H','NEN8H']
		self.Tabla = self.Tabla.T

		if self.var =='PM2.5':
			self.estaciones		= self.est_pm25Med if self.Medellin else self.est_pm25 
			self.dif			= list(set(self.est_pm25Med if self.Medellin else self.est_pm25) - set(self.Tabla.columns.values))
			for i in range(len( self.dif )): 
				self.Tabla[self.dif[i]] = np.NaN

		elif self.var =='PM10M':
			self.estaciones 		= self.Est[self.Est['Nombre'].isin( self.Tabla.columns.values)].sort_values(by='Latitud',ascending=False)['Nombre'].values
			self.Tabla.columns		= map(lambda x: '%s(M)' %x,self.Tabla.columns.values)
			self.estaciones			= map(lambda x: '%s(M)' %x,self.estaciones)
		else:
			self.estaciones = self.Est[self.Est['Nombre'].isin( self.Tabla.columns.values)].sort_values(by='Latitud',ascending=False)['Nombre'].values

		#--------------------------------------------------------------------------------
		#
		self.T = []

		self.styleSheet = getSampleStyleSheet()
		for i in range(self.Tabla.index.size):
			if i ==0: self.T.append(['']+map(lambda x: Paragraph('<para align=center><b><font color=white>'+x[:4]+'\n'+x[4:],self.styleSheet["BodyText"]),self.estaciones))
			self.T.append([self.Tabla.index[i]]+map(lambda x: ('%.f' %x if self.Tabla.index[i] in self.nodecimal else '%.1f' %x)  if np.isfinite(x) else 'NP', self.Tabla[self.estaciones].iloc[i].values))

		self.doc = SimpleDocTemplate('Figuras/Procuraduria/Resumen%s.pdf' %self.varsave,pagesize=(50*(self.Tabla.columns.size+1)+32,20*(self.Tabla.index.size+2)+20), rightMargin = 10, bottomMargin= 10, topMargin=10, leftMargin=10) #

		self.t = Table(self.T ,[50])
		self.Tstyle=[('INNERGRID', (0,0), (-1,-1), 0.9, colors.grey),('GRID',(0,1),(-1,-1),0.9,colors.grey), ('GRID',(0,0),(-1,0),0.9,colors.white), 
			('TEXTCOLOR',(1,0),(-1,0),colors.white),('VALIGN',(0,0),(-1,-1),'MIDDLE'),
			('ALIGN',(1,0),(-1,-1),'CENTER'),('BACKGROUND',(0,0),(-1,0),colors.Color(0.32,  0.71,  0.77))]

		#~ if var == 'PM10': 	Tstyle.extend([('BACKGROUND', (1, 1), (1, -1), colors.Color(0.95,0.95,0.95)), ('BACKGROUND', (3, 1), (3, -1), colors.Color(0.95,0.95,0.95)), ('BACKGROUND', (7, 1), (7, -1), colors.Color(0.95,0.95,0.95)), ('BACKGROUND', (9, 1), (9, -1), colors.Color(0.95,0.95,0.95)), ('BACKGROUND', (11, 1), (12, -1), colors.Color(0.95,0.95,0.95)),	('BACKGROUND', (14, 1), (14, -1), colors.Color(0.95,0.95,0.95)), ('BACKGROUND', (16, 1), (17, -1), colors.Color(0.95,0.95,0.95)), ('BACKGROUND', (19, 1), (19, -1), colors.Color(0.95,0.95,0.95))])

		if self.var == 'PM10M': 	self.Tstyle.extend([('BACKGROUND', (1, 1), (-1, -1), colors.Color(0.95,0.95,0.95))])
		elif (self.var == 'PM2.5') and self.Medellin: 	self.Tstyle.extend([('BACKGROUND', (8, 1), (8, -1), colors.Color(0.95,0.95,0.95))])
		elif (self.var == 'PM2.5') and (self.Medellin==False): 	self.Tstyle.extend([('BACKGROUND', (5, 1), (5, -1), colors.Color(0.95,0.95,0.95))])

		#~ wh=np.where(Tabla.isnull())
		#~ for i in range(wh[0].size):
			#~ Tstyle.append(('BACKGROUND', (wh[1][i]+1, wh[0][i]+1), (wh[1][i]+1, wh[0][i]+1), colors.Color(0.95,0.95,0.95)))

		self.t.setStyle(TableStyle(self.Tstyle))
		self.PDF=[]
		self.PDF.append(self.t)
		self.doc.build(self.PDF)

		#--------------------------------------------------------------------------------------------------------------------------------------
		#Porcentaje Validado
		if self.runPV:
			if self.var == 'PM10M':
				self.Tabla			= pd.DataFrame(self.C.count()/self.C.index.size*100,columns=['Validos [%]'])
				self.Tabla.index	= map(lambda x: '%s(M)' %x,self.Tabla.index.values)
			else:
				self.Tabla 			= pd.DataFrame(self.Contaminante[self.var].count()/pd.date_range(self.Fechai,self.Fechaf,freq='H').size *100,columns=['Validos [%]'])

			if self.var =='PM2.5':
				if 'MED-PJIC(M)' not in self.dif:
					self.C 				= self.ContaminanteManual[self.var+'M'].resample('3D').mean().drop('MED-PJIC',axis=1)
					self.CC 			= self.ContaminanteManual[self.var+'M'].resample('D').mean()['MED-PJIC']
					self.Tabla			= self.Tabla.append(pd.DataFrame(self.CC.count()/float(self.CC.index.size)*100,columns=['Validos [%]'],index=['MED-PJIC(M)']))
				else:
					self.C 				= self.ContaminanteManual[self.var+'M'].resample('3D').mean()
				self.tt				= pd.DataFrame(self.C.count()/self.C.index.size*100,columns=['Validos [%]'])
				self.tt.index 		= map(lambda x: '%s(M)' %x,self.tt.index.values)
				self.Tabla 		= self.Tabla.append(self.tt)
				self.Tabla		= self.Tabla.loc[self.est_pm25Med] if self.Medellin else self.Tabla.loc[self.est_pm25]
			self.Tabla = self.Tabla.T

			if self.var == 'PM2.5':
				self.dif			= list(set(self.est_pm25Med if self.Medellin else self.est_pm25) - set(self.Tabla.columns.values))
				for i in range(len( self.dif )):
					self.Tabla[self.dif[i]] = np.NaN

			self.T = []

			self.styleSheet = getSampleStyleSheet()
			for i in range(self.Tabla.index.size):
				print i
				if i ==0: self.T.append(['']+map(lambda x: Paragraph('<para align=center><b><font color=white>%s-\n%s'%(x[:3],x[4:]),self.styleSheet["BodyText"]),self.estaciones))
				self.T.append([self.Tabla.index[i]]+map(lambda x: '%.1f' %x   if np.isfinite(x) else 'NP', self.Tabla[self.estaciones].iloc[i].values))

			self.doc = SimpleDocTemplate('Figuras/Procuraduria/validos_%s.pdf' %self.varsave,pagesize=(50*(self.Tabla.columns.size+1)+32,20*(self.Tabla.index.size+2)+20), rightMargin = 10, bottomMargin= 10, topMargin=10, leftMargin=10) #

			self.t = Table(self.T ,[62,50])
			self.Tstyle=[('INNERGRID', (0,0), (-1,-1), 0.9, colors.grey),('GRID',(0,1),(-1,-1),0.9,colors.grey), ('GRID',(0,0),(-1,0),0.9,colors.white), 
				('TEXTCOLOR',(1,0),(-1,0),colors.white),('VALIGN',(0,0),(-1,-1),'MIDDLE'),
				('ALIGN',(1,0),(-1,-1),'CENTER'),('BACKGROUND',(0,0),(-1,0),colors.Color(0.32,  0.71,  0.77))]
			#~ if var == 'PM10': 	Tstyle.extend([('BACKGROUND', (1, 1), (1, -1), colors.Color(0.95,0.95,0.95)), ('BACKGROUND', (3, 1), (3, -1), colors.Color(0.95,0.95,0.95)), ('BACKGROUND', (7, 1), (7, -1), colors.Color(0.95,0.95,0.95)), ('BACKGROUND', (9, 1), (9, -1), colors.Color(0.95,0.95,0.95)), ('BACKGROUND', (11, 1), (12, -1), colors.Color(0.95,0.95,0.95)),	('BACKGROUND', (14, 1), (14, -1), colors.Color(0.95,0.95,0.95)), ('BACKGROUND', (16, 1), (17, -1), colors.Color(0.95,0.95,0.95)), ('BACKGROUND', (19, 1), (19, -1), colors.Color(0.95,0.95,0.95))])
			if self.var == 'PM10M': self.Tstyle.extend([('BACKGROUND', (1, 1), (-1, -1), colors.Color(0.95,0.95,0.95))])

			elif (self.var == 'PM2.5') and self.Medellin:	self.Tstyle.extend([('BACKGROUND', (8, 1), (8, -1), colors.Color(0.95,0.95,0.95))])
			elif (self.var == 'PM2.5') and (self.Medellin==False):	self.Tstyle.extend([('BACKGROUND', (5, 1), (5, -1), colors.Color(0.95,0.95,0.95))])

			#~ wh=np.where(Tabla.isnull())
			#~ for i in range(wh[0].size):
				#~ Tstyle.append(('BACKGROUND', (wh[1][i]+1, wh[0][i]+1), (wh[1][i]+1, wh[0][i]+1), colors.Color(0.95,0.95,0.95)))

			self.t.setStyle(TableStyle(self.Tstyle))
			self.PDF			=[]
			self.PDF.append(self.t)
			self.doc.build(self.PDF)
			if type(self.textsave)==type(None): os.system('scp Figuras/Procuraduria/validos_%s.pdf nroldan@siata.gov.co:/var/www/CalidadAire/Figuras//Procuraduria/' %self.varsave)

			else: os.system('scp Figuras/Procuraduria/validos_%s.pdf nroldan@siata.gov.co:/var/www/CalidadAire/Figuras/Procuraduria/validos_%s-%s.pdf' %(self.varsave,self.varsave,self.textsave))

		if type(self.textsave)==type(None): os.system('scp Figuras/Procuraduria/Resumen%s.pdf nroldan@siata.gov.co:/var/www/CalidadAire/Figuras/Procuraduria/' %self.varsave)
		else: os.system('scp Figuras/Procuraduria/Resumen%s.pdf nroldan@siata.gov.co:/var/www/CalidadAire/Figuras/Procuraduria/Resumen%s-%s.pdf' %(self.varsave,self.varsave,self.textsave))

		if self.Procuraduria:
			os.system('scp Figuras/Procuraduria/Resumen%s.pdf calidadaire@192.168.1.10:Informe_Procuraduria/Tablas_Resumen/' %self.varsave)
			if self.runPV: os.system('scp Figuras/Procuraduria/validos_%s.pdf calidadaire@192.168.1.10:Informe_Procuraduria/Tablas_Resumen/' %self.varsave)

		if self.ExcedenciaDiaria:
			os.system('scp Figuras/Procuraduria/Resumen%s.pdf calidadaire@192.168.1.10:Excedencias_Diarias/Resumen%s-Diaria.pdf' %(self.varsave,self.varsave))

	def Plot_Promedio_Mensual(self,*args,**kwargs):
		"""Genera un plot de barras donde cada mes contiene el promedio de
		de la variable con sus respectivas estaciones seleccionadas"""
		
		self.df					= kwargs.get('df',None)
		self.Procuraduria		= kwargs.get('Procuraduria',False)
		self.norma_PM			= kwargs.get('norma',False)
		self.fontsize			= kwargs.get('fontsize',12)
		self.path				= kwargs.get('path','nroldan@siata.gov.co:/var/www/CalidadAire/Figuras/')
		#~ color				= kwargs.get('color',[[0.398,0.758,0.6445],[0.9765,0.5508,0.3828],[0.5508,0.621,0.789],[0.8984,0.539,0.762],[0.648,0.844,0.324],[1.,0.844,0.183],[0.89,0.762,0.578],[0.699,0.699,0.699],[0.726,0.609,0.7695],[0.988,0.664,0.387],[0.387,0.691,0.734],[0.996,0.988,0.668],[0.398,0.758,0.6445]]*2)
		
		#self.color				= kwargs.get('color',[[0.9726,0.898,0.223],[0.781,0.816,0.363 ],[ 0.5429, 0.73, 0.453],[ 0.152, 0.644,0.515 ],[ 0.121, 0.449, 0.453],[ 0.32, 0.714, 0.765],[ 0.2148,  0.48, 0.578],[ 0.922,  0.3867, 0.105],[ 0.96, 0.242, 0.062],[ 0.32, 0.28, 0.398]]*2)
		self.color				= kwargs.get('color',[[244./255,118./255,118./255],[198./255,46./255,46./255],[165./255,60./255,115./255],[168./255,59./255,155./255],[153./255,58./255,170./255],[114./255,58./255,173./255],[79./255,56./255,175./255],[58./255,83./255,175./255],[55./255,112./255,181./255],[53./255,140./255,183./255],[53./255,179./255,186./255],[53./255,183./255,146./255],[55./255,181./255,87./255],[56./255,178./255,61./255],[100./255,175./255,56./255],[137./255,173./255,58./255],[170./255,161./255,58./255],[168./255,124./255,59./255],[165./255,60./255,60./255],[102./255,50./255,50./255],[63./255,36./255,36./255]]*2)
		
		
		#self.espacios = {'BAR-PDLA':5,'GIR-SOSN':6,'GIR-IECO':7,'BEL-USBV':6,'MED-UNFM':4,'MED-UNNV':4,'MED-MANT':4,'MED-UDEM':4,'MED-MIRA':5,'MED-EXSA':5,'ITA-CJUS':8,'MED-PJIC':7,'MED-LAYE':5,'ITA-CONC':6, 'ITA-CRSV':7,'EST-METR':6, 'CAL-LASA':6, 'CAL-PMER':6}
		self.espacios = {'BAR-PDLA':5,'GIR-SOSN':6,'GIR-IECO':7,'BEL-USBV':6,'MED-ITMR':4,'MED-UNNV':4,'CEN-TRAF':4,'MED-UDEM':4,'MED-MIRA':5,'MED-EXSA':5,'ITA-CJUS':8,'MED-PJIC':7,'MED-LAYE':5,'ITA-CONC':6, 'ITA-CRSV':7,'SUR-TRAF':6, 'CAL-LASA':6, 'CAL-JOAR':6}
		
		self.resol ='m'
		if type(self.df)== type(None):
			self.df 		= self.Contaminante[self.var] if self.var in self.nombre_contaminantes else self.Meteo[self.var]
			
		if self.var=='PLiquida_SSR':
			self.df=self.df.groupby([lambda x: x.year,lambda x: x.month]).sum()
		else: 
			self.df=self.df.groupby([lambda x: x.year,lambda x: x.month]).mean()

		
		self.ylim 		= (10,30) if self.var == 'SO2' else kwargs.get('ylim',(self.df.min().min()-(self.df.max().max()-self.df.min().min())*.05,self.df.max().max()+(self.df.max().max()-self.df.min().min())*.05))#self.limC[self.resol][var]) 
		
		plt.close('all')
		self.fig 	= plt.figure(figsize=(9.5,3),facecolor='w',edgecolor='w')
		self.ax		= self.fig.add_subplot(111)
		self.ax.spines['top'].set_visible(False)
		self.ax.spines['right'].set_visible(False)
		self.ax.spines['left'].set_color((0.45, 0.45, 0.45))
		self.ax.spines['bottom'].set_color((0.45, 0.45, 0.45))
		self.ax.tick_params(top='off', right='off',bottom='on',left='on',which='both',color=(0.45, 0.45, 0.45),labelsize=self.fontsize)
		self.ax.xaxis.label.set_color((0.45, 0.45, 0.45))
		self.ax.yaxis.label.set_color((0.45, 0.45, 0.45))
		
		self.estaciones = self.Est[self.Est['Nombre'].isin( self.df.columns.values)].sort_values(by='Latitud',ascending=False)['Nombre'].values
		
		if self.norma_PM:
			self.values=self.df[self.estaciones]
			self.values.columns = map(lambda x: '%s%s%.1f' %(x,' '*self.espacios[x],self.Contaminante[self.var][self.estaciones].mean()[x]),self.values.columns.values ) #'-'*espacios[x]
			self.values.plot(kind='bar',ax=self.ax,width=0.8,color=self.color[:self.df.columns.size],lw=0.05,edgecolor='w',ylim=self.ylim) 
			self.leg = self.ax.legend(bbox_to_anchor=(1.01,.5),loc='center left',fontsize=self.fontsize-2,ncol=1,title='Promedio Anual')
			self.leg.get_frame().set_edgecolor((0.45, 0.45, 0.45))
			try: self.ax.set_title('Norma Anual Colombiana %s (%d $\mu g/m^{3}$)' %(self.var,self.norma['Y'][self.var]),loc='right',weight='heavy',fontsize=self.fontsize)
			except:pass
		else:
			self.df[self.estaciones].plot(kind='bar',ax=self.ax,width=0.8,color=self.color[:self.df.columns.size],lw=0.05,edgecolor='w',ylim=self.ylim) 
			self.leg = self.ax.legend(bbox_to_anchor=(.47,-.17),loc='upper center',fontsize=self.fontsize-2,ncol=(5 if self.estaciones.size <= 5 else self.estaciones.size/2 + self.estaciones.size%2 if self.estaciones.size <= 15 else 6))
			self.leg.get_frame().set_edgecolor((0.45, 0.45, 0.45))
		
		for text in self.leg.get_texts(): plt.setp(text, color = (0.45, 0.45, 0.45))
		self.ax.yaxis.grid(True,alpha=.4,zorder=1,ls='--')
		

		self.xticks,self.c=[],0
		for d in self.df.index.levels[1].values:
			self.xticks.append(dt.datetime.strptime('%d%d' %((d),self.df.index.levels[0].values[self.c]),'%m%Y').strftime('%b \n%Y' if d==1 else '%b'))
			if d==12: self.c += 1
		self.ax.set_xticklabels(self.xticks,rotation='horizontal')
		self.ax.set_ylabel(self.label[self.var],color=(0.45, 0.45, 0.45),fontsize=self.fontsize)
		
		self.varsave = 'PM25' if self.var == 'PM2.5' else self.var
		plt.savefig('Figuras/%s/Promedio_%s.pdf' %(self.varsave,self.varsave),bbox_inches='tight')
		os.system('scp Figuras/%s/Promedio_%s.pdf %s%s/' %(self.varsave,self.varsave,self.path,self.varsave))
		#~ if var=='DViento_SSR': os.system('rm jhernandezv@siata.gov.co:/var/www/jhernandezv/RedAire/Consultas/Promedio_%s.pdf' %var)
		if self.Procuraduria: os.system('scp Figuras/%s/Promedio_%s.pdf calidadaire@192.168.1.10:Informe_Procuraduria/Graficos_Resumen/' %(self.varsave,self.varsave))
		
	
	def Plot_Precipitacion_Distribucion_Diurna(self,*args,**kwargs):
		
		var 		= self.var
		fontsize	= kwargs.get('fontsize','medium')
		textsave	= kwargs.get('textsave','')
		
		df = self.Meteo[self.var].groupby(lambda x: x.hour).sum().apply(lambda x: x/x.sum()*100)
		
		for est in df.columns.values:
			
			plt.close('all')
			fig = plt.figure(figsize=(8,3),facecolor='w',edgecolor='w')
			ax = fig.add_subplot(111)
			plt.setp(ax.spines.values(), color=self.colors[var][4])
			ax.spines['top'].set_visible(False)
			ax.tick_params(top='off',bottom='off', right='on',left='on',which='both',color=self.colors[var][4])
			ax.yaxis.label.set_color(self.colors[var][4])
			
			ylim 		= (0, df.max().max()+2)
			lims		= np.linspace(ylim[0],ylim[1],4)
			poscolor 	= df[est].apply(lambda x: np.abs(lims -x).argmin()).values
			cc			=[self.colors[var][i] for i in poscolor]

			df[est].plot(kind='bar',ax=ax,width=.5,color=cc,edgecolor='w',ylim=ylim,legend=False)

			ax.set_ylabel('Distribución Diurna de Precipitación [%]',fontproperties=prop_1,fontsize='small')
			ax.set_xticks(range(1,24,3))
			ticks = ax.get_xticks()
			label =  [dt.datetime.strptime('%.f' %j, '%H').strftime('%H:%M') for j in ticks[:]]  #[1,2,3,4,5,6,0]
			ax.set_xticklabels(label,fontproperties=prop_1,rotation='horizontal')
			ax.text(0,ylim[0]-(ylim[1]-ylim[0])*.18,self.Meteo[var].index[0].strftime('%Y'),fontsize=fontsize,color=self.colors[var][4],fontproperties=prop_2,ha='left')

			ax.set_yticks(range(0,int('%.f' %ylim[1]),3))
			ax.yaxis.grid(linestyle='--', linewidth=.5,color=self.colors[var][4],alpha=0.4)
			ax.set_yticks(range(0,int('%.f' %ylim[1]),1),minor=True)
			plt.setp(ax.get_yticklabels(),fontproperties=prop_1)

			#~ c=0
			#~ rects = ax.patches
			#~ for rect in rects:
				#~ height = rect.get_height()
				#~ ax.text(rect.get_x() + rect.get_width()/2. ,height+1, '%.1f' %height if height!=0 else ' ', ha='center',va='bottom',fontsize=fontsize, fontproperties=prop_2,color='w' if poscolor[c]>3 else self.colors[var][4])
				#~ c+=1

			plt.savefig('Figuras/%s/Distribucion_PPT_%s%s.pdf' %(var,est,textsave) ,bbox_inches='tight')
			os.system('scp Figuras/%s/Distribucion_PPT_%s%s.pdf nroldan@siata.gov.co:/var/www/CalidadAire/Figuras/%s/' %(var,est,textsave,var))


	
	def Plot_PrecipitacionDiaria(self):
		""" self.Meteo es como un diccionario que contine por variable meteorológica un 
			DataFrame con cada una de las estaciones con los datos del mes, se requiere 
			leer los datos de Meteorogogia utilizando Air.Read_db(Meteorologicas=True) 
			o leer precipitacion con Air.Aire_db(Meteorologicas=True) y definiendo la variable
			Air.var = 'PLiquida_SSR' y guardarlos datos leidos Air.Meteo = {Air.var:Air.Data}"""
		
		var				= 'PLiquida_SSR'
		cc				= ([0.69,0.87,0.93],[0.61,0.82,0.88],[0.32,0.71,0.77],[0.21,0.60,0.65],[0.0156,0.486,0.556],[0.007,0.32,0.36],[0.0078,0.227,0.26])
		ls				= ['-',':']
		self.resol		= '1h' 
		fontsize 		= 'medium'
		limAc			= 50
		datesize		= 2
		estaciones = self.Est[self.Est['Nombre'].isin( self.Meteo[var].columns.values)].sort_values(by='Latitud',ascending=False)['Nombre'].values
				
		print '------------------------'
		print var
		print '------------------------'
		
		
			
		plt.close('all')
		fig = plt.figure(figsize=(9, 3),facecolor='w',edgecolor='w')
		#~ plt.subplots_adjust(wspace=.2,hspace=.35,bottom=0.1,left=0.1,right=0.90,top=0.9)
		#~ fig.subplots_adjust(wspace = .3, hspace = .3)
		plt.rcParams["xtick.labelsize"]=fontsize
		plt.rcParams["ytick.labelsize"]=fontsize
		plt.rcParams["axes.labelsize"]=fontsize

		ax = {}
		ax[0] = fig.add_subplot(111)
		ax[1] = ax[0].twinx()
	
		for i in range(2):
			plt.setp(ax[i].spines.values(), color=(0.45, 0.45, 0.45))
			plt.setp([ax[i].get_xticklines(), ax[i].get_yticklines()], color=(0.45, 0.45, 0.45))
		
		width=1./self.Meteo[var].columns.size
		cum = 0
		P = []
		for c in range(len(estaciones)):
			ax[0].bar(left=np.arange(cum,self.Meteo[var][estaciones[c]].size+cum,1),height=self.Meteo[var][estaciones[c]],
				width=width,color=cc[c],lw=0.05,alpha=0.7)
			ax[1].plot(range(self.Meteo[var][estaciones[c]].size),self.Meteo[var][estaciones[c]].cumsum(),color=cc[c],ls=ls[1],lw=1)
			cum += width
			P.append( plt.Line2D((0,1),(0,0),color=cc[c],marker='s',ls='',fillstyle='full',markeredgecolor='k'))#(0.007,0.32,0.36)))
			
		box		= (0.5,-.18)
		leg=plt.legend(P,estaciones,bbox_to_anchor=box,fontsize='x-small', ncol=7,loc='center')
		leg.get_frame().set_edgecolor((0.45, 0.45, 0.45))
		
		
		c=0
		ax[0].set_ylim(self.limC[self.resol][var])
		ax[1].set_ylim(0,limAc)
		ax[0].set_xlim(-self.Meteo[var][estaciones[c]].size*.01,self.Meteo[var][estaciones[c]].size*1.01)
		#~ self.Meteo[var][self.Meteo[var].columns[c]].cumsum().plot(ax=ax[1],legend=False,ylim=(0,200),color=cc[1],style=ls[1])
		ax[0].set_ylabel(u'Precipitación Horaria $[mm]$',fontsize=fontsize,fontproperties=prop_1,color='k')
		ax[1].set_ylabel(u'Precipitación Acumulada $[mm]$',fontsize=fontsize,fontproperties=prop_1,color='k')
		#~ title = self.Est['Nombre_Estacion'][self.Est['Nombre'] == self.Meteo[var].columns[c]].values[0].decode('utf-8')
		#~ ax[0].set_title(title,loc='right',fontsize=fontsize,fontproperties=prop_2)
		
	
		ax[0].set_xticks(range(1,self.Meteo[var][estaciones[c]].size,datesize))
		ticks = ax[0].get_xticks()
		date = 		self.Meteo[var][estaciones[c]].index #date = pd.date_range(self.Fechai,self.Fechaf,freq=self.resol)
		label = ['%s' %(date[j].strftime('%H:%M')) for j in ticks[:]]
		ax[0].set_xticks(range(0,self.Meteo[var][estaciones[c]].size+1,datesize/2),minor=True)
		ax[0].set_xticklabels(label,fontsize=fontsize,fontproperties=prop_1)
		ax[0].set_yticks(np.arange(0,self.limC[self.resol][var][1],self.limC[self.resol][var][1]/50.),minor=True)
		ax[1].set_yticks(np.arange(0,limAc,limAc/50.),minor=True)
		#~ ax[0].set_xlabel('')
		
		plt.savefig('Figuras/Precipitacion_Diaria.pdf' ,bbox_inches='tight')
		os.system('scp Figuras/Precipitacion_Diaria.pdf jhernandezv@siata.gov.co:/var/www/CalidadAire/Figuras/')
	
	
	def Plot_Precipitacion(self,*args,**kwargs):
		""" self.Meteo es como un diccionario que contine por variable meteorológica un 
			DataFrame con cada una de las estaciones con los datos del mes, se requiere 
			leer los datos de Meteorogogia utilizando Air.Read_db(Meteorologicas=True) 
			o leer precipitacion con Air.Aire_db(Meteorologicas=True) y definiendo la variable
			Air.var = 'PLiquida_SSR' y guardarlos datos leidos Air.Meteo = {Air.var:Air.Data}"""
		Mensual			= kwargs.get('Mensual',True)

		var				= 'PLiquida_SSR'
		cc				= ['b',(0.0078,0.227,0.26)]
		ls				= ['-',':']
		self.resol		= '1h' 
		fontsize 		= 'medium'
		limAc			 = 500 if Mensual else 50
		datesize		= 48 if Mensual else 2
		widht			= 0.005 if Mensual else 0.03
		df			= kwargs.get('df',None)
		print '------------------------'
		print var
		print '------------------------'
		
		print df
		df = df.resample('H').sum()	
		if len(df)==0:
			df=self.Meteo[var]
		
		for c in range(df.columns.size):
			plt.close('all')
			fig = plt.figure(figsize=(7, 3),facecolor='w',edgecolor='w')
			#~ plt.subplots_adjust(wspace=.2,hspace=.35,bottom=0.1,left=0.1,right=0.90,top=0.9)
			#~ fig.subplots_adjust(wspace = .3, hspace = .3)
			plt.rcParams["xtick.labelsize"]=fontsize
			plt.rcParams["ytick.labelsize"]=fontsize
			plt.rcParams["axes.labelsize"]=fontsize

			ax = {}
			ax[0] = fig.add_subplot(111)
			ax[1] = ax[0].twinx()

			for i in range(2):
				plt.setp(ax[i].spines.values(), color=(0.45, 0.45, 0.45))
				plt.setp([ax[i].get_xticklines(), ax[i].get_yticklines()], color=(0.45, 0.45, 0.45))

			ax[0].bar(left=range(df[df.columns[c]].size),height=df[df.columns[c]],
				width=df[df.columns[c]].size*widht,color=cc[0],lw=0.05,alpha=0.7)
			ax[1].plot(range(df[df.columns[c]].size),df[df.columns[c]].cumsum(),color=cc[1],ls=ls[1],lw=2)
			
			ax[0].set_ylim(self.limC[self.resol][var])
			ax[1].set_ylim(0,limAc)
			ax[0].set_xlim(-df[df.columns[c]].size*.01,df[df.columns[c]].size*1.01)
			#~ self.Meteo[var][self.Meteo[var].columns[c]].cumsum().plot(ax=ax[1],legend=False,ylim=(0,200),color=cc[1],style=ls[1])
			ax[0].set_ylabel(u'Precipitación Horaria $[mm]$',fontsize=fontsize,fontproperties=prop_1,color=cc[0])
			ax[1].set_ylabel(u'Precipitación Acumulada $[mm]$',fontsize=fontsize,fontproperties=prop_1,color=cc[1])
			title = self.EstR['Nombre_Estacion'][self.EstR['Nombre'] == df.columns[c]].values[0].decode('utf-8')
			ax[0].set_title(title,loc='right',fontsize=fontsize,fontproperties=prop_2)


			ax[0].set_xticks(range(1,df[df.columns[c]].size,datesize))
			ticks = ax[0].get_xticks()
			date = 		df[df.columns[c]].index #date = pd.date_range(self.Fechai,self.Fechaf,freq=self.resol)
			if Mensual:
				label = ['%s%d' %(self.dias_es[date[j].strftime('%w')],date[j].day) for j in ticks[:]]
				ax[0].text(0,-self.limC[self.resol][var][1]*.2,'%s' %self.mes_es[date[0].month],ha='left',va='bottom',fontsize=fontsize,fontproperties=prop)
			else:
				label = ['%s' %(date[j].strftime('%H:%M')) for j in ticks[:]]

			ax[0].set_xticks(range(0,df[df.columns[c]].size,datesize/2),minor=True)
			ax[0].set_xticklabels(label,fontsize=fontsize,fontproperties=prop_1)
			ax[0].set_yticks(np.arange(0,self.limC[self.resol][var][1],self.limC[self.resol][var][1]/50.),minor=True)
			ax[1].set_yticks(np.arange(0,limAc,limAc/50.),minor=True)
			#~ ax[0].set_xlabel('')

			P 		= plt.Line2D((0,1),(0,0),color=cc[0],marker='s',ls='',fillstyle='full',markeredgecolor='k')#(0.007,0.32,0.36)))
			PA		= plt.Line2D((0,1),(0,0),color=cc[1],ls=ls[1],lw=2)
			box		= (0.5,-.18)
			leg=plt.legend([P,PA],['PPT','PPT A'],bbox_to_anchor=box,fontsize=fontsize, ncol=2,loc='center')
			leg.get_frame().set_edgecolor((0.45, 0.45, 0.45))

			if Mensual:
                               
				plt.savefig('Informe/Figuras/%s/Precipitacion_%s.pdf' %(var,df.columns[c]),bbox_inches='tight')
				#os.system('scp Informe/Figuras/%s/Precipitacion_%s.pdf nroldan@siata.gov.co:/var/www/CalidadAire/Figuras/%s/' %(var,self.Meteo[var].columns[c],var))
			else:
                
				plt.savefig('Informe/Figuras/PLiquida_SSR/Precipitacion_%s.pdf' %(df.columns[c]),bbox_inches='tight')
				os.system('scp Informe/Figuras/PLiquida_SSR/Precipitacion_%s.pdf nroldan@siata.gov.co:/var/www/CalidadAire/Figuras/' %(self.Meteo[var].columns[c]))
				#plt.savefig('figurita')
	def Plot_CD_HR_T_RG(self,*args,**kwargs):

		var			= ['HAire10_SSR','TAire10_SSR','P_SSR']
		color			= ['b','r','k']
		ls				= ['-','--','-']
		self.resol		= '1h' 
		fontsize		= 14
		
		## Editamos para poner un df como argumento
		self.Meteo = kwargs.get('df')##Esta línea no existía hasta el informe ruido del mes de MAYO

		print '------------------------'
		print var
		print '------------------------'
		for c in range(self.Meteo['TAire10_SSR'].columns.size):
			plt.close('all')
			fig = plt.figure(figsize=(6, 3),facecolor='w',edgecolor='w')
			#~ plt.subplots_adjust(wspace=.2,hspace=.35,bottom=0.1,left=0.1,right=0.90,top=0.9)
			#~ fig.subplots_adjust(wspace = .3, hspace = .3)
			plt.rcParams["xtick.labelsize"]=fontsize
			plt.rcParams["ytick.labelsize"]=fontsize
			plt.rcParams["axes.labelsize"]=fontsize
			#~ mpl.rc('axes',edgecolor=(0.45, 0.45, 0.45))
			
			ax={}
			ax[0] = host_subplot(111, axes_class=AA.Axes)
			plt.subplots_adjust(right=0.75)
			ax[1] = ax[0].twinx()

			ax[1].spines['right'].set_position(('outward', 40))

			offset = 60

			ax[2] = ax[0].twinx()
			new_fixed_axis = ax[2].get_grid_helper().new_fixed_axis
			ax[2].axis["right"] = new_fixed_axis(loc="right", axes=ax[2], offset=(offset, 0))
			ax[2].axis["right"].toggle(all=True)

			ax[1].axis["right"] = new_fixed_axis(loc="right", axes=ax[1], offset=(0, 0))
			ax[1].axis["right"].toggle(all=True)

			##ax[2] = ax[0].twinx()
			
			#ax[1].spines['right'].set_position(('outward', 40))
			##offset = 60

			#ax[1].axis["right"] = new_fixed_axis(loc="right", axes=ax[1], offset=(0, 0))
			#ax[1].axis["right"].toggle(all=True)
			##new_fixed_axis = ax[1].get_grid_helper().new_fixed_axis
			##ax[1].axis["right"] = new_fixed_axis(loc="right", axes=ax[1], offset=(offset, 0))
			##ax[1].axis["right"].toggle(all=True)
			
			for i in range(len(var)):
				
				
				#~ ax[i].xaxis.label.set_color((0.45, 0.45, 0.45))
				#~ ax[i].yaxis.label.set_color((0.45, 0.45, 0.45))
				#~ ax[i].tick_params(axis='x', colors=(0.45, 0.45, 0.45))
				#~ ax[i].tick_params(axis='y', colors=(0.45, 0.45, 0.45))
				#~ plt.setp(ax[i].spines.values(), color=(0.45, 0.45, 0.45))
				#~ plt.setp([ax[i].get_xticklines(), ax[i].get_yticklines()], color=(0.45, 0.45, 0.45))
				
				#try: 
				values = self.Meteo[var[i]][self.Meteo[var[i]].columns[c]].groupby(lambda x: x.hour).mean().values
				ax[i].plot(range(24),values,color=color[i],ls=ls[i])

				print var[i]
				print values
				#except:pass
				ax[i].set_ylim(self.limC[self.resol][var[i]] if var[i]!='P_SSR' else (830,870))
				ax[i].locator_params(axis='y',nbins=6)
				ax[i].set_ylabel(self.label[var[i]],fontproperties=prop_1, fontsize=fontsize,color=color[i])
				ax[i].set_xlim(0,23)
				
				if i == 1: 
					title = self.EstR['Nombre_Estacion'][self.EstR['Nombre'] == self.Meteo[var[i]].columns[c]].values[0].decode('utf-8')
					ax[0].set_title(title,loc='right',fontsize=fontsize,fontproperties=prop_2)
					ax[0].locator_params(axis='x',nbins=6)
					ticks = ax[0].get_xticks()
					label = [dt.datetime.strptime('%.f' %j, '%H').strftime('%H:%M') for j in ticks[:-1]]
					ax[0].set_xticklabels(label)
					#Legend
					HR		= plt.Line2D((0,1),(0,0),color=color[0],ls=ls[0])
					T 		= plt.Line2D((0,1),(0,0),color=color[1],ls=ls[1])
					P		= plt.Line2D((0,1),(0,0),color=color[2],ls=ls[2])
					box		= (0.5,-.18)

					#leg=plt.legend([HR,T,RG],['HR','T','RG'],bbox_to_anchor=box,fontsize=fontsize -2 , ncol=3,loc='center')
					leg=plt.legend([HR,T,P],['HR','T','P'],bbox_to_anchor=box,fontsize=fontsize -2 , ncol=3,loc='center')
					leg.get_frame().set_edgecolor((0.45, 0.45, 0.45))

			plt.savefig('Informe/Figuras/Meteorologia/Ciclo_diurno_P_T_RG_%s.pdf' %(self.Meteo[var[i]].columns[c]),bbox_inches='tight')
			os.system('scp Informe/Figuras/Meteorologia/Ciclo_diurno_P_T_RG_%s.pdf nroldan@siata.gov.co:/var/www/CalidadAire/Figuras/Meteorologia/' %(self.Meteo[var[i]].columns[c]))

	def Plot_MMM(self,*args,**kwargs):

		self.Medellin 		= kwargs.get('Medellin',False)
		self.Valle		= kwargs.get('Valle',False)
		self.Procuraduria	= kwargs.get('Procuraduria',False)
		self.var		= kwargs.get('var',self.var)
		self.fontsize		= kwargs.get('fontsize',10)
		self.resol		= kwargs.get('resol','D')
		self.color		= kwargs.get('color',[[0.61,0.82,0.88],[0.21,0.60,0.65],[0.0078,0.227,0.26]])
		self.textsave		= kwargs.get('textsave','')
		self.path		= kwargs.get('path','Procuraduria/')
		self.df			= kwargs.get('df',None)
		self.text_down		= kwargs.get('text_down',True)

		self.varsave	= 'PM25' if self.var == 'PM2.5' else self.var

		if type(self.df)== type(None):
			self.df   = (self.Contaminante[self.var].rolling(8,freq='1h').mean() if self.resol=='8h' else self.Contaminante[self.var].resample(self.resol).mean()) if self.var in self.nombre_contaminantes else self.Meteo[self.var].resample(self.resol).apply(lambda x: x.sum() if self.var == 'PLiquida_SSR' else x.mean())

		if self.Medellin:
			estaciones = ['MED-ARAN', 'MED-VILL', 'MED-SCRI', 'MED-UNNV','MED-BEME', 'MED-ALTA', 'MED-TESO', 'MED-LAYE','CEN-TRAF']
			self.df = self.df.loc[:,estaciones]
			self.varsave = self.varsave + 'Med'
		if self.Valle:
 			estaciones = ['BAR-TORR', 'GIR-SOSN', 'COP-CVID', 'BEL-FEVE', 'ITA-CJUS', 'ENV-HOSP', 'ITA-CONC', 'SAB-JOFE','EST-HOSP', 'CAL-LASA','SUR-TRAF']
			self.df = self.df.loc[:,estaciones]
			self.varsave = self.varsave + 'Valle'

		self.X= pd.concat({'Máximo':self.df.max(),'Media':self.df.mean(),'Mínimo':self.df.min()},axis=1)

		#Plot
		plt.close('all')
		self.fig = plt.figure(figsize=(self.X.index.size*1.2,3),facecolor='w',edgecolor='w')
		self.ax = self.fig.add_subplot(111)
		plt.setp(self.ax.spines.values(),color='w')
		self.ax.tick_params(axis='both',which='both',length=0,color='w')
		self.X[['Máximo','Media','Mínimo']].plot(kind='bar',ax=self.ax,width=.75,color=self.color,edgecolor='w')

		#Ticks
		self.ticks=self.ax.get_xticklabels()
		self.ax.set_xticklabels(self.ticks,rotation='horizontal',fontsize=self.fontsize,weight='heavy')
		self.ax.set_yticklabels([])

		#Legend
		self.leg = self.ax.legend(bbox_to_anchor=(1.03,0.5),loc='center left',fontsize=self.fontsize,framealpha=0.3)
		self.leg.get_frame().set_linewidth(0.0)

		#Label Bar
		self.rects = self.ax.patches
		for rect in self.rects:
			self.height = rect.get_height()
			self.ax.text(rect.get_x() + rect.get_width()/2. , self.height*1.02, '%.f' %self.height if self.height!=0 else ' ', ha='center',va='bottom',fontsize=self.fontsize,fontproperties=prop_1)

		self.ax.text(self.ax.get_xticks()[-1]+.7,self.df.max().max()*.5,self.label[self.var],rotation='vertical',fontproperties=prop_1,fontsize=self.fontsize+4,ha='center',va='center')
		if self.text_down:
			self.ax.text(-.5,-self.df.max().max()*.17,'CM%s' %self.resol,fontsize=self.fontsize,fontproperties=prop,ha='right',va='bottom')

			for x in self.ax.get_xticks():
				self.ax.text(x ,-self.df.max().max()*.17,'%d' %self.df[self.df.columns[x]].count(),fontsize=self.fontsize,fontproperties=prop_1,ha='center',va='bottom')
				if self.df[self.df.columns[x]].count()!=0:
					if self.var in ['PM10','PM2.5','SO2','NO2']:
						if x==0: self.ax.text(-.5,-self.df.max().max()*.25,'EN'+self.resol+ur' [$\%$]' ,fontsize=self.fontsize,fontproperties=prop,ha='right',va='bottom')
						self.excedencia = self.df[self.df > self.norma[self.resol][self.var]][self.df.columns[x]].count()/float(self.df[self.df.columns[x]].count())*100
						self.ax.text(x ,-self.df.max().max()*.25, '%.1f' %self.excedencia,fontsize=self.fontsize,fontproperties=prop_1,ha='center',va='bottom')
						if self.var =='NO2':
							self.res='1h'
							self.exc1 = self.Contaminante[self.var][self.df.columns[x]]
							self.excedencia = self.exc1[self.exc1 > self.norma[self.res][self.var]].count()/float(self.exc1.count())*100
							self.ax.text(x ,-self.df.max().max()*.33, '%.1f' %self.excedencia,fontsize=self.fontsize,fontproperties=prop_1,ha='center',va='bottom')
							if x==0: self.ax.text(-.5,-self.df.max().max()*.33,'EN'+self.res+ur' [$\%$]',fontsize=self.fontsize,fontproperties=prop,ha='right',va='bottom')
					elif self.var in ['Ozono','CO']:
						self.res='1h'
						self.exc1 = self.Contaminante[self.var][self.df.columns[x]]
						self.excedencia = self.exc1[self.exc1 > self.norma[self.res][self.var]].count()/float(self.exc1.count())*100
						self.ax.text(x ,-self.df.max().max()*.25, '%.1f' %self.excedencia,fontsize=self.fontsize,fontproperties=prop_1,ha='center',va='bottom')
						if x==0: self.ax.text(-.5,-self.df.max().max()*.25,'EN'+self.res+ur' [$\%$]',fontsize=self.fontsize,fontproperties=prop,ha='right',va='bottom')

						self.res='8h'
						self.exc1 = self.Contaminante[self.var][self.df.columns[x]].rolling(8,freq='1h').mean()
						self.excedencia = self.exc1[self.exc1 > self.norma[self.res][self.var]].count()/float(self.exc1.count())*100
						self.ax.text(x ,-self.df.max().max()*.33, '%.1f' %self.excedencia,fontsize=self.fontsize,fontproperties=prop_1,ha='center',va='bottom')
						if x==0: self.ax.text(-.5,-self.df.max().max()*.33,'EN'+self.res+ur' [$\%$]',fontsize=self.fontsize,fontproperties=prop,ha='right',va='bottom')

		plt.savefig('Figuras/MMM_%s%s.pdf' %(self.varsave,self.textsave),bbox_inches='tight')
		os.system('scp Figuras/MMM_%s%s.pdf nroldan@siata.gov.co:/var/www/CalidadAire/Figuras/%s' %(self.varsave,self.textsave,self.path))
		if self.Procuraduria: os.system('scp Figuras/MMM_%s%s.pdf calidadaire@192.168.1.10:Informe_Procuraduria/Graficos_Resumen/' %(self.varsave,self.textsave))


	def Plot_Flags(self,df,var,*args,**kwargs):
		path			= kwargs.get('path', 'CalidadAire/Figuras/Flags/')
		fontsize		= kwargs.get('fontsize','medium')
		colors			= kwargs.get('colors',[[0.61,0.82,0.88],[0.32,0.71,0.77],[0.0156,0.486,0.556]])

		plt.close('all')
		fig = plt.figure(figsize=(df.index.size*1.25,3),facecolor='w',edgecolor='w')
		ax = fig.add_subplot(111)
		plt.rcParams["ytick.labelsize"]=fontsize
		plt.rcParams["xtick.labelsize"]='small'


		for spinename, spine in ax.spines.iteritems():
			spine.set_visible(False)

		ax.spines['left'].set_visible(True)
		ax.spines['left'].set_color((0.45, 0.45, 0.45))
		ax.tick_params(top='off', right='off',bottom='off',left='on',which='both',color=(0.45, 0.45, 0.45),labelcolor=(0.45, 0.45, 0.45))
		#~ ax.tick_params(left='on', which='both',color=(0.45, 0.45, 0.45))
		#~ plt.setp([ax.get_xticklines(), ax.get_yticklines()], color=(0.45, 0.45, 0.45))

		df.plot(kind='bar',ax=ax,width=0.8,color=colors,edgecolor=(0.45, 0.45, 0.45))

		ax.set_ylim(0,100)
		ax.legend(bbox_to_anchor=(1.0,1.0),loc='upper left',fontsize=fontsize,framealpha=0.3,)
		ax.set_xticklabels(ax.get_xticklabels(),rotation='horizontal',weight='heavy')
		ax.set_ylabel('Porcentaje [%]',fontsize=fontsize,color=(0.45, 0.45, 0.45))

		ax.text(ax.get_xticks()[-1] +1.5,40,'Variable',fontsize=fontsize,color=(0.45, 0.45, 0.45),ha='center')
		ax.text(ax.get_xticks()[-1] +1.5,25,var,fontsize=fontsize,color=(0.45, 0.45, 0.45),ha='center')

		vartex = 'PM25' if var =='PM2.5' else var
		plt.savefig('Figuras/Flags_%s.pdf' %(vartex),bbox_inches='tight')
		os.system('scp Figuras/Flags_%s.pdf roldan@siata.gov.co:/var/www/%s' %(vartex,path))

	def Plot_Serie(self,*args,**kwargs):
		
		self.varsave	= 'PM25' if self.var == 'PM2.5' else self.var
		self.df			= kwargs.get('df',None)
		self.textsave	= kwargs.get('textsave','')
		self.fontsize	= kwargs.get('fontsize','large')
		self.estaciones	= kwargs.get('estaciones',None)
		self.color		= kwargs.get('color',[[0.69,0.87,0.93],[0.32,0.71,0.77],[0.0156,0.486,0.556],[0.0078,0.227,0.26],[0.45, 0.45, 0.45]])
		self.get_color	= self.colors[self.var] if self.var in self.colors.keys() else self.color
#		self.get_color	= tuple (self.colors[self.var]) if self.var in self.colors.keys() else tuple (self.color)
		self.legend		= kwargs.get('legend',True)
		self.path		= kwargs.get('path','nroldan@siata.gov.co:/var/www/CalidadAire/Figuras/%s/' %self.varsave) 
		self.resolucion	= kwargs.get('resolucion','D')
		self.title		= kwargs.get('title',True)
		self.ax			= kwargs.get('ax',None)
		self.savefig	= type(self.ax) == type(None)
		
		
		if type(self.df)== type(None):
			self.df		= self.Contaminante[self.var] if self.var in self.nombre_contaminantes else self.Meteo[self.var] 
		
		if type(self.estaciones)== type(None):
			self.estaciones = self.Est[self.Est['Nombre'].isin(self.df.columns.values)].sort_values(by='Latitud',ascending=False)['Nombre'].values[::-1]
		
		#####################################
		for i in range(len(self.estaciones)):
			
			if self.savefig: 
				plt.close('all')
				self.fig		= plt.figure(figsize=(9, 4),facecolor='w',edgecolor='w')
				plt.subplots_adjust(wspace=.0,hspace=.2,bottom=0.1,left=0.1,right=0.90,top=0.9)
				self.ax	= self.fig.add_subplot(111) 
			self.ax.spines['top'].set_visible(False)
			self.ax.spines['right'].set_visible(False)
			self.ax.spines['left'].set_color(self.get_color[4])
			self.ax.spines['bottom'].set_color(self.get_color[4])
			self.ax.tick_params(top='off', right='off',bottom='on',left='on',which='both',color=self.get_color[4],labelsize=self.fontsize)
			self.ax.xaxis.label.set_color(self.get_color[4])
			self.ax.yaxis.label.set_color(self.get_color[4])
			
			#~ df[estaciones[i]].plot(ax=ax[i],legend=False,lw=0.0001,alpha=0.5,color=colors[1],label='Horario')
			self.ylim = kwargs.get('ylim',(self.df.resample('D').median().min().min()-1,self.df.resample('D').median().max().max()+1))
			#~ self.ylim = kwargs.get('ylim',(self.df.groupby(pd.Grouper(freq='D')).quantile(.25).min().min()-5,self.df.groupby(pd.Grouper(freq='D')).quantile(.75).max().max()+5))
			
			self.dfmean = self.df[self.estaciones[i]].resample(self.resolucion).apply(lambda x: x.median() if self.var != 'PLiquida_SSR' else x.sum())
			
			self.dfmean.plot(ax=self.ax,ylim=self.ylim,legend=False,color=self.get_color[0],label='Diario',lw=0.5,alpha=.5)
			
			self.dfmean.rolling(30,freq='D',center=True,min_periods=1).median().plot(ax=self.ax,ylim=self.ylim,legend=False,color=self.get_color[3],label='Mediana Móvil Mensual',lw=2) #.apply(lambda x: x.median() if self.var != 'PLiquida_SSR' else x.sum())
			
			#~ if self.var != 'PLiquida_SSR':
				#~ self.ax.fill_between(self.df[self.estaciones[i]].groupby(pd.Grouper(freq='D')).quantile(.25).index,self.df[self.estaciones[i]].groupby(pd.Grouper(freq='D')).quantile(.25).values,self.df[self.estaciones[i]].groupby(pd.Grouper(freq='D')).quantile(.75).values,color=self.get_color[0],alpha=.6,label='RIQ')
			
			
				#~ ax[i].scatter(df[estaciones[i]].resample(resolucion,how='max').index, df[estaciones[i]].resample(resolucion,how='max').values,color=colors[3],s=1,label='Máximo')
				#~ df[estaciones[i]].groupby(pd.Grouper(freq='D')).quantile([.25,.75]).plot(kind='area',stacked=True,ax=ax[i],legend=False,color=colors[3],label='RIQ')
				#~ df[estaciones[i]].resample(resolucion,how=lambda x: np.percentile(x,q=75)).plot(ax=ax[i],legend=False,color=colors[3],label='Máximo',s=1)
				#~ df[estaciones[i]].resample(resolucion,how='min').plot(ax=ax[i],legend=False,color=colors[3],label='Mínimo',style='-')
			
			#Legend
			if self.legend:
				self.leg		= self.ax.legend(bbox_to_anchor=(.5,-.2),loc='center',fontsize=self.fontsize,framealpha=0.2,ncol=3) #,frameon=False)
				self.leg.get_frame().set_facecolor('w')
				self.leg.get_frame().set_edgecolor(self.get_color[4])
				for text in self.leg.get_texts(): plt.setp(text, color = self.get_color[4])
			
			
			if self.title: self.ax.set_title(self.Est[self.Est['Nombre']==self.estaciones[i]]['Nombre_Largo'].values[0],loc='right',color=self.get_color[4],fontproperties=prop_2,fontsize=self.fontsize)
			self.ax.set_ylabel(self.label[self.var],fontproperties=prop_1,fontsize=self.fontsize)
			self.ax.set_xlabel('') 
			
			#~ self.ticks = self.df.resample('m').mean().index
			#~ self.ax.set_xticklabels([t.strftime('%B\n %Y' if t.strftime('%m')=='01' else '%B') for t in self.ticks],rotation='horizontal',fontsize=self.fontsize)
			#~ plt.setp(ax[i].get_xticklabels(),rotation='horizontal')
			
			
			
			#~ ticklabels = ['']*len(df_ts.index)
			#~ # Every 4th ticklable shows the month and day
			#~ ticklabels[::4] = [item.strftime('%b %d') for item in df_ts.index[::4]]
			#~ # Every 12th ticklabel includes the year
			#~ ticklabels[::12] = [item.strftime('%b %d\n%Y') for item in df_ts.index[::12]]
			#~ ax.xaxis.set_major_formatter(ticker.FixedFormatter(ticklabels))
			
			self.ax.minorticks_off()
			if self.savefig:
				plt.savefig('Figuras/%s/Serie_%s_%s%s.pdf' %(self.varsave,self.varsave,self.estaciones[i],self.textsave) ,bbox_inches='tight')
				os.system('scp Figuras/%s/Serie_%s_%s%s.pdf %s'%(self.varsave,self.varsave,self.estaciones[i],self.textsave,self.path))
				self.ax = None
			
	def Plot_Historico_Anual(self,*args,**kwargs):
		
		var 		= self.var
		textsave	= kwargs.get('textsave','')
		fontsize	= kwargs.get('fontsize','medium')
		df			= kwargs.get('df',None)

		if type(df)== type(None):
			df	= self.Contaminante if var in self.nombre_contaminantes else self.Meteo if var in self.nombre_meteorologicas else self.ContaminanteManual

		D = df.resample('m').median()[var]

		for est in D.columns.values:

			plt.close('all')
			fig = plt.figure(figsize=(6, 3),facecolor='w',edgecolor='w')

			ax=fig.add_subplot(111)
			plt.setp(ax.spines.values(), color=self.colors[var][4])
			ax.spines['top'].set_visible(False)
			ax.spines['right'].set_visible(False)
			ax.tick_params(top='off', right='off',bottom='on',left='on',which='both',color=self.colors[var][4],labelsize=fontsize)
			ax.xaxis.label.set_color(self.colors[var][4])
			ax.yaxis.label.set_color(self.colors[var][4])

			ax.plot(range(1,13),D['2014'][est].values,label='2014',color= self.colors[var][0],alpha=0.4,lw=3)
			ax.plot(range(1,13),D['2015'][est].values,label='2015',color= self.colors[var][1],alpha=0.9,lw=3)
			ax.plot(range(1,13),D['2016'][est].values,label='2016',color= self.colors[var][3],alpha=1,lw=3)
			ax.scatter(range(1,13),D['2014'][est].values,color= self.colors[var][0],alpha=0.4)
			ax.scatter(range(1,13),D['2015'][est].values,color= self.colors[var][1],alpha=0.9)
			ax.scatter(range(1,13),D['2016'][est].values,color= self.colors[var][3],alpha=1)

			ax.set_xlim(0.5,12.5)
			ax.set_ylim(D.min().min()-1,D.max().max()+1)
			ax.set_ylabel(self.label[var])
			leg=ax.legend(loc='best',fontsize=fontsize,ncol=3,framealpha=0.1) #,bbox_to_anchor=
			leg.get_frame().set_edgecolor(self.colors[var][4])
			for text in leg.get_texts(): plt.setp(text, color = self.colors[var][4])
			ax.set_xticks(range(1,13))
			xticks =ax.get_xticks()
			xticklabels = [dt.datetime.strptime('%d' %x,'%m').strftime('%b') for x in xticks]
			ax.set_xticklabels(xticklabels,fontsize=fontsize)

			varsave = 'PM25' if (var =='PM2.5') else 'PM25M' if (var=='PM2.5M') else  var
			plt.savefig('Figuras/%s/Historico_Anual_%s_%s%s.pdf' %(varsave,varsave,est,textsave),bbox_inches='tight')
			os.system('scp Figuras/%s/Historico_Anual_%s_%s%s.pdf nroldan@siata.gov.co:/var/www/CalidadAire/Figuras/%s/' %(varsave,varsave,est,textsave,varsave))

	def Plot_Histogramas(self,*args,**kwargs):
		
		self.df			= kwargs.get('df',None)
		self.textsave	= kwargs.get('textsave','')
		self.fontsize	= kwargs.get('fontsize','medium')
		self.title		= kwargs.get('title',True)
		self.legend		= kwargs.get('legend',True)
		self.ax			= kwargs.get('ax',None)
		self.path		= kwargs.get('path', 'nroldan@siata.gov.co:/var/www/CalidadAire/Figuras/')
		self.color		= kwargs.get('color',[[0.69,0.87,0.93],[0.32,0.71,0.77],[0.0156,0.486,0.556],[0.0078,0.227,0.26],[0.45, 0.45, 0.45]])
		self.get_color 	= self.colors[self.var] if self.var in self.colors.keys() else self.color
#		self.get_color 	= tuple (self.colors[self.var]) if self.var in self.colors.keys() else tuple (self.color)
		self.savefig			= type(self.ax) == type(None)
		
		if type(self.df)==type(None): self.df = self.Contaminante[self.var] if self.var in self.nombre_contaminantes else self.Meteo[self.var] if self.var in self.nombre_meteorologicas else self.ContaminanteManual[self.var]
		
		if self.var=='RGlobal_SSR': self.df[self.df==0]=np.NaN
		self.plot = self.df.plot(kind='density') if self.savefig else self.df.plot(kind='density',ax=self.ax) 
		self.ylim = (np.max([self.plot.lines[i].get_xydata()[:,1].max() for i in range(len(self.plot.lines))])+.003)*100
		
		for est in self.df.columns.values:
			if self.savefig: 
				plt.close('all')
				self.plot = self.df[est].plot(kind='density', legend=False)
				self.data = self.plot.lines[0].get_xydata()
				self.data[:,1] = self.data[:,1]*100
				plt.close('all')
				self.fig 		= plt.figure(figsize=(4.2, 2.3),facecolor='w',edgecolor='w')
				self.ax			= self.fig.add_subplot(111) 
				
			else:
				self.ax.cla()
				self.plot = self.df[est].plot(kind='density', legend=False,ax=self.ax)
				self.data = self.plot.lines[0].get_xydata()
				self.data[:,1] = self.data[:,1]*100
				self.ax.cla()
				
			
			self.ax.spines['top'].set_visible(False)
			self.ax.spines['right'].set_visible(False)
			self.ax.spines['left'].set_color((0.45, 0.45, 0.45))
			self.ax.spines['bottom'].set_color((0.45, 0.45, 0.45))
			self.ax.tick_params(top='off', right='off',bottom='on',left='on',which='both',color=(0.45, 0.45, 0.45),labelsize=self.fontsize)
			self.ax.xaxis.label.set_color((0.45, 0.45, 0.45))
			self.ax.yaxis.label.set_color((0.45, 0.45, 0.45))
			
			self.ax.plot(self.data[:,0],self.data[:,1],color=self.get_color[3])
			self.ax.set_xlim(self.df.min().min(),self.df.max().max())
			self.ax.set_ylim(0,self.ylim)
			
			if self.title: self.ax.set_title(self.Est['Nombre_Largo'][self.Est['Nombre'] == est].values[0],loc='center',fontproperties=prop_2,color=(0.45, 0.45, 0.45),fontsize=self.fontsize)
			
			self.ax.locator_params(axis='y',nbins=6)
			self.ax.locator_params(axis='x',nbins=6)
			self.ax.set_xlabel(self.label[self.var],fontproperties=prop_1,fontsize=self.fontsize)
			self.ax.set_ylabel('Frecuencia Relativa [%]',fontsize=self.fontsize,fontproperties=prop_1)
			self.loc = lambda x: np.abs(self.data[:,0]-self.df[est].quantile(x)).argmin()
			
			self.ax.axvline(self.df[est].quantile(.5),ymax=self.data[self.loc(.5),1]/self.ylim,color=self.get_color[1],ls='--')
			self.ax.fill_between(self.data[:,0],0,self.data[:,1], where= (self.data[:,0] >= self.df[est].quantile(.75)) | (self.data[:,0] <= self.df[est].quantile(.25)),color = self.get_color[0],alpha=.4)
			
			self.c=0
			self.Q = [.25,.50,.75]
			for i in range(3):
				self.ax.text(self.df.max().max()*.25 if self.var =='HAire10_SSR' else self.df.max().max()*.9,self.ylim*(.8-self.c),'Q%.f: ' %(self.Q[i]*100),va='center',ha='right',fontsize=self.fontsize,fontproperties=prop_2,color=self.get_color[4])
				self.ax.text(self.df.max().max()*.25 if self.var =='HAire10_SSR' else self.df.max().max()*.9,self.ylim*(.8-self.c),' %.1f' %(self.df[est].quantile(self.Q[i])),va='center',ha='left',fontsize=self.fontsize,fontproperties=prop_1,color=self.get_color[4])
				self.c+=.1
			
			self.varsave = 'PM25' if (self.var =='PM2.5') else 'PM25M' if (self.var=='PM2.5M') else  self.var
			if self.savefig:
				plt.savefig('Figuras/%s/Histograma_%s_%s%s.pdf' %(self.varsave,self.varsave,est,self.textsave),bbox_inches='tight')
				os.system('scp Figuras/%s/Histograma_%s_%s%s.pdf %s/%s/' %(self.varsave,self.varsave,est,self.textsave,self.path,self.varsave))
				self.ax = None

	
	def Plot_CicloDiurno(self,*args,**kwargs):
		"""Genera gráficas de ciclos diurnos de las variables de entrada (self.var)
			con la media, el rango intercuartil y los percentiles 10 y 90."""
		
		self.df				= kwargs.get('df',None)
		self.textsave		= kwargs.get('textsave','')
		self.subplots		= kwargs.get('subplots',False)
		self.percen10_90	= kwargs.get('percen10_90',False)
		self.Anual			= kwargs.get('Anual',False)
		self.Semanal		= kwargs.get('Semanal',False)
		self.fontsize		= kwargs.get('fontsize',12)
		self.title			= kwargs.get('title',True)
		self.legend			= kwargs.get('legend',True)
		self.path			= kwargs.get('path','nroldan@siata.gov.co:/var/www/CalidadAire/Figuras/')
		self.color			= kwargs.get('color',[[0.69,0.87,0.93],[0.32,0.71,0.77],[0.0156,0.486,0.556],[0.0078,0.227,0.26],[0.45, 0.45, 0.45]])
		self.get_color 		= self.colors[self.var] if self.var in self.colors.keys() else self.color
#		self.get_color 	= tuple (self.colors[self.var]) if self.var in self.colors.keys() else tuple (self.color)
		self.ax				= kwargs.get('ax',None)
		self.savefig		= type(self.ax) == type(None)
		
		self.no_plot = []

		self.resol        = 'm' if self.Anual else '1h' 
		if type(self.df) == type(None):  
			self.df = self.Contaminante[self.var] if self.var in self.nombre_contaminantes else (self.Meteo[self.var] if self.var in self.nombre_meteorologicas else self.ContaminanteManual[self.var])
		
		print '------------------------'
		print self.var
		print '------------------------'
		
		#~ ylim		= kwargs.get('ylim',self.limC[self.resol][var])
		
		#Prueba para graficar necesarios
		self.c=[]
		for i in range(self.df.columns.size):
			try:
				#~ df[df.columns[i]].groupby(lambda x: x.hour).quantile([.75]).unstack().dropna().plot(kind='area',legend=False)
				#~ df[df.columns[i]].groupby(lambda x: x.hour).quantile([.25]).unstack().dropna().plot(kind='area', legend=False)
				self.df[self.df.columns[i]].groupby(lambda x:(x.month if self.Anual else (x.weekday() if self.Semanal else x.hour))).quantile(.5).plot(legend=False)
				self.c.append(i)
			except:
				#self.no_plot.append(var+' '+df.columns[i])
				pass
		print self.c
		
		
		#~ if len(self.c)>0:
			#~ self.ylabelrow = (len(self.c)-1)/4 
			#~ self.pos = [-4,self.limC[self.resol][self.var][1]/2.] if (len(self.c)-1)%4 < 2 else [-4,-self.limC[self.resol][self.var][1]*.2]
		
		#~ plt.close('all')
		#~ self.fig = plt.figure(figsize=(6, 2.3*(len(self.c)/2+len(self.c)%2)),facecolor='w',edgecolor='w')
		#~ plt.subplots_adjust(wspace=.2,hspace=.35,bottom=0.1,left=0.1,right=0.90,top=0.9)
		#fig.subplots_adjust(wspace = .3, hspace = .3)
		#~ self.gs = grid.GridSpec(len(self.c)/2+1,4)
		
		#~ self.ax = {} if type(self.ax) == type(None) else self.ax
		
		for i in range(len(self.c)):
			#Genera los axis y ubica los subplots
			#~ if self.subplots:
				#~ print i
				#~ if (i+1 == len(self.c)) & ((i+1)%2 == 1):
					#~ self.col = (1,3)
					#~ self.row = i/2
					#~ self.yl  = 0
				#~ else:
					#~ self.col = (0,2) if i < len(self.c)/2 else (2,4)
					#~ self.row = i%(len(self.c)/2)
					#~ self.yl  = 0 if i < len(self.c)/2 else 1
				
				#~ self.ax[i]		=	plt.subplot(self.gs[self.row, self.col[0]:self.col[1]])
			
			#Genera un figure paca cada estación
			#~ else: 
			if self.savefig: 
				plt.close('all')
				self.fig = plt.figure(figsize=(4.2, 2.3),facecolor='w',edgecolor='w')
				plt.subplots_adjust(wspace=.2,hspace=.35,bottom=0.1,left=0.1,right=0.90,top=0.9)
				self.ax	=	self.fig.add_subplot(111) 
			
			
			self.ax.spines['top'].set_visible(False)
			self.ax.spines['right'].set_visible(False)
			self.ax.spines['left'].set_color((0.45, 0.45, 0.45))
			self.ax.spines['bottom'].set_color((0.45, 0.45, 0.45))
			self.ax.tick_params(top='off', right='off',bottom='on',left='on',which='both',color=(0.45, 0.45, 0.45),labelsize=self.fontsize)
			self.ax.xaxis.label.set_color((0.45, 0.45, 0.45))
			self.ax.yaxis.label.set_color((0.45, 0.45, 0.45))
			
			if self.Semanal:
				self.sem = self.df[self.df.columns[self.c[i]]].groupby(lambda x: x.weekday()).median()
				self.sem.index = self.sem.index.values +1
				self.ax.bar(self.sem.index.values-.25,self.sem.values,.5,color=[self.get_color[2]]*7,edgecolor='w',alpha=1)
				
				self.rects = self.ax.patches
				for rect in self.rects:
					self.height = rect.get_height()
					self.ax.text(rect.get_x() + rect.get_width()/2. , self.height*1.02, '%.f' %self.height if self.height!=0 else ' ', ha='center',va='bottom',fontsize=self.fontsize, fontproperties=prop_1,color=(0.45, 0.45, 0.45))
				self.ax.set_xticks([1,2,3,4,5,6,7])
				self.ax.set_xlim(0.5,7.5)
				self.ax.set_ylim(self.df.groupby(lambda x: x.weekday()).median().min().min() - 5,self.df.groupby(lambda x: x.weekday()).median().max().max() + 5) #self.limC['w'][var])
			
			else:
				self.ylim = (self.df.groupby(lambda x:(x.month if self.Anual else x.hour)).quantile(.25).min().min()-5, self.df.groupby(lambda x:(x.month if self.Anual else x.hour)).quantile(.75).max().max()+5)
				self.df[self.df.columns[self.c[i]]].groupby(lambda x: (x.month if self.Anual else x.hour)).quantile(.75).plot(ax=self.ax,legend=False,color=self.get_color[1],style='--',lw=.6,alpha=1)
				self.df[self.df.columns[self.c[i]]].groupby(lambda x: (x.month if self.Anual else x.hour)).quantile(.25).plot(ax=self.ax,legend=False,color=self.get_color[1],style='--',lw=.6,alpha=1)
				self.df[self.df.columns[self.c[i]]].groupby(lambda x:(x.month if self.Anual else x.hour)).quantile(.5).plot(ax=self.ax,legend=False,color=self.get_color[3],ylim=self.ylim,lw=2)
				if self.percen10_90:	
					self.ylim = (self.df.groupby(lambda x:(x.month if self.Anual else x.hour)).quantile(.10).min().min()-5, self.df.groupby(lambda x:(x.month if self.Anual else x.hour)).quantile(.90).min().min()+5)
					self.df[self.df.columns[self.c[i]]].groupby(lambda x: (x.month if self.Anual else x.hour)).quantile([.1,.9]).unstack().plot(ax=self.ax,legend=False,color=[self.get_color[0]],	style=':',ylim=self.ylim)

			ticks_aux = [tick_elem for tick_elem in self.ax.get_xticks () if tick_elem >= 0]
			self.ax.set_xticks (ticks_aux)

			#~ fill = df[df.columns[c[i]]].groupby(lambda x: (x.month if Anual else x.hour)).quantile([.75,.25]).unstack()#		color=[(0.875,0.875,0.875),'w']
			#~ ax[i].fill_between(fill.index.values,fill[0.25].values,fill[0.75].values,color=(0.875,0.875,0.875))
			
			
			if self.title: self.ax.set_title(self.Est['Nombre_Largo'][self.Est['Nombre'] == self.df.columns[self.c[i]]].values[0].decode('utf-8'),loc='center',fontproperties=prop_2,color=(0.45, 0.45, 0.45),fontsize=self.fontsize)
			#~ ax[i].text(22.5,self.limC[self.resol][var][1], title, horizontalalignment='right',verticalalignment='bottom',
				#~ fontsize='xx-small',fontproperties=prop_2)#,bbox={'facecolor':(0.32,0.71,0.77), 'alpha':0.2, 'pad':2,'edgecolor':'w'})
			if self.Semanal!=True: self.ax.locator_params(axis='y',nbins=6)
			if self.Semanal!=True: self.ax.locator_params(axis='x',nbins=6)
			
			self.ticks = self.ax.get_xticks()
						
#			print "*****************************************************"
#			print self.Est['Nombre'][self.Est['Nombre'] == self.df.columns[self.c[i]]].values[0].decode('utf-8')
#			print self.ticks
#			print "*****************************************************"

			self.labelciclodiurno = [dt.datetime.strptime('%.f' %(1 if j==0 else j), '%m').strftime('%b') for j in self.ticks[:]] if self.Anual else ([self.dias_es['%.f' %j] for j in self.ticks] if self.Semanal else [dt.datetime.strptime('%.f' %j, '%H').strftime('%H:%M') for j in self.ticks[:-1]])  #[1,2,3,4,5,6,0]
			self.ax.set_xticklabels(self.labelciclodiurno,fontproperties=prop_1,fontsize=self.fontsize)
			#~ if self.yl == 1: self.ax.set_yticklabels('')  
			#~ else:	
			self.ax.set_yticklabels(['%.f' % x for x in self.ax.get_yticks()],fontproperties=prop_1,fontsize=self.fontsize)
			
			self.diurno = 'anual' if self.Anual else ('semanal' if self.Semanal else 'diurno')
			
			if self.legend:
				self.legenda = i if self.subplots else (1 if self.Semanal else 0)
				if (self.legenda == 0) : 
					plt.rcParams['legend.numpoints']=1 
					#~ iqr     = plt.Line2D((0,1),(0,0),color=(0.875,0.875,0.875),marker='s',linestyle='',fillstyle='full',markeredgecolor='w')#(0.007,0.32,0.36))
					self.iqr     = plt.Line2D((0,1),(0,0),color=self.get_color[1],linestyle='--')#(0.007,0.32,0.36))
					self.mediana = plt.Line2D((0,1),(0,0),color=self.get_color[3],linestyle='-',lw=2)
					if self.percen10_90: self.per     = plt.Line2D((0,1),(0,0),color=self.get_color[0],linestyle=':')
					self.box = (1.,1.4) if (len(self.c)>1) & (self.subplots) else (0.5,-.25)
					
					if self.percen10_90: self.leg=plt.legend([self.iqr,self.mediana,self.per],['RIQ','Mediana','Percentiles 10 y 90'],bbox_to_anchor=self.box,fontsize=self.fontsize, ncol=3,loc='center')
					else: self.leg=plt.legend([self.iqr,self.mediana],['RIQ','Mediana'],bbox_to_anchor=self.box,fontsize=self.fontsize, ncol=2,loc='center')
					self.leg.get_frame().set_edgecolor((0.45, 0.45, 0.45))
					for text in self.leg.get_texts(): plt.setp(text, color = (0.45, 0.45, 0.45))
				
			self.ax.set_ylabel(self.label[self.var],fontproperties=prop_1 ,fontsize=self.fontsize)
			self.varsave = 'PM25' if (self.var =='PM2.5') else 'PM25M' if (self.var=='PM2.5M') else  self.var
			if self.savefig:
				print ('scp Figuras/%s/Ciclo_%s_%s_%s%s.pdf %s%s/' %(self.varsave,self.diurno,self.varsave,self.df.columns[self.c[i]],self.textsave,self.path,self.varsave))
				plt.savefig('Figuras/%s/Ciclo_%s_%s_%s%s.pdf' %(self.varsave,self.diurno,self.varsave,self.df.columns[self.c[i]],self.textsave),bbox_inches='tight')
				os.system('scp Figuras/%s/Ciclo_%s_%s_%s%s.pdf %s%s/' %(self.varsave,self.diurno,self.varsave,self.df.columns[self.c[i]],self.textsave,self.path,self.varsave))
				self.ax = None

		#~ if self.subplots:
			#~ self.ax[self.ylabelrow].text(self.pos[0],self.pos[1],self.label[self.var],fontproperties = prop_1,rotation=90,va='center',ha='center',fontsize='small',color=(0.45, 0.45, 0.45))
			
			#~ self.varsave = 'PM25' if (self.var =='PM2.5') else 'PM25M' if (self.var=='PM2.5M') else  self.var
			#~ plt.savefig('Figuras/%s/Ciclo_%s_%s%s.pdf' %(self.varsave,self.diurno,self.varsave,self.textsave),bbox_inches='tight')
			#~ os.system('scp Figuras/%s/Ciclo_%s_%s%s.pdf jhernandezv@siata.gov.co:/var/www/jhernandezv/RedAire/Informe_Mensual/%s/' %(self.varsave,self.diurno,self.varsave,self.textsave,self.varsave))

	def Plot_ICA_Resumen(self,*args,**kwargs):

		self.fontsize		= kwargs.get('fontsize',12)
		self.resol		= kwargs.get('resolucion','D')
		self.Medellin		= kwargs.get('Medellin',True)

		if   self.resol == 'D':  self.resolucion = 'diario'
		elif self.resol == '8h': self.resolucion = 'octohorario'
		elif self.resol == '1h': self.resolucion = 'horario'
		else: pass

		self.varresol 		= '%s-%s' %(self.var,self.resol)
		self.df 			= self.Contaminante[self.var] if self.var in self.nombre_contaminantes else self.ContaminanteManual[self.var]
		self.estaciones 	= self.Est[self.Est['Nombre'].isin( self.ICA[self.varresol].columns.values)].sort_values(by='Latitud',ascending=False)['Nombre'].values[::-1]

		#Para dividir entre estaciones de Medellin y demas del valle
		if (self.var=='PM2.5') and self.Medellin: self.estaciones = ['MED-ARAN', 'MED-VILL', 'MED-SCRI', 'MED-UNNV', 'CEN-TRAF', 'MED-BEME', 'MED-ALTA', 'MED-TESO', 'MED-LAYE']
		if (self.var=='PM2.5') and (self.Medellin==False): self.estaciones = ['BAR-TORR', 'GIR-SOSN', 'COP-CVID', 'BEL-FEVE', 'ITA-CJUS', 'ENV-HOSP', 'ITA-CONC', 'SAB-JOFE', 'SUR-TRAF','EST-HOSP', 'CAL-LASA']

#Esto es para pm25 viejo	self.estaciones = ['GIR-SOSN', 'MED-UNNV', 'MED-MANT', 'ITA-CJUS', 'MED-LAYE', 'ITA-CONC', 'SUR-TRAF', 'CAL-LASA']

		if kwargs.get('Mensual',False):
			self.porcentaje = {} #pd.DataFrame()
			for i in range(4):
				self.porcentaje[self.labelica[i]] = self.ICA[self.varresol].groupby(lambda x: x.month).apply(lambda x: x[(x >= self.RangosICA[self.varresol]['Ilo'][i]) & (x < self.RangosICA[self.varresol]['Ihi'][i])].count() /x.count()*100)
			self.porcentaje = pd.concat(self.porcentaje,axis=1)
			self.nplots = self.estaciones.size
		else:

			self.porcentaje = pd.DataFrame()
			for i in range(4):
				self.porcentaje[self.labelica[i]] = self.ICA[self.varresol][(self.ICA[self.varresol] >= self.RangosICA[self.varresol]['Ilo'][i]) & (self.ICA[self.varresol] < self.RangosICA[self.varresol]['Ihi'][i])][self.estaciones].count() /self.ICA[self.varresol][self.estaciones].count()*100

			nplots = 1 #if 'stacked' not in kwargs.keys() else  self.estaciones.size / 5 + 1

		for i in range(nplots):
			plt.close('all')
			self.fig 			= plt.figure(figsize=(self.porcentaje.index.size*(.92 if kwargs.get('Mensual',False) else 1.25),4 if 'stacked' in kwargs.keys() else 5),facecolor='w',edgecolor='w')
			self.ax 			= self.fig.add_subplot(111)
			plt.rcParams["axes.labelsize"] = self.fontsize

			for spinename, spine in self.ax.spines.iteritems():
				spine.set_visible(False)

			self.ax.yaxis.label.set_color((0.45, 0.45, 0.45))
			self.ax.xaxis.label.set_color((0.45, 0.45, 0.45))

			if 'stacked' not in kwargs.keys():
				self.ax.spines['left'].set_visible(True)
				self.ax.spines['left'].set_color((0.45, 0.45, 0.45))
				self.ax.spines['right'].set_visible(True)
				self.ax.spines['right'].set_color((0.45, 0.45, 0.45))
				self.ax.tick_params(top='off', bottom='off',right='on',left='on',which='both',color=(0.45, 0.45, 0.45),direction='in',labelsize=self.fontsize)

			else :
				 self.ax.tick_params(labelleft='off',left='off',bottom='off',right='off',top='off',which='both',color=(0.45, 0.45, 0.45))

			if kwargs.get('Mensual',False):
				self.porcentaje.xs(self.estaciones[i],axis=1,level=1)[self.labelica].plot(kind='bar',ax=self.ax,stacked=kwargs.get('stacked',True),color=self.RangosICA[self.varresol]['color'][:4],ylim=(0,100),edgecolor='w',alpha=.6,legend=False)
				self.ax.set_xticklabels(map(lambda x: dt.datetime.strptime('%d' %(x+1),'%m').strftime('%b'),self.ax.get_xticks()),rotation='horizontal',fontsize='x-small', fontproperties=prop_2)
				self.title = self.Est['Nombre_Largo'][self.Est['Nombre'] == self.estaciones[i]].values[0].decode('utf-8')
				self.ax.set_title(self.title,loc='right',fontsize=self.fontsize,fontproperties=prop_2,color=(0.45, 0.45, 0.45))

			else:
				self.porcentaje.plot(kind='bar',width=(1 if 'stacked' in kwargs.keys() else .5),ax=self.ax,stacked=kwargs.get('stacked',True),color=self.RangosICA[self.varresol]['color'][:4],ylim=(0,100),edgecolor=(0.45, 0.45, 0.45) if (self.var=='Ozono') & (self.resol=='1h') else 'w',alpha=.6,legend=False)
				self.ax.set_xticklabels(self.ax.get_xticklabels(),rotation='horizontal',fontsize=self.fontsize-4,fontproperties=prop_2)

			if 'stacked' not in kwargs.keys():
				self.leg 	= self.ax.legend(bbox_to_anchor=(1.01,.5),loc='center left',fontsize=self.fontsize,framealpha=0.3) if self.var == 'SO2' else self.ax.legend(bbox_to_anchor=(.5,-.15),loc='center',fontsize=self.fontsize,framealpha=0.3,ncol=4)
				for text in self.leg.get_texts(): plt.setp(text, color = (0.45, 0.45, 0.45))
				self.ax.set_ylabel('Porcentaje ICA %s %s [%%]' %(self.var,self.ICA[self.varresol].index[0].strftime('%Y')),fontsize=self.fontsize,color=(0.45, 0.45, 0.45),fontproperties=prop_1)
				self.ax.set_yticks(range(0,101,5),minor=True)
				self.ax.yaxis.grid(linestyle='--', linewidth=.5,color=(0.45, 0.45, 0.45),alpha=0.4)

			else:
				self.exc 			= self.df.rolling(8,freq='1h').mean() if self.resol=='8h' else self.df.resample(self.resol).mean()
				self.excedencia 	= self.exc[self.exc > self.norma[self.resol][self.var]].count()/self.exc.count()*100
				for tick in self.ax.get_xticks():
					if tick ==0:
						self.ax.text(-.8,-15,'Muestras',fontsize=self.fontsize,fontproperties=prop,color=(0.45, 0.45, 0.45),ha='center',va='center')
						self.ax.text(-.8,-25,'Excedencias\nNorma [%]',fontsize=self.fontsize,fontproperties=prop,color=(0.45, 0.45, 0.45),ha='center',va='center')
					self.ax.text(tick,-15, '%d' %self.ICA[self.varresol][self.estaciones[tick]].count(),fontsize=self.fontsize,fontproperties=prop_1,color=(0.45, 0.45, 0.45),ha='center',va='center')

					self.ax.text(tick,-25, '%.1f' %self.excedencia[self.estaciones[tick]] ,fontsize=self.fontsize,fontproperties=prop_1,color=(0.45, 0.45, 0.45),ha='center',va='center')

				#self.ax.set_ylabel('Porcentaje ICA %s %s %s' %(('%s Manual' %self.var[:-1]) if self.var in ['PM2.5M','PM10M'] else self.var,self.resolucion,self.ICA[self.varresol].index[0].strftime('%Y-%m')),fontsize = self.fontsize,fontproperties=prop,color= (0.45, 0.45, 0.45))
				self.ax.set_ylabel('Porcentaje ICA %s %s %s' %(('%s Manual' %self.var[:-1]) if self.var in ['PM2.5M','PM10M'] else self.var,self.resolucion,self.ICA[self.varresol].index[0].strftime('%Y')),fontsize = self.fontsize,fontproperties=prop,color= (0.45, 0.45, 0.45))

				#~ if kwargs.get('loc_text','top')=='bottom':
					#~ for i in range(5):
						#~ if ((i == 0) | (i>=3)) & ((porcentaje[i]>= 8) | (porcentaje[i]== 0) | (np.isnan(porcentaje[i]))):	cc = 'w'
						#~ elif (i>0) & (i<3) & ((porcentaje[i] == 0) |(np.isnan(porcentaje[i]))): cc = 'w'
						#~ else:											cc = (0.45, 0.45, 0.45)
						#~ ax[c].text(i,6,'%.1f \n' %porcentaje[i] + ur'$\%$' , fontsize=self.fontsize-3,fontproperties=prop_2,ha='center',va='center',color=cc)

				if kwargs.get('loc_text','top')=='top':
					self.rects = self.ax.patches
					for rect in self.rects:
						self.height = rect.get_height()
						self.ax.text(rect.get_x() + rect.get_width()/2. , self.height+2, '%.1f\n%%' %self.height if self.height!=0 else ' ', ha='center',va='bottom',fontsize=self.fontsize-4, color=(0.45, 0.45, 0.45),fontproperties=prop)

			self.ax.set_xlabel('')

			self.varsave = 'PM25' if self.var =='PM2.5' else self.var
			self.varsave2 = 'PM25-D' if self.varresol == 'PM2.5-D' else self.varresol
			if (self.var=='PM2.5') and (self.Medellin):	self.varsave2 = self.varsave2 + 'Med'

			plt.savefig('Figuras/%s/ICA_%s_%s%s%s.pdf' %(self.varsave,'Histograma' if 'stacked' in kwargs.keys() else 'Resumen',self.varsave2,'_%s' %self.estaciones[i] if kwargs.get('Mensual',False) else '',kwargs.get('textsave','')),bbox_inches='tight')
			os.system('scp Figuras/%s/ICA_%s_%s%s%s.pdf nroldan@siata.gov.co:/var/www/CalidadAire/Figuras/%s/' %(self.varsave,'Histograma' if 'stacked' in kwargs.keys() else 'Resumen',self.varsave2,'_%s' %self.estaciones[i] if kwargs.get('Mensual',False) else '',kwargs.get('textsave',''),self.varsave))

			if kwargs.get('Procuraduria',False): os.system('scp Figuras/%s/ICA_%s_%s.pdf calidadaire@192.168.1.10:Informe_Procuraduria/Graficos_ICA/' %(self.varsave,'Histograma' if 'stacked' in kwargs.keys() else 'Resumen',self.varsave2) )


	def Plot_ICA_Hist(self,*args,**kwargs):
		"""Genera un histograma de los rangos respectivos al indice de calidad
			del aire para las fechas consultadas"""
		
		
		self.resol 		= kwargs.get('resolucion','D')
		self.textsave		= kwargs.get('textsave',None)
		self.fontsize		= kwargs.get('fontsize',10)
		loc_text		= kwargs.get('loc_text','bottom')
		title			= kwargs.get('title',True)
		title2			= kwargs.get('title2',False)
		ylabel			= kwargs.get('ylabel',False)
		legend			= kwargs.get('legend',False)
		

		varsave = 'PM25' if (var =='PM2.5') else 'PM25M' if (var=='PM2.5M') else  var

		if   self.resol == 'D':  resolucion = 'diario'		 ; datesize = 1
		elif self.resol == '8h': resolucion = 'octohorario' 	; datesize = 3
		elif self.resol == '1h': resolucion = 'horario'	    ; datesize = 24
		else: pass
		
		varresol 	= '%s-%s' %(var,self.resol)
		df			= self.Contaminante if var in self.nombre_contaminantes else self.ContaminanteManual
		ticksdate 	= pd.date_range(self.ICA[varresol].index[0],self.ICA[varresol].index[-1],freq=self.resol).size
		estaciones 	= self.Est[self.Est['Nombre'].isin(self.ICA[varresol].columns.values)].sort_values(by='Latitud',ascending=False)['Nombre'].values[::-1]
		textizq		=-4.2*datesize
		
		if len(estaciones) <= 5:
			naxis 	= len(estaciones)
			falta 	= 0
		else:
			naxis 	= 5
			falta 	= len(estaciones) -5
		
		c 			= 0
		ce 			= 0
		number 		=''
		while c < naxis:
			if c == 0:
				plt.close('all')
				fig = plt.figure(figsize=(1.7*naxis,3),facecolor='w',edgecolor='w')
				plt.subplots_adjust(wspace=0,hspace=.3,bottom=0.1,left=0.1,right=0.90,top=0.9)
				plt.rcParams["xtick.labelsize"]=self.fontsize
				plt.rcParams["ytick.labelsize"]=self.fontsize
				plt.rcParams["axes.labelsize"]=self.fontsize
				ax={}
			ax[c]= fig.add_subplot(1, naxis, c+1)
			plt.setp(ax[c].spines.values(), color='w')
			#~ ax[c].tick_params(labeltop='off', labelright='off',labelleft='off',labelbottom='off',colors=(0.504,0.5,0.5))
			ax[c].tick_params(axis=u'both', which=u'both',length=0,color='w' )#, color=(0.504,0.5,0.5))
			
			porcentaje = np.empty(5)
			color,edge = [],[]
			for i in range(5):
				porcentaje[i] = self.ICA[varresol][(self.ICA[varresol] >= self.RangosICA[varresol]['Ilo'][i]) & 
					(self.ICA[varresol] < self.RangosICA[varresol]['Ihi'][i])][estaciones[ce]].count() 
				color.append( self.RangosICA[varresol]['color'][i] )
				edge.append('w' if self.RangosICA[varresol]['color'][i] != 'w' else (0.504,0.5,0.5))
			porcentaje = porcentaje/float(self.ICA[varresol][estaciones[ce]].count())*100
			
			ax[c].set_xlim(0,5)
			ax[c].set_ylim(0,105)
			ax[c].bar(left=range(5),height=porcentaje,width=1,color=color,lw=.1,edgecolor=edge,alpha=.6)
			
			if loc_text=='bottom':
				for i in range(5):
					if ((i == 0) | (i>=3)) & ((porcentaje[i]>= 8) | (porcentaje[i]== 0) | (np.isnan(porcentaje[i]))):	cc = 'w'
					elif (i>0) & (i<3) & ((porcentaje[i] == 0) |(np.isnan(porcentaje[i]))): cc = 'w'
					else:											cc = (0.45, 0.45, 0.45)
					ax[c].text(i,6,'%.1f \n' %porcentaje[i] + ur'$\%$' , fontsize=self.fontsize-3,fontproperties=prop_2,ha='center',va='center',color=cc)
			
			elif loc_text=='top':
				rects = ax[c].patches
				for rect in rects:
					height = rect.get_height()
					ax[c].text(rect.get_x() + rect.get_width()/2. , height*1.02, '%.1f%%' %height if height!=0 else ' ', ha='center',va='bottom',fontsize=self.fontsize-2, color=(0.45, 0.45, 0.45),weight='bold')
			
			if (c == 0) & (title): ax[c].text(0,104,'Registros desde (%s a %s)' %(pd.to_datetime(self.Fechai).strftime('%Y-%m-%d'), pd.to_datetime(self.Fechaf).strftime('%Y-%m-%d')),fontsize=self.fontsize-2,fontproperties=prop_1,color=(0.45, 0.45, 0.45),ha='left',va='bottom')
			
			if (c == 0) & (title2): ax[c].text(0,108,'Porcentaje ICA %s %s %s' %(('%s Manual' %var[:-1]) if var in ['PM2.5M','PM10M'] else var,resolucion,self.ICA[varresol].index[0].strftime('%Y')),fontsize=self.fontsize,fontproperties=prop_2,color=(0.45, 0.45, 0.45),ha='left',va='bottom')
			
			if (c == 0) & (ylabel): ax[c].set_ylabel('Porcentaje ICA %s %s %s' %(('%s Manual' %var[:-1]) if var in ['PM2.5M','PM10M'] else var,resolucion,self.ICA[varresol].index[0].strftime('%Y')),fontsize = self.fontsize-2,fontproperties=prop_1,color= (0.45, 0.45, 0.45))
			
			if  (c == 0) & (legend):
				plt.rcParams['legend.numpoints']=1 
				v	= plt.Line2D((0,1),(0,0),color=self.RangosICA[varresol]['color'][0],marker='s',mec=self.RangosICA[varresol]['color'][0],ms=10,lw=0,alpha=.6)
				a	= plt.Line2D((0,1),(0,0),color=self.RangosICA[varresol]['color'][1],marker='s',mec=self.RangosICA[varresol]['color'][1],ms=10,lw=0,alpha=.6)
				n	= plt.Line2D((0,1),(0,0),color=self.RangosICA[varresol]['color'][2],marker='s',mec=self.RangosICA[varresol]['color'][2],ms=10,lw=0,alpha=.6)
				r	= plt.Line2D((0,1),(0,0),color=self.RangosICA[varresol]['color'][3],marker='s',mec=self.RangosICA[varresol]['color'][3],ms=10,lw=0,alpha=.6)
				leg = ax[c].legend([v,a,n,r],self.labelica,bbox_to_anchor=(1.01,.5),loc='center left',fontsize=self.fontsize-2,framealpha=0.3) if var == 'SO2' else ax[c].legend([v,a,n,r],self.labelica, bbox_to_anchor=(0.,-.35),loc='center left',fontsize=self.fontsize-2,framealpha=0.3,ncol=4)
				leg.get_frame().set_edgecolor((0.45, 0.45, 0.45))
				for text in leg.get_texts(): plt.setp(text, color = (0.45, 0.45, 0.45))
			
			#~ ax[c].set_xticks([2.5])
			ax[c].set_xticklabels('')
			ax[c].set_yticklabels('')
			ax[c].text(2.5,-5,estaciones[ce],fontproperties=prop_2,fontsize=self.fontsize,color=(0.45, 0.45, 0.45),ha='center',va='center')
			ax[c].text(2.5,-15, '%d Muestras' %self.ICA[varresol][estaciones[ce]].count(),fontsize=self.fontsize,fontproperties=prop_1,color=(0.45, 0.45, 0.45),ha='center',va='center')
			
			
			exc = df[var].rolling(8,freq='1h').mean() if self.resol=='8h' else df[var].resample(self.resol).mean()
			excedencia = exc[exc > self.norma[self.resol][var]][estaciones[ce]].count()/float(exc[estaciones[ce]].count())*100
			ax[c].text(2.5,-23, '%.2f' %excedencia +ur'$\%$ Excedencias' ,fontsize=self.fontsize,fontproperties=prop_1,color=(0.45, 0.45, 0.45),ha='center',va='center')
			#~ except: pass
			c +=1
			ce+=1
			if (c == naxis):
				var1 = 'PM25' if var =='PM2.5' else ('PM25M' if var=='PM2.5M' else var)
				var2 = 'PM25-D' if varresol == 'PM2.5-D' else 'PM25M-D'if varresol == 'PM2.5M-D' else varresol

				if textsave!=None:
					plt.savefig('Figuras/ICA_Hist_%s_%s.pdf' %(var1,textsave),bbox_inches='tight')
					os.system('scp Figuras/ICA_Hist_%s_%s.pdf nroldan@siata.gov.co:/var/www/CalidadAire/Figuras/' %(var1,textsave))
				else:
					plt.savefig('Figuras/%s/ICA_Hist_%s%s.pdf' %(var1,var2,number),bbox_inches='tight')
					os.system('scp Figuras/%s/ICA_Hist_%s%s.pdf nroldan@siata.gov.co:/var/www/CalidadAire/Figuras/%s/' %(var1,var2,number,var1))
				if kwargs.get('Procuraduria',False): os.system('scp Figuras/%s/ICA_Hist_%s%s.pdf calidadaire@192.168.1.10:Informe_Procuraduria/Graficos_ICA/' %(var1,var2,number))
				if (falta != 0):
					naxis = falta
					falta = 0
					c=0
					number=2
					title=False 

	def Plot_ICA_Anual(self,*args,**kwargs):

		var 			= self.var
		C 				= self.Contaminante
		textsave		= kwargs.get('textsave','')
		self.resol 		= kwargs.get('resolucion','D')
		fontsize		= kwargs.get('fontsize','x-small')
		if   self.resol == 'D':  resolucion = 'Diaria'		 ; datesize = 1
		elif self.resol == '8h': resolucion = 'Octohoraria' 	; datesize = 3
		elif self.resol == '1h': resolucion = 'Horaria'	    ; datesize = 24
		else: pass

		varresol = '%s-%s' %(var,self.resol)
		ticksdate = pd.date_range(self.ICA[varresol].index[0],self.ICA[varresol].index[-1],freq=self.resol)

		textizq=-70*datesize
		how = 'mean' if var != 'PLiquida_SSR' else 'sum'
		no_in		= []

		if var != 'PM2.5':
			estaciones = self.Est[self.Est['Nombre'].isin( self.ICA[varresol].columns.values)].sort_values(by='Latitud',ascending=False)['Nombre'].values[::-1]
		else:
			estaciones = ['GIR-SOSN','MED-UNNV', 'MED-LAYE', 'ITA-CJUS', 'ITA-CONC', 'CAL-LASA','NO-EST', 'CEN-TRAF', 'SUR-TRAF'][::-1]
			#estaciones = ['BAR-TORR','GIR-SOSN','COP-CVID', 'BEL-FEVE', 'MED-ARAN', 'MED-SCRI', 'MED-UNNV', 'MED-VILL', 'MED-BEME', 'MED-ALTA', 'MED-TESO', 'MED-LAYE', 'ITA-CJUS', 'ITA-CONC','EST-HOSP', 'ENV-HOSP','SAB-JOFE', 'CAL-LASA', 'NO-EST', 'MED-MANT', 'SUR-TRAF'][::-1]
			x = self.Est[self.Est['Nombre'].isin( self.ICA[varresol].columns.values)]['Nombre'].values

			for est in estaciones:
				if est not in x: no_in.append(est)
		df = self.ICA[varresol]

		if len(no_in) > 0:
			for est in no_in: 
				df[est] = np.NaN
				C[est]	= np.NaN
		df = df.loc[:,estaciones]
		C = C.loc[:,estaciones]

		plt.close('all')
		#~ fig = plt.figure(figsize=(0.1*(self.ICA[varresol].columns.size),(ticksdate.size)*.1),facecolor='w',edgecolor='w') #.42, 0.025
		fig = plt.figure(figsize=((6+ticksdate.size)*0.035, 0.42*(4+df.columns.size)),facecolor='w',edgecolor='w')

		ax={}
		i=0
		ax[i]= fig.add_subplot(111)
		plt.setp(ax[i].spines.values(), color=(0.45, 0.45, 0.45))
		ax[i].tick_params( which=u'both',top='off',bottom='off',left='off',right='off', color=(0.45, 0.45, 0.45))
		ax[i].xaxis.label.set_color((0.45, 0.45, 0.45))
		ax[i].yaxis.label.set_color((0.45, 0.45, 0.45))

		#contorno
		cmap = mpl.colors.ListedColormap([(0.875,0.875,0.875)]+self.RangosICA[varresol]['color'])
		bounds       = [-50,0,51,101,151,201,301,501]
		bounds_ticks = [-50,0,51,101,151,201,301,501]
		norm = mpl.colors.BoundaryNorm(bounds, cmap.N)

		contf = ax[0].imshow(df.resample(self.resol).mean()[estaciones].fillna(-10).T.values,interpolation='nearest',cmap=cmap, aspect='auto', origin='lower',
			extent=[0,ticksdate.size,0,df.columns.size],norm=norm)

		#~ ax[i].set_xticks(np.arange(.5,self.ICA[varresol].columns.size))
		#~ ax[i].set_xticklabels(estaciones,rotation='vertical',fontsize=fontsize) #['%s\n%s' %(est[:4],est[4:]) for est in estaciones]
		#~ ax[i].set_yticks([0]+[int(mes.strftime('%j')) for mes in meses])
		#~ ax[i].invert_yaxis()
		#~ ticks = self.ICA[varresol].resample('m',how='mean').index
		#~ ax[i].set_yticklabels([t.strftime('%b\n %Y' if t.strftime('%m')=='01' else '%b') for t in ticks],rotation='horizontal',fontsize=fontsize)

		#Valores numericos
		for i in range(df.columns.size):
			ax[0].text(textizq,i+0.75,'%s' %'' if estaciones[i] =='NO-EST' else estaciones[i][:3],ha='left',va='center',fontsize=fontsize,fontproperties=prop_1)
			ax[0].text(textizq,i+0.25,'%s' %'' if estaciones[i] =='NO-EST' else self.Est[self.Est['Nombre'].isin([estaciones[i]])]['Nombre_Estacion'].values[0],ha='left',va='center',fontsize=fontsize,fontproperties=prop)
			ax[0].axhline(i,color='w',lw=1)


		ax[0].axhline(len(estaciones)+1,xmin=np.abs(textizq-10)/float(ticksdate.size+10+np.abs(textizq-10)), xmax=float(ticksdate.size+np.abs(textizq-10))/(ticksdate.size+10+np.abs(textizq-10)),color='k',lw=2.5)
		ax[0].text(textizq,df.columns.size+.6,u'Estaciones',ha='left',va='center',fontsize='small',fontproperties=prop_2)
		#Fechas

		meses = pd.date_range(df.index[0],df.index[-1],freq='m') + dt.timedelta(days=1)
		ticks = df.resample('m').mean().index
		ticklabel=[t.strftime('%b') for t in ticks]
		c=0
		for j in [0]+[int(mes.strftime('%j')) for mes in meses[:-1]]:
			ax[0].text(j+0.5,df.columns.size+1.5,ticklabel[c],fontsize='small',ha='left',va='center',fontproperties=prop_1)
			ax[0].axvline(x=j,ymax=(len(estaciones)+.5)/(len(estaciones)+4.),color='w',lw=1)
			if (j==0) | (ticksdate[j].day ==1): ax[0].text(j+.1, df.columns.size+2.1,'%s' %ticksdate[j].strftime('%Y'),ha='left',va='bottom',fontsize='small',fontproperties=prop_2)
			c+=1

		if var == 'PM2.5': 
			ax[0].axhspan(2,3,fc='w',ec='w')
			#ax[0].axhspan(1,2,fc='w',ec='w')
			ax[0].text(0,2.6,'DE TRÁFICO',ha='left',va='center',fontsize=fontsize,fontproperties=prop_1)
			#ax[0].text(0,1.6,'DE TRÁFICO',ha='left',va='center',fontsize=fontsize,fontproperties=prop_1)
			ax[0].axhline(2.15,xmin=np.abs(textizq-10)/float(ticksdate.size+10+np.abs(textizq-10)), xmax=(ticksdate.size+np.abs(textizq-10))/float(ticksdate.size+10+np.abs(textizq-10)),color=(0.45, 0.45, 0.45),lw=1)
			#ax[0].axhline(1.15,xmin=np.abs(textizq-10)/float(ticksdate.size+10+np.abs(textizq-10)), xmax=(ticksdate.size+np.abs(textizq-10))/float(ticksdate.size+10+np.abs(textizq-10)),color=(0.45, 0.45, 0.45),lw=1)
			ax[0].text(0,df.columns.size+.6,'DE REPRESENTACIÓN POBLACIONAL',ha='left',va='center',fontsize=fontsize,fontproperties=prop_1)
			ax[0].axhline(df.columns.size+.15,xmin =10./(ticksdate.size+10+np.abs(textizq-10)),xmax=(ticksdate.size+np.abs(textizq-10))/float(ticksdate.size+10+np.abs(textizq-10)),color=(0.45, 0.45, 0.45),lw=1)

		#~ ax[0].add_patch(Rectangle((0,df.columns.size+2), ticksdate.size, 1, facecolor=(0.875,0.875,0.875),edgecolor='w'))
		ax[0].axhspan(df.columns.size+2,df.columns.size+3,xmin=np.abs(textizq-10)/float(ticksdate.size+10+np.abs(textizq-10)), xmax=(ticksdate.size+np.abs(textizq-10))/float(ticksdate.size+10+np.abs(textizq-10)),fc=(0.875,0.875,0.875),ec='w')

		ax[0].axhspan(df.columns.size+2,df.columns.size+3,xmax=np.abs(textizq-10)/float(ticksdate.size+10+np.abs(textizq-10))-.02,fc=(0.875,0.875,0.875),ec='w')
		ax[0].text(textizq,df.columns.size+2.1,var,ha='left',va='bottom',fontsize='small',fontproperties=prop_2)

		ax[0].set_ylim(-.5,len(estaciones)+3.5)
		ax[0].set_xlim(textizq-10,ticksdate.size+10)
		ax[0].set_xticklabels('')
		ax[0].set_yticklabels('')

		varsave = 'PM25' if var =='PM2.5' else var
		varresol = 'PM25-D' if varresol == 'PM2.5-D' else varresol
		plt.savefig('Figuras/%s/ICA_Anual_%s%s.pdf' %(varsave,varresol,textsave),bbox_inches='tight')
		plt.savefig('Figuras/%s/ICA_Anual_%s%s.png' %(varsave,varresol,textsave),bbox_inches='tight')
		os.system('scp Figuras/%s/ICA_Anual_%s%s* nroldan@siata.gov.co:/var/www/CalidadAire/Figuras/%s/' %(varsave,varresol,textsave,varsave))

	def Plot_ICA(self,*args,**kwargs):

		self.Medellin           = kwargs.get('Medellin',False)
		self.Valle              = kwargs.get('Valle',False)
		self.resol 		= kwargs.get('resolucion','D')
		self.textsave	        = kwargs.get('textsave','')
		fontsize 		= kwargs.get('fontsize','x-small' if self.textsave <> '_Semanal' else 'small') #estaba x-small

		C = self.Contaminante[self.var]


		if   self.resol == 'D':  resolucion = 'Diaria'		 ; datesize = 1
		elif self.resol == '8h': resolucion = 'Octohoraria' 	; datesize = 3
		elif self.resol == '1h': resolucion = 'Horaria'	    ; datesize = 24
		else: pass

		self.varresol = '%s-%s' %(self.var,self.resol)
		ticksdate = pd.date_range(self.ICA[self.varresol].index[0],self.ICA[self.varresol].index[-1],freq=self.resol)
		self.varsave = 'PM25' if self.var =='PM2.5' else self.var
		self.varsave2 = 'PM25-D' if self.varresol == 'PM2.5-D' else self.varresol

		if (self.Medellin) and (self.var=='PM2.5'):
			self.varsave2 = self.varsave2 + 'Med'
		if (self.Valle) and (self.var=='PM2.5'):
			self.varsave2 = self.varsave2 + 'Valle'

		self.path			= kwargs.get('path','/var/www/CalidadAire/Figuras/%s/' %self.varsave)

		how = 'mean' if self.var != 'PLiquida_SSR' else 'sum'
		no_in		= []

		if self.var != 'PM2.5':
			estaciones = self.Est[self.Est['Nombre'].isin( self.ICA[self.varresol].columns.values)].sort_values(by='Latitud',ascending=False)['Nombre'].values[::-1]
		else:
			if self.textsave <> '_Semanal':
				#estaciones = ['BAR-TORR','GIR-SOSN','COP-CVID', 'BEL-FEVE', 'MED-ARAN', 'MED-SCRI', 'MED-UNNV', 'MED-VILL', 'MED-BEME', 'MED-ALTA', 'MED-TESO', 'MED-LAYE', 'ITA-CJUS', 'ITA-CONC','EST-HOSP', 'ENV-HOSP','SAB-JOFE', 'CAL-JOAR','CAL-LASA', 'NO-EST', 'CEN-TRAF', 'SUR-TRAF'][::-1]
				estaciones = ['MED-TESO', 'MED-LAYE', 'ITA-CJUS', 'ITA-CONC','EST-HOSP', 'ENV-HOSP','SAB-JOFE', 'CAL-JOAR','CAL-LASA', 'NO-EST','SUR-TRAF'][::-1]
			else: #quito las de trafico
				estaciones = ['BAR-TORR','GIR-SOSN','COP-CVID', 'BEL-FEVE', 'MED-ARAN', 'MED-SCRI', 'MED-UNNV', 'MED-VILL', 'MED-BEME', 'MED-ALTA', 'MED-TESO', 'MED-LAYE', 'ITA-CJUS','ITA-CONC','EST-HOSP', 'ENV-HOSP','SAB-JOFE', 'CAL-JOAR'][::-1]
				Num = []
				for i in range(len(estaciones)): Num.append(self.Est[self.Est['Nombre']==estaciones[i]]['Enumeracion'].values[0])
				estaciones = [x for _,x in sorted(zip(Num,estaciones))][::-1]

			x = self.Est[self.Est['Nombre'].isin( self.ICA[self.varresol].columns.values)]['Nombre'].values

			if self.Medellin: estaciones = ['MED-ARAN', 'MED-VILL', 'MED-SCRI', 'MED-UNNV','MED-BEME', 'MED-ALTA', 'MED-TESO', 'MED-LAYE','NO-EST','CEN-TRAF'][::-1]
			if self.Valle:    estaciones = ['BAR-TORR', 'GIR-SOSN', 'COP-CVID', 'BEL-FEVE', 'ITA-CJUS', 'ENV-HOSP', 'ITA-CONC', 'SAB-JOFE','EST-HOSP', 'CAL-LASA','NO-EST','SUR-TRAF'][::-1]

			for est in estaciones:
				if est not in x: no_in.append(est)

		df = self.ICA[self.varresol]
		if len(no_in) > 0:
			print 'aqui si'
			for est in no_in:
				df.loc[df.index,est]	= np.NaN
				C.loc[C.index,est]	= np.NaN

		#if ((self.var=='PM2.5') and (self.Medellin or self.Valle)):
		#	df = df.loc[:,estaciones]
                #	C = C.loc[:,estaciones]

		#Esto es para evitar errores!
		df = df.loc[:,estaciones]
                C = C.loc[:,estaciones]

		textizq=-5.6*datesize

		plt.close('all')
		p1 = 6 if self.textsave <> '_Semanal' else 10
		fig = plt.figure(figsize=((p1+ticksdate.size)*0.32, 0.42*(4+df.columns.size)),facecolor='w',edgecolor='w')
		plt.subplots_adjust(wspace=.1,hspace=.3,bottom=0.1,left=0.1,right=0.90,top=0.9)

		ax={}
		i=0
		ax[i]= fig.add_subplot(111)
		plt.setp(ax[i].spines.values(), color=(0.45, 0.45, 0.45)  if self.textsave <> '_Semanal' else None)
		ax[i].tick_params(axis=u'both', which=u'both',length=0, color=(0.45, 0.45, 0.45) if self.textsave <> '_Semanal' else None)

		#contorno
		cmap = mpl.colors.ListedColormap([(0.875,0.875,0.875)]+self.RangosICA[self.varresol]['color'])
		bounds       = [-50,0,51,101,151,201,301,501]
		bounds_ticks = [-50,0,51,101,151,201,301,501]
		#bounds       = [-50,0,51,101,151,201,301,401,501]
		#bounds_ticks = [-50,0,51,101,151,201,301,401,501]
		norm = mpl.colors.BoundaryNorm(bounds, cmap.N)
		contf = ax[0].imshow(df.resample(self.resol).mean()[estaciones].T.fillna(-10).values,interpolation='nearest',cmap=cmap, aspect='auto', origin='lower',
			extent=[0,ticksdate.size,0,df.columns.size],norm=norm ,)# alpha=.6)# vmin=self.limC[self.resol][var][0],vmax=self.limC[self.resol][var][1])

		#Valores numericos
		for i in range(df.columns.size):
			for j in range(ticksdate.size):
				if estaciones[i] != 'NO-EST':
					dato = C.resample(self.resol).mean()[estaciones[i]].T.values[j]
					dato = dato if np.isnan(dato) else np.float(int(dato))
					ax[0].text(j+0.5,i+0.5,'' %dato if np.isnan(dato) else '%.f' %dato, ha='center',va='center', fontsize=fontsize, color= 'k' if (df.resample(self.resol).mean()[estaciones].T.fillna(-10).values[i,j] < 151) else 'w' , fontproperties=prop_1)
			ax[0].text(textizq if self.textsave <> '_Semanal' else textizq + 5.2,i+0.75,'%s' %'' if estaciones[i] =='NO-EST' else '%s%s' %('%.f | ' %self.Est[self.Est['Nombre']==estaciones[i]]['Enumeracion'].values[0] if 'add_code' in kwargs.keys() else '',self.Est[self.Est['Nombre']==estaciones[i]]['Municipio'].values[0]),ha='left' if self.textsave <> '_Semanal' else 'right',va='center',fontsize=fontsize,fontproperties=prop_1)
			ax[0].text(textizq if self.textsave <> '_Semanal' else textizq + 5.2,i+0.25,'%s' %'' if estaciones[i] =='NO-EST' else self.Est[self.Est['Nombre'].isin([estaciones[i]])]['Nombre_Estacion'].values[0],ha='left' if self.textsave <> '_Semanal' else 'right',va='center',fontsize=fontsize,fontproperties=prop)
			ax[0].axhline(i,color='w',lw=1)

		if self.textsave <> '_Semanal':
			ax[0].axhline(len(estaciones)+1,xmin=np.abs(textizq-0.5)/(ticksdate.size+1+np.abs(textizq-0.5)), xmax=(ticksdate.size+np.abs(textizq-0.5))/(ticksdate.size+1+np.abs(textizq-0.5)),color='k',lw=2.5)
			ax[0].text(textizq,df.columns.size+.6,u'Estaciones',ha='left',va='center',fontsize='small',fontproperties=prop_2)

		#Fechas
		pos1 = 2 if self.textsave <> '_Semanal'  else 1
		for j in range(ticksdate.size):
			ax[0].text(j+0.5,df.columns.size+pos1-0.5,'%s%d' %(self.dias_es[ticksdate[j].strftime('%w')],ticksdate[j].day),fontsize='xx-small',ha='center',va='center',fontproperties=prop_1)
			ax[0].axvline(x=j,ymax=(len(estaciones)+.5)/(len(estaciones)+4.),color='w',lw=1) #ymin= 1./(len(estaciones)+4.)
			if self.textsave <> '_Semanal':
				if ((j==0) & (ticksdate[1].day!=1)) | (ticksdate[j].day ==1) : ax[0].text(j+.1, df.columns.size+pos1+0.1,'%s' %self.mes_es[ticksdate[j].month],ha='left',va='bottom',fontsize=fontsize if self.textsave <> '_Semanal' else "medium",fontproperties=prop_2)
			else:
				if (j==0): ax[0].text(j+.1, df.columns.size+pos1+0.1 ,'%s' %" - ".join([self.mes_es[m] for m in np.unique(ticksdate.month)]),ha='left',va='bottom',fontsize=fontsize if self.textsave <> '_Semanal' else "medium",fontproperties=prop_2)

		#~ ax[0].add_patch(Rectangle((0,df.columns.size+2), ticksdate.size, 1, facecolor=(0.875,0.875,0.875),edgecolor='w'))


		ax[0].axhspan(df.columns.size+pos1, df.columns.size+pos1+1, xmin=np.abs(textizq-0.5)/(ticksdate.size+1+np.abs(textizq-0.5)), xmax=(ticksdate.size+np.abs(textizq-0.5))/(ticksdate.size+1+np.abs(textizq-0.5)),fc=(0.875,0.875,0.875) if self.textsave <> '_Semanal'  else (214./255, 232./255 ,233./255),ec='w')
		ax[0].axhspan(df.columns.size+pos1,df.columns.size+pos1+1,xmax=np.abs(textizq-0.5)/(ticksdate.size+1+np.abs(textizq-0.5))-.02,fc=(0.875,0.875,0.875)  if self.textsave <> '_Semanal' else (214./255, 232./255 ,233./255),ec='w')
		ax[0].text(textizq,df.columns.size+pos1+0.1,self.var if self.textsave <> '_Semanal' else "Estaciones" ,ha='left',va='bottom',fontsize='small' if self.textsave <> '_Semanal' else "medium" ,fontproperties=prop_2)

		if (self.var == 'PM2.5' and self.textsave <> '_Semanal'):
			ax[0].axhspan(1,2,fc='w',ec='w')
			#ax[0].axhspan(1 if (self.Medellin or self.Valle) else 2,2 if (self.Medellin or self.Valle) else 3,fc='w',ec='w')
			ax[0].text(0,1.6,'DE TRÁFICO',ha='left',va='center',fontsize=fontsize,fontproperties=prop_1)
			#ax[0].text(0,1.6 if (self.Medellin or self.Valle) else 2.6,'DE TRÁFICO',ha='left',va='center',fontsize=fontsize,fontproperties=prop_1)
			ax[0].axhline(1.15,xmin=np.abs(textizq-0.5)/(ticksdate.size+1+np.abs(textizq-0.5)), xmax=(ticksdate.size+np.abs(textizq-0.5))/(ticksdate.size+1+np.abs(textizq-0.5)),color=(0.45, 0.45, 0.45),lw=1)
			#ax[0].axhline(1.15 if (self.Medellin or self.Valle) else 2.15,xmin=np.abs(textizq-0.5)/(ticksdate.size+1+np.abs(textizq-0.5)), xmax=(ticksdate.size+np.abs(textizq-0.5))/(ticksdate.size+1+np.abs(textizq-0.5)),color=(0.45, 0.45, 0.45),lw=1)
			ax[0].text(0,df.columns.size+.6,'DE REPRESENTACIÓN POBLACIONAL',ha='left',va='center',fontsize=fontsize,fontproperties=prop_1)
			ax[0].axhline(df.columns.size+.15,xmin =0.5/(ticksdate.size+1+np.abs(textizq-0.5)),xmax=(ticksdate.size+np.abs(textizq-0.5))/(ticksdate.size+1+np.abs(textizq-0.5)),color=(0.45, 0.45, 0.45),lw=1)

		ax[0].set_ylim(-.5,len(estaciones)+3.5)
		#ax[0].set_ylim(-.5,len(estaciones)+3.5 if self.textsave <> '_Semanal' else len(estaciones)+2.5)
		ax[0].set_xlim(textizq-0.5,ticksdate.size+1)
		ax[0].set_xticklabels('')
		ax[0].set_yticklabels('')

		plt.savefig('Figuras/%s/ICA_%s%s.pdf' %(self.varsave,self.varsave2,self.textsave),bbox_inches='tight', transparent = False if self.textsave <> '_Semanal' else True, format='pdf')
		os.system('scp Figuras/%s/ICA_%s%s.pdf nroldan@siata.gov.co:%s' %(self.varsave,self.varsave2,self.textsave,self.path))

		if kwargs.get('Procuraduria',False): os.system('scp Figuras/%s/ICA_%s.pdf calidadaire@192.168.1.10:Informe_Procuraduria/Graficos_ICA/' %(self.varsave,self.varsave2))

	def Plot_Norma_Anual(self,*args,**kwargs):

		var = self.var
		fontsize		= kwargs.get('fontsize','medium')
		colors			= kwargs.get('colors',[[0.69,0.87,0.93],[0.61,0.82,0.88],[0.32,0.71,0.77],[0.21,0.60,0.65],[0.0156,0.486,0.556],[0.007,0.32,0.36],[0.0078,0.227,0.26]])
		self.textsave		= kwargs.get('textsave','')
		ylim			= kwargs.get('ylim',self.limC['Y'][var])

		df = self.Contaminante[var].mean() #pd.DataFrame(self.Contaminante[var].mean(),columns=['Mean'])

		########################################################################
		#Plot
		plt.close('all')
		fig = plt.figure(figsize=(df.index.size*1.25,3),facecolor='w',edgecolor='w')
		ax = fig.add_subplot(111)

		for spinename, spine in ax.spines.iteritems():
			spine.set_visible(False)

		ax.tick_params(top='off', right='off',bottom='off',left='off',labelleft='off',which='both',color=(0.45, 0.45, 0.45))

		lims		= np.linspace(ylim[0],ylim[1],7)
		poscolor 	= df.apply(lambda x: np.abs(lims -x).argmin()).values
		cc			=[colors[i] for i in poscolor]

		estaciones = self.Est[self.Est['Nombre'].isin( df.index.values)].sort_values(by='Latitud',ascending=False)['Nombre'].values[::-1]
		df.loc[estaciones].plot(kind='bar',ax=ax,width=.5,color=cc,edgecolor='w',ylim=ylim,legend=False)

		ax.set_xticklabels(estaciones,rotation='horizontal',fontproperties=prop_1,fontsize=fontsize,)
		ax.text(0,ylim[0]-(ylim[1]-ylim[0])*.18,self.Contaminante[var].index[0].strftime('%Y'),fontsize=fontsize,color=(0.45, 0.45, 0.45),fontproperties=prop_2,ha='left')
		ax.set_ylabel(self.labelx[var] %'',fontsize=fontsize,color=(0.45, 0.45, 0.45),fontproperties=prop_1)

		ax.axhline(self.norma['Y'][var],color=colors[6],lw=2,ls='--')

		ticks = ax.get_xticks()
		c=0
		rects = ax.patches
		for rect in rects:
			height = rect.get_height()
			ax.text(rect.get_x() + rect.get_width()/2. ,ylim[0]+(ylim[1]-ylim[0])*.05, '%.1f' %height if height!=0 else ' ', ha='center',va='bottom',fontsize=fontsize, fontproperties=prop_2,color='w' if poscolor[c]>3 else colors[6])
			c+=1

		ax.annotate('Norma Anual Colombiana %s (%d $\mu g/m^{3}$)' %(var,self.norma['Y'][var]), xy=(ticks[-1]*.7,self.norma['Y'][var]), xytext=(ticks[-1]*.7, ylim[1]*.9),ha='center',fontsize=fontsize,fontproperties=prop_2, color=colors[6],arrowprops=dict(facecolor=colors[6],edgecolor=colors[6], shrink=0.00,width=.5,headwidth=5), bbox=dict(facecolor=colors[0], edgecolor='none', boxstyle='round',alpha=.5))

		self.varsave = 'PM25' if var =='PM2.5' else var
		plt.savefig('Figuras/%s/Norma_Anual_%s%s.pdf' %(self.varsave,self.varsave,self.textsave),bbox_inches='tight')
		os.system('scp Figuras/%s/Norma_Anual_%s.pdf nroldan@siata.gov.co:/var/www/CalidadAire/Figuras/%s/%s' %(self.varsave,self.varsave,self.varsave,self.textsave))

	def Plot_Imshow(self,*args,**kwargs):

		resol			= kwargs.get('resol','D')
		resolucion		= kwargs.get('resolucion','Diaria')
		textsave		= kwargs.get('textsave',None)
		valores			= kwargs.get('valores',False)
		ExcedenciaDiaria= kwargs.get('ExcedenciaDiaria',False)
		path			= kwargs.get('path','RedAire/Informe_Mensual/')
		df				= kwargs.get('df',None)

		"""Genera plot discreto de las variables de acuerdo 
		a las diferentes resoluciones temporales establecidas por la norma
		para los contaminantes. Requiere leer los datos """

		fontsize= 'medium' if resolucion in ['1h','8h'] else 'x-small'
		fontsize2= 'medium' if resolucion in ['1h','8h'] else 'small'

		self.resol = resol

		if   self.resol == 'D':  	datesize = 1
		elif self.resol == '8h': 	datesize = 1
		elif self.resol == '3h':	datesize = 8
		elif self.resol == '1h': 	datesize = 1
		else: pass

		#~ if   self.resol == 'D':  	resolucion = 'Diaria'		; datesize = 1
		#~ elif self.resol == '8h': 	resolucion = 'Octohoraria'  ; datesize = 1
		#~ elif self.resol == '3h':	resolucion = 'Trihoraria'	; datesize = 8
		#~ elif self.resol == '1h': 	resolucion = 'Horaria'	    ; datesize = 1
		#~ else: pass
		self.labelx       = {'PM10':ur'Concentración Promedio %s PM10 $[\mu g /m^{3}]$' %(resolucion[:-1]+'o'), 'PM2.5':ur'Concentración Promedio %s PM2.5 $[\mu g /m^{3}]$' %(resolucion[:-1]+'o'),
			'Ozono':ur'Concentración Promedio %s Ozono $[\mu g /m^{3}]$' %(resolucion[:-1]+'o'), 'NO':ur'Concentración Promedio %s NO $[\mu g /m^{3}]$' %(resolucion[:-1]+'o'),
			'NO2':ur'Concentración Promedio %s NO2 $[\mu g /m^{3}]$' %(resolucion[:-1]+'o'),'NOx':ur'Concentración Promedio %s NOx $[\mu g /m^{3}]$' %(resolucion[:-1]+'o'),
			'SO2':ur'Concentración Promedio %s SO2 $[\mu g /m^{3}]$' %(resolucion[:-1]+'o'), 'CO':ur'Concentración Promedio %s CO $[\mu g /m^{3}]$' %(resolucion[:-1]+'o'),
			'P_SSR':ur'Presión Atmosférica Promedio %s $[\frac{mm} {Hg}]$' %(resolucion[:-1]+'o'), 'PLiquida_SSR':ur'Precipitación Acumulada %s $[mm]$' %(resolucion[:-1]+'o'),
			'TAire10_SSR':ur'Temperatura del Aire a 10m Promedio %s $[C^{\circ}]$' %(resolucion[:-1]+'o'), 'RGlobal_SSR':ur'Radiación Solar Global Promedio %s $[\frac {W}{m^{2}}]$' %(resolucion[:-1]+'o'),
			'HAire10_SSR':ur'Humedad Relativa a 10m Promedio %s $[\%%]$' %(resolucion[:-1]+'o'), 'VViento_SSR':ur'Velocidad del Viento Promedio %s $[\frac {m}{s}]$' %(resolucion[:-1]+'o'),
			'DViento_SSR':ur'Dirección del Viento %s $[^{\circ}]$' %(resolucion[:-1]+'o'),'Ruido':ur'Nivel de Presión Sonora $dB(A)$'}

		var = self.var


		how = 'mean' if var != 'PLiquida_SSR' else 'sum'

		if df == None:
			C = (self.Contaminante.resample(self.resol).mean() if self.resol!= '8h' else self.Contaminante.rolling(8,freq='1H').mean().iloc[7:]) if (var in self.nombre_contaminantes) else self.Meteo.resample(self.resol).apply(lambda x: x.sum() if var == 'PLiquida_SSR' else x.mean())
		else:
			C = df

		self.limC['1h']['PLiquida_SSR']=(0,35)
		resol = self.resol if self.resol!= '8h' else '1h'
		ticksdate = pd.date_range(C[var].index[0],C[var].index[-1],freq=resol)
		estaciones = self.Est[self.Est['Nombre'].isin( C[var].columns.values)].sort_values(by='Latitud',ascending=False)['Nombre'].values[::-1]

		plt.close('all')
		fig = plt.figure(figsize=((6+ticksdate.size)*0.32, 0.42*(C[var].columns.size)),facecolor='w',edgecolor='w')
		plt.subplots_adjust(wspace=.1,hspace=.3,bottom=0.1,left=0.1,right=0.90,top=0.9)
		plt.rcParams["xtick.labelsize"]=fontsize
		plt.rcParams["ytick.labelsize"]=fontsize
		plt.rcParams["axes.labelsize"]=fontsize
		#~ plt.rcParams["axes.titlesize"]='small'
		ax={}

		#Pendiente Automatizar
		if var == 'SO2':
			ax[0] = fig.add_axes((0.1,0.21,0.88,0.76))
			ax[1] = fig.add_axes((0.1,-1.1,0.88,0.3))
		elif var == 'NO2':
			ax[0] = fig.add_axes((0.1,0.21,0.88,0.76))
			ax[1] = fig.add_axes((0.1,-0.05,0.88,0.07))
		elif var == 'CO':
			ax[0] = fig.add_axes((0.1,0.21,0.88,0.76))
			ax[1] = fig.add_axes((0.1,-0.1,0.88,0.07))
		else:
			ax[0] = fig.add_axes((0.1,0.21,0.88,0.76))
			ax[1] = fig.add_axes((0.1,0.05,0.88,0.04))

		for i in range(2):
			plt.setp(ax[i].spines.values(), color=(0.45, 0.45, 0.45))
			ax[i].tick_params(axis=u'both', which=u'both',length=0, color=(0.45, 0.45, 0.45))
			#~ ax[i].yaxis.label.set_color((0.45, 0.45, 0.45))
			ax[i].xaxis.label.set_color((0.45, 0.45, 0.45))

		#Colorbar
		cmap   = mpl.colors.ListedColormap(['w',[0.69,0.87,0.93],[0.61,0.82,0.88],[0.32,0.71,0.77],[0.21,0.60,0.65],[0.0156,0.486,0.556],[0.007,0.32,0.36],[0.0078,0.227,0.26]])
		cmap.set_over([0.0078,0.227,0.26])
		cmap.set_under('w')
		bounds       = [-1,0,1,2,3,4,5,6,7]
		bounds_ticks = [-1,0,1,2,3,4,5,6,7]

		tickscolorbar  = ['NaN']+[ur'%.f' %j for j in np.linspace(self.limC[self.resol][var][0],self.limC[self.resol][var][1],8)] 
		norm = mpl.colors.BoundaryNorm(bounds, cmap.N)
		cb2  = mpl.colorbar.ColorbarBase(ax[1], cmap=cmap, norm=norm,boundaries=bounds,ticks=bounds,spacing='proportional',orientation='horizontal')
		cb2.set_ticks(bounds_ticks)
		cb2.set_ticklabels(tickscolorbar)
		cb2.ax.tick_params(labelsize=13)
		#ax[1].set_xlabel(self.labelx[var],fontproperties=prop_1,fontsize=fontsize2)
		ax[1].set_xlabel(self.labelx[var],fontproperties=prop_1,fontsize=13, color = 'k')
		norm1=mpl.colors.Normalize(self.limC[self.resol][var][0]-self.limC[self.resol][var][1]/7. ,self.limC[self.resol][var][1])

		#Imshow
		if var =='SO2':
			SO=C[var]
			SO['GIR']=SO.values
			contf = ax[0].imshow(SO.T.values,interpolation='nearest',cmap=cmap, aspect='auto', origin='lower',
				extent=[0,ticksdate.size,0,C[var].columns.size],norm=norm1 )# vmin=self.limC[self.resol][var][0],vmax=self.limC[self.resol][var][1])
		else:
			contf = ax[0].imshow(C[var][estaciones].T.values,interpolation='nearest',cmap=cmap, aspect='auto', origin='lower',
				extent=[0,ticksdate.size,0,C[var].columns.size],norm=norm1 )# vmin=self.limC[self.resol][var][0],vmax=self.limC[self.resol][var][1])

		#Scatter
		xx=0
		try:
			norma			= kwargs.get('norma',self.norma[self.resol][var])
			scatter={x:np.where(C[var][x]>norma)[0] for x in C[var].columns.values}
			for i in range(len(estaciones)):
				ax[0].scatter(scatter[estaciones[i]]+.5,[i+.5]*len(scatter[estaciones[i]]), marker='*',color='w',s=20)
				xx += scatter[estaciones[i]].size
			if xx ==0:
#				ax[0].text(ticksdate.size*0.97,C[var].columns.size*1.04, ur'No Hay Excedencia de Norma %s Colombiana %s (%d $\mu g/m^{3}$)' %(resolucion,var,self.norma[self.resol][var]), ha='right',va='bottom', fontsize=fontsize2,fontproperties=prop_1, bbox={'facecolor':(0.32,0.71,0.77), 'alpha':0.2, 'pad':2,'edgecolor':'w'})
				ax[0].text(ticksdate.size*0.97,C[var].columns.size*1.04, ur'No Hay Excedencia de Norma %s Colombiana %s (%d $\mu g/m^{3}$)' %(resolucion,var,self.norma[self.resol][var]), ha='right',va='bottom', fontsize=13,fontproperties=prop_1, bbox={'facecolor':(0.32,0.71,0.77), 'alpha':0.2, 'pad':2,'edgecolor':'w'})
			else:
#				ax[0].text(ticksdate.size*0.97,C[var].columns.size*1.04, ur'$\star$ Excedencia Norma %s Colombiana %s (%d $\mu g/m^{3}$)' %(resolucion,var,self.norma[self.resol][var]), ha='right',va='bottom', fontsize=fontsize2,fontproperties=prop_1, bbox={'facecolor':(0.32,0.71,0.77), 'alpha':0.2, 'pad':2,'edgecolor':'w'})
				ax[0].text(ticksdate.size*0.97,C[var].columns.size*1.04, ur'$\star$ Excedencia Norma %s Colombiana %s (%d $\mu g/m^{3}$)' %(resolucion,var,self.norma[self.resol][var]), ha='right',va='bottom', fontsize=13,fontproperties=prop_1, bbox={'facecolor':(0.32,0.71,0.77), 'alpha':0.2, 'pad':2,'edgecolor':'w'})
		except:pass
		#Contorno
		#~ try: 
			#~ x,y = np.meshgrid(np.arange(.5,ticksdate.size+.5),np.arange(0.5,C[var].columns.size+.5))
			#~ contorno = C[var][estaciones].T.values
			#~ cont  = ax[0].contour(x,y,contorno, levels = [self.norma[self.resol][var]],colors=('k',),linestyles=('--',),linewidths=(0.5,),interpolation='nearest')
			#~ ax[0].clabel(cont,fontsize=fontsize, fmt = '%2.1d', colors = 'k')
			#~ ax[0].text(ticksdate.size*0.97,C[var].columns.size*1.04, ur'---- Norma %s Colombiana [ug/m$^{3}$]' %resolucion, 
				#~ horizontalalignment='right',verticalalignment='bottom', style='normal', fontsize='small',
				#~ bbox={'facecolor':(0.32,0.71,0.77), 'alpha':0.2, 'pad':3,'edgecolor':'w'})
		#~ except: pass

		#Tickslabels
		ax[0].set_ylim(0,len(estaciones))
		ax[0].set_xlim(0,ticksdate.size)
		#~ if self.resol =='8h': ax[0].set_xticks(np.arange(1.5,ticksdate.size + 1.5, datesize))
		ax[0].set_xticks(np.arange(0.5,ticksdate.size + 0.5, datesize))
		ticks = ax[0].get_xticks()

		date = pd.date_range(self.Fechai,self.Fechaf,freq=resol)
		label=[]
		for i in range(0,ticksdate.size,datesize):
			if (self.resol=='1h'):	label.append('%s' %(date[i].strftime('%H:%M')) if i%2 == 0 else ' ')
			elif self.resol=='8h':	label.append('%s%s' %(date[i].strftime('%H-'),date[i+7].strftime('%H')) if i%2 == 0 else ' ')
			else: 					label.append('%s%d' %(self.dias_es[date[i].strftime('%w')],date[i].day))
			ax[0].axvline(i,color=(0.0078,0.227,0.26),ls='-',lw=1)


		#ax[0].set_xticklabels(label,fontproperties=prop_1,fontsize=fontsize)
		ax[0].set_xticklabels(label,fontproperties=prop_1,fontsize=10, color = 'k')
#		if self.resol == 'D': ax[0].text(0., -1.15,'%s' %self.mes_es[date[0].month],ha='left',va='bottom',fontsize=fontsize,fontproperties=prop_2)
		if self.resol == 'D': ax[0].text(0., -1.15,'%s' %self.mes_es[date[0].month],ha='left',va='bottom',fontsize=13,fontproperties=prop_2)
		ax[0].set_yticklabels('')

		#Estaciones y numeros
		textizq=-5.4*datesize #if self.resol !='1h' else -4.7*datesize
		for i in range(len(estaciones)):
#			ax[0].text(textizq,i+0.75,'%s' %estaciones[i][:3],ha='left',va='center',fontsize=fontsize2,fontproperties=prop_1)
			ax[0].text(textizq,i+0.75,'%s' %estaciones[i][:3],ha='left',va='center',fontsize=9.5,fontproperties=prop_1)
#			ax[0].text(textizq,i+0.25,'%s' %self.Est[self.Est['Nombre'].isin([estaciones[i]])]['Nombre_Estacion'].values[0],ha='left',va='center',fontsize=fontsize2,fontproperties=prop)
			ax[0].text(textizq,i+0.25,'%s' %self.Est[self.Est['Nombre'].isin([estaciones[i]])]['Nombre_Estacion'].values[0],ha='left',va='center',fontsize=9.5,fontproperties=prop)
			ax[0].axhline(i,color=(0.0078,0.227,0.26),ls='-',lw=1)
			if valores:
				for j in range(ticksdate.size):
					dato = C[var][estaciones[i]].values[j]
					ax[0].text(j+0.5,i+0.5,'NaN' %dato if np.isnan(dato) else '%.f' %dato, ha='center',va='center', fontsize=fontsize,
						color= 'k' if (dato < self.limC[self.resol][var][1]/7.*4) else 'w' ,fontproperties=prop_1)

#		ax[0].text(textizq,C[var].columns.size*1.04,'Estación', fontproperties = prop_2, fontsize=fontsize2,ha='left',va='bottom')
		ax[0].text(textizq,C[var].columns.size*1.04,'Estación', fontproperties = prop_2, fontsize=13,ha='left',va='bottom')

		#~ if (self.resol in ['8h','D']):
			#~ ax[0].set_xticks(np.arange(0,ticksdate.size), minor = True)
			#~ ax[0].grid(which='minor',linestyle='-', linewidth=1,color='k',alpha=0.4)
		#~ else:
			#~ ax[0].yaxis.grid(which='minor',linestyle='-', linewidth=1,color='k',alpha=0.4)

		var = 'PM25' if var =='PM2.5' else var
		if type(textsave) ==type(None):
			plt.savefig('Figuras/%s/%s_%s.pdf' %(var,resolucion, var),bbox_inches='tight',)
			os.system('scp Figuras/%s/%s_%s.pdf nroldan@siata.gov.co:/var/www/CalidadAire/Figuras/%s/' %(var,resolucion,var,var))
		else:
			plt.savefig('Figuras/%s_%s.pdf' %(var,textsave),bbox_inches='tight',)
			os.system('scp Figuras/%s_%s.pdf nroldan@siata.gov.co:/var/www/CalidadAire/Figuras/%s' %(var,textsave,path))
			if ExcedenciaDiaria:
				os.system('scp Figuras/%s_%s.pdf calidadaire@192.168.1.10:Excedencias_Diarias/' %(var,textsave))

	def Plot_Mapa_Contorno(self,df,*args,**kwargs):
		""" Makes contour plot from df (DataFrame with columns as longitude and index like latitude)"""

		self.clim			= kwargs.get('clim',(df.min().min(),df.max().max()))
		self.fontsize		= kwargs.get('fontsize',12)

		#~ self.georef		= kwargs.get('georef',[df.index.values.max()+(df.index.values.max()-df.index.values.min())*.025,df.index.values.min()-(df.index.values.max()-df.index.values.min())*.025,df.columns.values.min()+(df.columns.values.max()-df.columns.values.min())*.025,df.columns.values.max()+(df.columns.values.max()-df.columns.values.min())*.025])

		self.georef		= kwargs.get('georef',[df.index.values.max(),df.index.values.min(),df.columns.values.min(),df.columns.values.max()])

		self.lats 	= df.index.values
		self.lons	= df.columns.values

		if 'ax' in kwargs.keys():
			self.ax = kwargs['ax']
		else:
			plt.close('all') 
			self.fig 	= plt.figure(figsize=(kwargs.get('figsize',10),kwargs.get('figsize',10)*(self.georef[0]-self.georef[1])/(self.georef[3]-self.georef[2])),facecolor='w',edgecolor='w') 
			self.ax		= self.ax			= self.fig.add_axes((0.125,0.11,0.775,.77))
			if 'Barbs' in kwargs.keys(): 		self.ax1		= self.fig.add_axes((0.265,0.05,0.5,0.02))
			if kwargs.get('Contourf',True):		self.ax2		= self.fig.add_axes((0.915,.2,0.02,0.59))

			for spinename, spine in self.ax.spines.iteritems():
				spine.set_visible(False)

			self.ax.tick_params(top='on', right='on',bottom='on',left='on',which='both',color=(0.45, 0.45, 0.45),labelsize=self.fontsize)
			self.ax.xaxis.label.set_color((0.45, 0.45, 0.45))
			self.ax.yaxis.label.set_color((0.45, 0.45, 0.45))

		self.ax.patch.set_facecolor((.75,.75,.75))
		self.divider 		= make_axes_locatable(self.ax)

		self.X,self.Y		= np.meshgrid(self.lons,self.lats)

		self.m 		= Basemap(projection='merc',llcrnrlat=self.georef[1],urcrnrlat=self.georef[0],llcrnrlon=self.georef[2],urcrnrlon=self.georef[3],resolution='h',ax=self.ax) 
		self.Setcolor( self.m.drawparallels(np.linspace(self.lats.min()+0.08,self.lats.max()-0.08,4),labels=[1,0,0,0],fmt="%.2f",color=(0.45, 0.45, 0.45),fontsize=self.fontsize,ax=self.ax,rotation='vertical',linewidth=0), (0.45, 0.45, 0.45))
		self.Setcolor( self.m.drawmeridians(np.linspace(self.lons.min()+0.08,self.lons.max()-0.08,4),labels=[0,0,0,1], fmt="%.2f",color=(0.45, 0.45, 0.45),fontsize=self.fontsize,ax=self.ax,linewidth=0) ,(0.45, 0.45, 0.45))


		self.Xm,self.Ym		= self.m(self.X,self.Y)

		if kwargs.get('Contourf',True):
			self.custom_cmap = [[ 0.4275,  0.0078,  0.1255], [ 0.6745,  0.0863,  0.1647], [ 0.8   ,  0.298 ,  0.2667], [ 0.8824,  0.4706,  0.3765],  [ 0.949 ,  0.6314,  0.498 ], [ 0.9686,  0.9686,  0.9686],  [ 0.5529,  0.7608,  0.8627],  [ 0.3725,  0.6471,  0.8039], [ 0.2275,  0.5294,  0.7412], [ 0.1176,  0.3804,  0.6471], [ 0.0275,  0.2039,  0.4039]] # [ 1.,  0.5765,  0.4549], n, [ 0.9608,  0.6745,  0.5451],medio,[ 0.6078,  0.7882,  0.8784], n,[ 0.4941,  0.7216,  0.8431]

			self.cf		= self.m.contourf(self.Xm,self.Ym,df.values, cmap = clr.LinearSegmentedColormap.from_list('custom96',self.custom_cmap) if  'cmap' not in kwargs.keys() else kwargs['cmap'] ,norm=mpl.colors.Normalize(self.clim[0],self.clim[1]) ,levels=np.linspace(self.clim[0],self.clim[1],40),alpha=kwargs.get('alpha',1),extend='both')
			if 'cmap' not in kwargs.keys():
				self.cf.cmap.set_over([ 0.02745098,  0.20392157,  0.40392157]  )
				self.cf.cmap.set_under([ 0.42745098,  0.00784314,  0.1254902 ])

			if ('ax' not in kwargs.keys()) | (kwargs.get('add_colorbar',False)): 
				self.cbar1	=plt.colorbar(self.cf,cax=self.divider.append_axes("right", size="2%", pad='1%') if 'ax' in kwargs.keys() else self.ax2,format='%.2f')
				self.cbar1.set_label(kwargs.get('labelcolorbarv',r"$\omega\ [m/s]$"), fontsize=self.fontsize,color=(0.45, 0.45, 0.45))
				self.cbar1.ax.tick_params(labelsize=self.fontsize,color=(0.45, 0.45, 0.45))
				self.cbar1.set_ticks(np.arange(self.clim[0],self.clim[1]+.005,.25 ) )
				self.cbar1.ax.set_yticklabels(np.arange(self.clim[0],self.clim[1]+.005,.25 ) , rotation='vertical')

		self.m.readshapefile(kwargs.get('shapefile','/home/nroldan/Tools/AreaMetropolitana'),'Area',linewidth=.5,color='k') #(0.45, 0.45, 0.45))

		self.n = kwargs.get('each',2)
		if 'Barbs' in kwargs.keys():
			#~ self.X, self.Y		= np.meshgrid( kwargs['Barbs'].U.columns.values, kwargs['Barbs'].index.values )
			#~ self.Xm, self.Ym	= self.m( self.X, self.Y )

			self.Xm, self.Ym	= np.meshgrid( kwargs['Barbs'].U.columns.values, kwargs['Barbs'].index.values )
			self.img			= self.m.barbs(self.Xm[::+self.n,::+self.n], self.Ym[::+self.n,::+self.n], kwargs['Barbs']['U'].values[::+self.n,::+self.n], kwargs['Barbs']['V'].values[::+self.n,::+self.n], (kwargs['Barbs']['U'].values[::+self.n,::+self.n]**2 + kwargs['Barbs']['V'].values[::+self.n,::+self.n]**2)**.5, cmap = clr.LinearSegmentedColormap.from_list('custom69',[(.0,.0,.0),[ 0.0706,  0.302 ,  0.4863],[ 0.    ,  0.5529,  0.4431],[ 0.251 ,  0.6588,  0.2902],[ 0.6471,  0.7255,  0.3451],[ 0.7882,  0.8314,  0.2039]] ) , length=4, norm=mpl.colors.Normalize(kwargs.get('advlim',[0,12])[0],kwargs.get('advlim',[0,12])[1]) ,fill_empty=False, rounding=True, sizes=dict(emptybarb=0.2, spacing=0.0, height=0.3) ,barb_increments={'half':0.514444,'full':1.02889,'flag':244.3611},  latlon=True) 

			for img in self.img:
				img.cmap.set_over([ 0.7882,  0.8314,  0.2039])
				img.set_clim(kwargs.get('advlim',[0,12])[0],kwargs.get('advlim',[0,12])[1])

			if ('ax' not in kwargs.keys()) | (kwargs.get('add_colorbar',False)): 
				self.cbar2		= plt.colorbar(self.img[0],cax= self.divider.append_axes("bottom", size="3%", pad='12%') if 'ax' in kwargs.keys() else self.ax1, orientation='horizontal',extend='max' if  kwargs.get('custom_cmap',True) else 'neither')
				self.cbar2.set_label(r"Wind Speed $[m/s]$", fontsize=self.fontsize,color=(0.45, 0.45, 0.45))
				self.cbar2.ax.tick_params(labelsize=self.fontsize,color=(0.45, 0.45, 0.45))

		if 'add_text' in kwargs.keys():
			self.y = self.ax.get_ylim()[0] - (self.ax.get_ylim()[1]-self.ax.get_ylim()[0])*.07
			self.x = self.ax.get_xlim()[0] + (self.ax.get_xlim()[1]-self.ax.get_xlim()[0])*.05
			self.ax.text(self.x,self.y,kwargs['add_text'],ha='center',va='center',color=(0.45, 0.45, 0.45),fontsize=self.fontsize,weight='bold')

		if kwargs.get('save',True):
			plt.savefig('Figuras/Map%s.pdf' %kwargs.get('textsave',''),bbox_inches='tight') 
			os.system("scp Figuras/Map%s.pdf nroldan@siata.gov.co:/var/www/jhernandezv/%s" %(kwargs.get('textsave',''),kwargs.get('path','')))

		if kwargs.get('get_mappable',False): return self.cf

	def Setcolor(self,
	x, color):
		for m in x.keys():
			for t in x[m][1]:
				t.set_color(color)

	def Plot_Mapa4(self,*args,**kwargs):

		self.figsize	= kwargs.get('figsize',11)
		self.estaciones = kwargs.get('estaciones', None)
		self.fontsize	= kwargs.get('fontsize',18)
		self.textsave	= kwargs.get('textsave',None)
		self.varsave 	= 'PM25' if self.var =='PM2.5' else 'PM25M' if self.var =='PM2.5M' else 'Meteorologia' if self.var == 'P_SSR' else self.var
		self.path 		= kwargs.get('path','jhernandezv@siata.gov.co:/var/www/CalidadAire/Figuras/')

		plt.close('all')
		self.fig 		= plt.figure(figsize=(self.figsize,self.figsize*(6.515-5.975)/(75.725-75.21)),facecolor='w',edgecolor='w')
		self.ax			={}
		self.ax[0]		= self.fig.add_axes((0.00,0.00,1,1))		#Relieve
		self.ax[3]		= self.fig.add_axes((0.46,0.00,0.54,0.3))	#Fondo Mapas Pequeños
		self.ax[4]		= self.fig.add_axes((0.48,0.0,0.25,0.25))	#Mapa izquierda
		self.ax[5]		= self.fig.add_axes((0.75,0.0,0.25,0.25))	#Mapa derecha
		self.ax[2]		= self.fig.add_axes((0.0,0.91,0.35,0.09))	#Fondo Colorbar
		self.ax[6]		= self.fig.add_axes((0.0,0.97,0.33,0.03))	#Colorbar
		#~ self.ax[7]		= self.fig.add_axes((-0.0306,-0.11081,1.0306,0.11081)) # Logo

		for i in self.ax.keys():
			plt.setp(self.ax[i].spines.values(), color='w') #(0.45, 0.45, 0.45))
			if i > 0: self.ax[i].tick_params(labelleft='off',labelbottom='off',right='off',left='off',bottom='off',top='off',which='both', color=(0.45, 0.45, 0.45))

		self.m 			= Basemap(ax=self.ax[0],projection='merc',llcrnrlat=5.975,urcrnrlat=6.515,llcrnrlon=-75.725,urcrnrlon=-75.21,resolution='h') # area_thresh=10000, suppress_ticFalse)
		self.Setcolor( self.m.drawparallels(np.linspace(6.,6.4,5),labels=[1,0,0,0],fmt="%.1f",color=(0.45, 0.45, 0.45),fontsize=self.fontsize,zorder=1,ax=self.ax[0],alpha=1,rotation='vertical',linewidth=0) ,(0.45, 0.45, 0.45))

		self.Setcolor( self.m.drawmeridians(np.linspace(-75.5,-75.2,4),labels=[0,0,1,0], fmt="%.1f",color=(0.45, 0.45, 0.45),fontsize=self.fontsize,zorder=2,ax=self.ax[0],alpha=1,linewidth=0) ,(0.45, 0.45, 0.45))


		print 'DEM'
		#~ #DEM
		self.Read_DEM()
		self.X,self.Y	= np.meshgrid(self.DEM.columns.values,self.DEM.index.values)
		self.Xm,self.Ym	= self.m(self.X,self.Y)

		self.cs 		= self.m.contourf(self.Xm, self.Ym, self.DEM.values, levels=np.linspace(1300,3400,50), cmap=plt.cm.terrain_r,alpha=.5,extend='min',zorder=3)
		self.cs.cmap.set_over('k')
		self.cs.cmap.set_under('w')

		# Colorbar
		self.cbar		= plt.colorbar(self.cs,cax=self.ax[6],orientation='horizontal',format='%.f')
		self.cbar.set_label(r"Altitud $[km]$",fontsize=self.fontsize,color=(0.45, 0.45, 0.45))
		self.cbar.set_ticks([1500,2000,2500,3000])
		self.cbar.set_ticklabels([1.5,2,2.5,3])
		self.cbar.ax.tick_params(labelsize=self.fontsize,color=(0.45, 0.45, 0.45))
		#~ cbar.get_frame().set_edgecolor((0.45, 0.45, 0.45))

		self.m.readshapefile('/home/calidadaire/ModuloAire/Tools/AreaMetropolitana','Area',linewidth=0.5,color=(0.0078,0.227,0.26),zorder=4)

		#Scatter
		if type(self.estaciones)==type(None):
			self.X,self.Y		= self.m(self.Est[self.Est[self.var]==1]['Longitud'].values,self.Est[self.Est[self.var]==1]['Latitud'].values)
			self.estaciones		= self.Est[self.Est[self.var]==1]['Nombre'].values
		else: 
			self.x			= self.Est[self.Est['Nombre'].isin( self.estaciones)].sort_values(by='Latitud',ascending=False)[['Latitud','Longitud']]
			self.X,self.Y	= self.m(self.x['Longitud'].values,self.x['Latitud'].values)
		self.esta 		= self.Est[self.Est['Nombre'].isin(self.estaciones)]
		self.m.scatter(self.X,self.Y,s=1300,facecolor=(0.0078,0.227,0.26),edgecolor=(0.0078,0.227,0.26),lw=1,alpha=1,zorder=5)

		#~ #####################################################################
		print 'Texto'
		#~ # Texto
		#~ self.rows		= len(self.estaciones)/2+len(self.estaciones)%2

		#~ self.ax[1]		= self.fig.add_axes((.5,0.26,0.5,0.05*(self.rows+1)))
		#~ plt.setp(self.ax[1].spines.values(), color='w') #(0.45, 0.45, 0.45))
		#~ self.ax[1].tick_params(labelleft='off',labelbottom='off',right='off',left='off',bottom='off',top='off',which='both', colors=(0.45, 0.45, 0.45))

		#~ self.title = 'Estaciones de %s' %self.var if self.var in self.nombre_contaminantes +['Ruido','Automatica'] else 'Estaciones Manuales %s' %self.var[:-1]  if self.var in ['PM2.5M','PM10M'] else u'Estaciones Meteorológicas'

		#title = 'Estación Automática'

		self.zor,self.c = 6,0
		for i in range(len(self.X)):
			self.ax[0].text(self.X[i],self.Y[i],'%.f' %self.esta.loc[self.esta.index[i],'Enumeracion'] if kwargs.get('Enumeracion',False) else self.esta.index[i], ha='center',va='center', fontsize=self.fontsize,color='w',zorder=self.zor,fontproperties=prop_2,)
			self.zor+=1
			#~ if i == 0 :
				#~ self.ax[1].set_ylim(0,self.rows+1)
				#~ self.ax[1].invert_yaxis()
				#~ self.ax[1].text(.5,.5,self.title,ha='center',va='center',fontsize=self.fontsize,color=(0.45, 0.45, 0.45),fontproperties=prop_2,)
			#~ self.ax[1].text(.05+self.c,i%self.rows+1.5,'%.f - %s'%(self.esta.index[i],self.esta['Nombre'].values[i]),ha='left', va='center',color=(0.45, 0.45, 0.45),fontsize=self.fontsize,fontproperties=prop_1,)
			#~ if i+1==self.rows: self.c+=.5

		self.ax[3].text(.5,.92,u'Ubicación Nacional y Regional',ha='center',va='center',fontsize=self.fontsize,color=(0.45, 0.45, 0.45),fontproperties=prop_2,)
		################################################################################
		#colores
		#~  Oceano			[ 0.71372549,  0.87058824,  0.88235294];
		#~ Antioquia		[ 0.64705882,  0.97254902,  0.70980392];[ 0.3372549 ,  0.91764706,  0.75294118] ;[ 0.44705882,  0.94901961,  0.68235294]
		#~ Colombia			[ 0.91372549,  0.87843137,  0.87843137]; 
		#~ Valle			[ 0.4745098 ,  0.52941176,  0.80784314];[ 0.36078431,  0.6745098 ,  0.94509804]

		print 'Colombia'
		# Colombia
		self.m 		= Basemap(ax=self.ax[4],projection='merc',llcrnrlat=-5,urcrnrlat=13,llcrnrlon=-81.86,urcrnrlon=-65,resolution='h')
		self.m.drawmapboundary(fill_color=[ 0.69019608,  0.89411765,  1.        ],zorder=1)
		self.m.fillcontinents(color=[ 0.96470588,  0.95686275,  0.95294118],lake_color=[ 0.69019608,  0.89411765,  1.        ],zorder=2)
		self.m.drawcountries(color=(0.0078,0.227,0.26),zorder=3)
		self.m.drawcoastlines(color=(0.0078,0.227,0.26),zorder=4)
		self.m.readshapefile('/home/calidadaire/ModuloAire/Tools/Antioquia','Antioquia',linewidth=0.1,color=(0.0078,0.227,0.26),zorder=5)
		self.patches = []
		for info,shape in zip(self.m.Antioquia_info,self.m.Antioquia):
			self.patches.append( Polygon(np.array(shape),True))

		self.ax[4].add_collection(PatchCollection(self.patches, facecolor=[ 0.64705882,  0.97647059,  0.69411765], edgecolor=(0.0078,0.227,0.26), linewidths=.1, zorder=6))

		###########################################################################
		print 'Antioquia'
		# Antioquia
		self.m 		= Basemap(ax=self.ax[5],projection='merc',llcrnrlat=5.35,urcrnrlat=8.95,llcrnrlon=-77.18,urcrnrlon=-73.76,resolution='f')
		self.m.drawmapboundary(fill_color=[ 0.69019608,  0.89411765,  1.        ],zorder=1)
		self.m.fillcontinents(color=[ 0.96470588,  0.95686275,  0.95294118],lake_color=[ 0.69019608,  0.89411765,  1.        ],zorder=2)

		self.m.readshapefile('/home/calidadaire/ModuloAire/Tools/Departamentos','Departamentos',linewidth=0.1,color=(0.0078,0.227,0.26),zorder=3)
		self.m.readshapefile('/home/calidadaire/ModuloAire/Tools/Antioquia','Antioquia',linewidth=0.1,color=(0.0078,0.227,0.26),zorder=4)
		self.patches = []
		for info,shape in zip(self.m.Antioquia_info,self.m.Antioquia):
			self.patches.append( Polygon(np.array(shape),True))

		self.ax[5].add_collection(PatchCollection(self.patches, facecolor=[ 0.64705882,  0.97647059,  0.69411765], edgecolor=(0.0078,0.227,0.26), linewidths=.1,zorder=5 ))

		self.m.readshapefile('/home/calidadaire/ModuloAire/Tools/AreaMetropolitana','Area',linewidth=0.5,color=(0.0078,0.227,0.26),zorder=6)
		self.patches = []
		for info,shape in zip(self.m.Area_info,self.m.Area):
			self.patches.append( Polygon(np.array(shape),True))

		self.ax[5].add_collection(PatchCollection(self.patches, facecolor= [ 0.96470588,  0.95686275,  0.95294118], edgecolor=(0.0078,0.227,0.26), linewidths=.1,zorder=7 )) #fc=[0.21,0.60,0.65]

		##############################################################################
		# Logos

		#~ self.ax[7].imshow(plt.imread('/home/jhernandezv/Tools/Logosblanco.png'))

		print 'Saving'
		if 'textsave' not in kwargs.keys():
			plt.savefig('Figuras/%s/Mapa_%s.pdf' %(self.varsave,self.varsave),bbox_inches='tight')
			#~ os.system('scp Figuras/%s/Mapa_%s.pdf %s%s' %(self.varsave,self.varsave,self.path,self.varsave))
		else:
			plt.savefig('Figuras/Mapa_%s.pdf' %(self.textsave),bbox_inches='tight')
			#~ os.system('scp Figuras/Mapa_%s.pdf %s' %(self.textsave,self.path))

	def Plot_Mapa3(self,*args,**kwargs):

		self.figsize	= kwargs.get('figsize',11)
		self.estaciones = kwargs.get('estaciones', None)
		self.fontsize	= kwargs.get('fontsize',18)
		self.textsave	= kwargs.get('textsave',None)
		self.varsave 	= 'PM25' if self.var =='PM2.5' else 'PM25M' if self.var =='PM2.5M' else 'Meteorologia' if self.var == 'P_SSR' else self.var
# 		self.path 		= kwargs.get('path','sjaramillo@siata.gov.co:/var/www/CalidadAire/Figuras/')
		self.path 		= kwargs.get('path','nroldan@siata.gov.co:/var/www/CalidadAire/Figuras/')
                
		plt.close('all')
		self.fig 		= plt.figure(figsize=(self.figsize,self.figsize*(6.515-5.975)/(75.725-75.1255)),facecolor='w',edgecolor='w')
		self.ax			={}
		self.ax[0]		= self.fig.add_axes((0.00,0.00,1,1))		#Relieve
		self.ax[3]		= self.fig.add_axes((0.5,0.00,0.5,0.26))	#Fondo Mapas Pequeños
		self.ax[4]		= self.fig.add_axes((0.52,0.0,0.22,0.22))	#Mapa izquierda
		self.ax[5]		= self.fig.add_axes((0.76,0.0,0.22,0.22))	#Mapa derecha
		self.ax[2]		= self.fig.add_axes((0.0,0.91,0.35,0.09))	#Fondo Colorbar
		self.ax[6]		= self.fig.add_axes((0.0,0.97,0.33,0.03))	#Colorbar
# 		self.ax[7]		= self.fig.add_axes((-0.0306,-0.11081,1.0306,0.11081)) # Logo

		for i in self.ax.keys():
			plt.setp(self.ax[i].spines.values(), color='w') #(0.45, 0.45, 0.45))
			if i > 0: self.ax[i].tick_params(labelleft='off',labelbottom='off',right='off',left='off',bottom='off',top='off',which='both', color=(0.45, 0.45, 0.45))

		self.m 			= Basemap(ax=self.ax[0],projection='merc',llcrnrlat=5.975,urcrnrlat=6.515,llcrnrlon=-75.725,urcrnrlon=-75.1255,resolution='h') # area_thresh=10000, suppress_ticFalse)
		self.Setcolor( self.m.drawparallels(np.linspace(6.,6.4,5),labels=[1,0,0,0],fmt="%.1f",color=(0.45, 0.45, 0.45),fontsize=self.fontsize,zorder=1,ax=self.ax[0],alpha=1,rotation='vertical',linewidth=0) ,(0.45, 0.45, 0.45))

		self.Setcolor( self.m.drawmeridians(np.linspace(-75.5,-75.2,4),labels=[0,0,1,0], fmt="%.1f",color=(0.45, 0.45, 0.45),fontsize=self.fontsize,zorder=2,ax=self.ax[0],alpha=1,linewidth=0) ,(0.45, 0.45, 0.45))

		print 'DEM'
		#~ #DEM
		self.Read_DEM()
		self.X,self.Y	= np.meshgrid(self.DEM.columns.values,self.DEM.index.values)
		self.Xm,self.Ym	= self.m(self.X,self.Y)

		self.cs 		= self.m.contourf(self.Xm, self.Ym, self.DEM.values, levels=np.linspace(1300,3400,50), cmap=plt.cm.terrain_r,alpha=.5,extend='min',zorder=3)
		self.cs.cmap.set_over('k')
		self.cs.cmap.set_under('w')

		# Colorbar
		self.cbar		= plt.colorbar(self.cs,cax=self.ax[6],orientation='horizontal',format='%.f')
		self.cbar.set_label(r"Altitud $[km]$",fontsize=self.fontsize,color=(0.45, 0.45, 0.45))
		self.cbar.set_ticks([1500,2000,2500,3000])
		self.cbar.set_ticklabels([1.5,2,2.5,3])
		self.cbar.ax.tick_params(labelsize=self.fontsize,color=(0.45, 0.45, 0.45))
		#~ cbar.get_frame().set_edgecolor((0.45, 0.45, 0.45))

		self.m.readshapefile('/home/calidadaire/ModuloAire/Tools/AreaMetropolitana','Area',linewidth=0.5,color=(0.0078,0.227,0.26),zorder=4)

		#Scatter
		if type(self.estaciones)==type(None):
			self.X,self.Y		= self.m(self.EstR[self.EstR[self.var]==1]['Longitud'].values,self.EstR[self.EstR[self.var]==1]['Latitud'].values)
			self.estaciones		= self.EstR[self.EstR[self.var]==1]['Nombre'].values
		else: 
			self.x			= self.EstR[self.EstR['Nombre'].isin( self.estaciones)].sort_values(by='Latitud',ascending=False)[['Latitud','Longitud']]
			self.X,self.Y	= self.m(self.x['Longitud'].values,self.x['Latitud'].values)
		self.esta 		= self.EstR[self.EstR['Nombre'].isin(self.estaciones)]
		self.m.scatter(self.X,self.Y,s=800,facecolor=(0.0078,0.227,0.26),edgecolor=(0.0078,0.227,0.26),lw=1,alpha=1,zorder=5)

		#~ #####################################################################
		print 'Texto'
		#~ # Texto
		self.rows		= len(self.estaciones)/2+len(self.estaciones)%2

		self.ax[1]		= self.fig.add_axes((.5,0.26,0.5,0.05*(self.rows+1)))
		plt.setp(self.ax[1].spines.values(), color='w') #(0.45, 0.45, 0.45))
		self.ax[1].tick_params(labelleft='off',labelbottom='off',right='off',left='off',bottom='off',top='off',which='both', color=(0.45, 0.45, 0.45))

		#self.title = 'Estaciones de %s' %self.var if self.var in self.nombre_contaminantes +['Ruido','Automatica'] else 'Estaciones Manuales %s' %self.var[:-1]  if self.var in ['PM2.5M','PM10M'] else u'Estaciones Meteorológicas'
		self.title = 'Estaciones Ruido Ambiental'

		self.zor,self.c = 6,0
		for i in range(len(self.X)):
			self.ax[0].text(self.X[i],self.Y[i],'%.f' %self.esta.loc[self.esta.index[i],'Enumeracion'] if kwargs.get('Enumeracion',False) else self.esta.index[i], ha='center',va='center', fontsize=self.fontsize-2,color='w',zorder=self.zor,fontproperties=prop_2,)
			self.zor+=1
			if i == 0 :
				self.ax[1].set_ylim(0,self.rows+1)
				self.ax[1].invert_yaxis()
				self.ax[1].text(.5,.5,self.title,ha='center',va='center',fontsize=self.fontsize,color=(0.45, 0.45, 0.45),fontproperties=prop_2,)
			self.ax[1].text(.05+self.c,i%self.rows+1.5,'%.f - %s'%(self.esta.index[i],self.esta['Nombre'].values[i]),ha='left', va='center',color=(0.45, 0.45, 0.45),fontsize=self.fontsize-2,fontproperties=prop_1,)
			if i+1==self.rows: self.c+=.5

		self.ax[3].text(.5,.92,u'Ubicación Nacional y Regional',ha='center',va='center',fontsize=self.fontsize,color=(0.45, 0.45, 0.45),fontproperties=prop_2,)
		################################################################################
		#colores
		#~  Oceano			[ 0.71372549,  0.87058824,  0.88235294];
		#~ Antioquia		[ 0.64705882,  0.97254902,  0.70980392];[ 0.3372549 ,  0.91764706,  0.75294118] ;[ 0.44705882,  0.94901961,  0.68235294]
		#~ Colombia			[ 0.91372549,  0.87843137,  0.87843137]; 
		#~ Valle			[ 0.4745098 ,  0.52941176,  0.80784314];[ 0.36078431,  0.6745098 ,  0.94509804]

		print 'Colombia'
		# Colombia

		self.m 		= Basemap(ax=self.ax[4],projection='merc',llcrnrlat=-5,urcrnrlat=13,llcrnrlon=-81.86,urcrnrlon=-65,resolution='h')
		self.m.drawmapboundary(fill_color=[ 0.69019608,  0.89411765,  1.        ],zorder=1)
		self.m.fillcontinents(color=[ 0.96470588,  0.95686275,  0.95294118],lake_color=[ 0.69019608,  0.89411765,  1.        ],zorder=2)
		self.m.drawcountries(color=(0.0078,0.227,0.26),zorder=3)
		self.m.drawcoastlines(color=(0.0078,0.227,0.26),zorder=4)
		self.m.readshapefile('/home/calidadaire/ModuloAire/Tools/Antioquia','Antioquia',linewidth=0.1,color=(0.0078,0.227,0.26),zorder=5)
		self.patches = []
		for info,shape in zip(self.m.Antioquia_info,self.m.Antioquia):
			self.patches.append( Polygon(np.array(shape),True))

		self.ax[4].add_collection(PatchCollection(self.patches, facecolor=[ 0.64705882,  0.97647059,  0.69411765], edgecolor=(0.0078,0.227,0.26), linewidths=.1, zorder=6))

		###########################################################################
		print 'Antioquia'
		# Antioquia
		self.m 		= Basemap(ax=self.ax[5],projection='merc',llcrnrlat=5.35,urcrnrlat=8.95,llcrnrlon=-77.18,urcrnrlon=-73.76,resolution='f')
		self.m.drawmapboundary(fill_color=[ 0.69019608,  0.89411765,  1.        ],zorder=1)
		self.m.fillcontinents(color=[ 0.96470588,  0.95686275,  0.95294118],lake_color=[ 0.69019608,  0.89411765,  1.        ],zorder=2)

		self.m.readshapefile('/home/calidadaire/ModuloAire/Tools/Departamentos','Departamentos',linewidth=0.1,color=(0.0078,0.227,0.26),zorder=3)
		self.m.readshapefile('/home/calidadaire/ModuloAire/Tools/Antioquia','Antioquia',linewidth=0.1,color=(0.0078,0.227,0.26),zorder=4)
		self.patches = []
		for info,shape in zip(self.m.Antioquia_info,self.m.Antioquia):
			self.patches.append( Polygon(np.array(shape),True))

		self.ax[5].add_collection(PatchCollection(self.patches, facecolor=[ 0.64705882,  0.97647059,  0.69411765], edgecolor=(0.0078,0.227,0.26), linewidths=.1,zorder=5 ))

		self.m.readshapefile('/home/calidadaire/ModuloAire/Tools/AreaMetropolitana','Area',linewidth=0.5,color=(0.0078,0.227,0.26),zorder=6)
		self.patches = []
		for info,shape in zip(self.m.Area_info,self.m.Area):
			self.patches.append( Polygon(np.array(shape),True))

		self.ax[5].add_collection(PatchCollection(self.patches, facecolor= [ 0.96470588,  0.95686275,  0.95294118], edgecolor=(0.0078,0.227,0.26), linewidths=.1,zorder=7 )) #fc=[0.21,0.60,0.65]

		##############################################################################
		# Logos

# 		self.ax[7].imshow(plt.imread('/home/calidadaire/ModuloAire/Tools/Logosblanco.png'))

		print 'Saving'
		if 'textsave' not in kwargs.keys():
			plt.savefig('%sFiguras/%s/Mapa_%s.%s' %('Informe/' if self.var == 'Ruido' else '',self.varsave,self.varsave,kwargs.get('formato','png')),bbox_inches='tight')
			os.system('scp %sFiguras/%s/Mapa_%s.%s %s%s' %('Informe/' if self.var == 'Ruido' else '',self.varsave,self.varsave,kwargs.get('formato','png'),self.path,self.varsave))
			#plt.savefig('Mapa_ruido.png',bbox_inches='tight')
		else:
			plt.savefig('%sFiguras/Mapa_%s.%s' %('Informe/' if self.var == 'Ruido' else '',self.textsave,kwargs.get('formato','png')),bbox_inches='tight')
			os.system('scp %sFiguras/Mapa_%s.%s %s' %('Informe/' if self.var == 'Ruido' else '',self.textsave,kwargs.get('formato','png'),self.path))

	def Plot_Mapa2(self,*args,**kwargs):

		self.figsize	= kwargs.get('figsize',11)
		self.fontsize	= kwargs.get('fontsize',24)
		self.textsave	= kwargs.get('textsave',None)
		self.path 		= kwargs.get('path','sjaramillo@siata.gov.co:/var/www/jhernandezv/')


		self.Read_DEM(path=kwargs['DEM'],ajust=False) if 'DEM' in kwargs.keys() else self.Read_DEM()
		self.georef		= kwargs.get('georef',[self.DEM.index[0]+(self.DEM.index[0]-self.DEM.index[-1])*.03,self.DEM.index[-1]-(self.DEM.index[0]-self.DEM.index[-1])*.03,self.DEM.columns[0]+(self.DEM.columns[0]-self.DEM.columns[-1])*.03,self.DEM.columns[-1]-(self.DEM.columns[0]-self.DEM.columns[-1])*.03])

		self.figsize = (self.figsize,self.figsize*(self.georef[0]-self.georef[1])/(self.georef[3]-self.georef[2]))

		plt.close('all')
		self.fig 		= plt.figure(figsize=self.figsize,facecolor='w',edgecolor='w')
		self.ax			= {}
		self.ax[0]		= self.fig.add_axes((0.00,0.00,1,1))		#Relieve
		self.ax[1]		= self.fig.add_axes((1.01,0.22,0.5,0.62))
		self.ax[1].patch.set_visible(False)

		if 'Logo' in kwargs.keys():	
			self.logo 		= plt.imread(kwargs['Logo'])
			self.logodim	= [self.logo.shape[1]/100./self.figsize[0]* (.15/(self.logo.shape[0]/100./self.figsize[1])),  .15]
			self.ax[2]		= self.fig.add_axes((1 +(.46-self.logodim[0])*.5 if(.46-self.logodim[0])>0 else 1 ,1-self.logodim[1],self.logodim[0],self.logodim[1]))
			self.ax[2].imshow(self.logo)

		#~ self.ax[4]		= self.fig.add_axes((0.46,0.02,0.25,0.25))
		#~ self.ax[5]		= self.fig.add_axes((0.73,0.02,0.25,0.25))
		#~ self.ax[6]		= self.fig.add_axes((1.02,0.03,0.35,0.03))
		#Mapas
		self.ax[4]		= self.fig.add_axes((1.01,-0.04,0.24,0.24))
		self.ax[5]		= self.fig.add_axes((1.27,-0.04,0.24,0.24))
		# Colorbar
		self.ax[3]		= self.fig.add_axes((0.66,-0.04,0.34,0.11))
		self.ax[6]		= self.fig.add_axes((0.68,0.03,0.3,0.03))

		for i in self.ax.keys():
			plt.setp(self.ax[i].spines.values(), color='w')
			if i > 0: self.ax[i].tick_params(labelleft='off',labelbottom='off',right='off',left='off',bottom='off',top='off',which='both', color=(0.45, 0.45, 0.45))

		self.ax[0].tick_params(labelleft='on',labelbottom='on',right='off',left='on',bottom='on',top='off',which='both', color=(0.45, 0.45, 0.45))
		self.ax[0].spines['bottom'].set_color((0.45, 0.45, 0.45))
		self.ax[0].spines['left'].set_color((0.45, 0.45, 0.45))

		self.m 			= Basemap(ax=self.ax[0],projection='merc',llcrnrlat=self.georef[1],urcrnrlat=self.georef[0],llcrnrlon=self.georef[2],urcrnrlon=self.georef[3],resolution='h') 
		self.Setcolor( self.m.drawparallels(np.linspace(np.round(self.georef[1],decimals=1),np.round(self.georef[0],decimals=1),3),labels=[1,0,0,0],fmt="%.1f",color=(0.45, 0.45, 0.45),fontsize=self.fontsize,zorder=1,ax=self.ax[0],alpha=1,rotation='vertical',linewidth=0) ,(0.45, 0.45, 0.45) )
		self.Setcolor( self.m.drawmeridians(np.linspace(np.round(self.georef[2],decimals=1),np.round(self.georef[3],decimals=1),3),labels=[0,0,0,1], fmt="%.1f",color=(0.45, 0.45, 0.45),fontsize=self.fontsize,zorder=2,ax=self.ax[0],alpha=1,linewidth=0),(0.45, 0.45, 0.45))

		##############################################################################
		#~ #DEM
		if 'Municipios' in kwargs.keys(): 
			self.m.readshapefile('/home/calidadaire/ModuloAire/Tools/MunicipiosAntioquia','Municipios',linewidth=.5,color=(0.0078,0.227,0.26),zorder=1)
			self.patches = []
			for info,shape in zip(self.m.Municipios_info,self.m.Municipios):
				if info['nom_munici'] in kwargs['Municipios']:	self.patches.append( Polygon(np.array(shape),True))
			self.ax[0].add_collection(PatchCollection(self.patches,  facecolor= [ 0.96470588,  0.95686275,  0.95294118], edgecolor=(0.0078,0.227,0.26), linewidths=1, zorder=2)) 

		self.X,self.Y		= np.meshgrid(self.DEM.columns.values,self.DEM.index.values)
		self.Xm,self.Ym		= self.m(self.X,self.Y)
		#~ #norm=mpl.colors.Normalize(700,3100)
		self.cs 			= self.m.contourf(self.Xm, self.Ym, self.DEM.values, levels=np.linspace(self.DEM.min().min(),self.DEM.max().max(),50) if 'clim' not in kwargs.keys() else np.linspace(kwargs['clim'][0],kwargs['clim'][1],50), cmap=plt.cm.terrain_r,alpha=.5,extend='min',zorder=3)
		self.cs.cmap.set_over('b')
		self.cs.cmap.set_under('w')

		# Colorbar
		cbar=plt.colorbar(self.cs,cax=self.ax[6],orientation='horizontal',format='%.f')
		cbar.set_label(r"Altitud $[km]$",fontsize=self.fontsize,color=(0.45, 0.45, 0.45))
		cbar.set_ticks(np.linspace(self.DEM.min().min(),self.DEM.max().max(),4)  if 'clim' not in kwargs.keys() else np.linspace(kwargs['clim'][0],kwargs['clim'][1],4))
		cbar.set_ticklabels(np.round(np.linspace(self.DEM.min().min(),self.DEM.max().max(),4)/1000.,decimals=1) if 'clim' not in kwargs.keys() else np.round(np.linspace(kwargs['clim'][0],kwargs['clim'][1],4)/1000.,decimals=1))
		cbar.ax.tick_params(labelsize=self.fontsize,color=(0.45, 0.45, 0.45))

		zorder = 0
		if 'Basin' in kwargs.keys():
			if type(kwargs['Basin']) == type('str'):
				self.m.readshapefile(kwargs['Basin'],'Area',linewidth=1.5,color=(0.0078,0.227,0.26),zorder=4)
			else:
				for basin in kwargs['Basin']:
					self.m.readshapefile(basin,'Area',linewidth=1,color=(0.0078,0.227,0.26),zorder=4 + zorder)
					zorder +=1

		if 'add_shape' in kwargs.keys():
			self.m.readshapefile(kwargs['add_shape'],'add_shape',linewidth=.5,color=(0.0078,0.227,0.26),zorder=5 + zorder)
			self.patches = []
			for info,shape in zip(self.m.add_shape_info,self.m.add_shape):
				self.patches.append( Polygon(np.array(shape),True))
			self.ax[0].add_collection(PatchCollection(self.patches,  facecolor= [ 0.7372549 ,  0.99215686,  0.1372549 ], edgecolor=(0.0078,0.227,0.26), linewidths=.5, zorder=6 + zorder)) #[ 0.96470588,  0.95686275,  0.95294118]

		if 'Drainage' in kwargs.keys(): 
			self.m.readshapefile(kwargs['Drainage'],'Drainage',linewidth=1,color=[0.21, 0.6, 0.65],zorder=7 + zorder)

		if 'add_scatter' in kwargs.keys(): 
			self.X,self.Y		= self.m(kwargs['add_scatter'][0] ,kwargs['add_scatter'][1])
			self.m.scatter(self.X,self.Y,s=500 + (300 if 'add_stations' in kwargs.keys() else 0),facecolor=(0.0078,0.227,0.26),edgecolor='w',zorder=8+ zorder)

		if 'add_stations' in kwargs.keys():
			c = 0
			for i in range(len(self.X)):
				self.ax[0].text(self.X[i],self.Y[i],'%d' %(i+1), ha='center',va='center',
					fontsize=self.fontsize-3,color='w',zorder=9+zorder) #,bbox={'facecolor':(0.32,0.71,0.77), 'alpha':0.2, 'pad':2,'edgecolor':'w'})

				self.ax[1].text(0,.86-.76/(len(self.X)-1)*i,'%d - %s'%(i+1,kwargs['add_stations'][i] ), ha='left', va='center',color=(0.007,0.32,0.36),fontsize=self.fontsize,fontproperties=prop_1)
				#~ self.ax[0].text(self.m(-75.1,6.472-c)[0],self.m(-75.1,6.472-c)[1],'%d - %s'%(i+1,kwargs['add_stations'][i] ), ha='left', va='center',color=(0.007,0.32,0.36),fontsize=self.fontsize,fontproperties=prop_1)
				c += 0.0385
				zorder+=1

		if kwargs.get('legend',False):
			self.legend = {}
			plt.rcParams['legend.numpoints']=1
			#~ iqr     = plt.Line2D((0,1),(0,0),color=(0.875,0.875,0.875),marker='s',linestyle='',fillstyle='full',markeredgecolor='w')#(0.007,0.32,0.36))
			if 'Drainage' in kwargs.keys():		self.legend['Red de Drenaje']		= plt.Line2D((0,1),(0,0),color=(0.0078,0.227,0.26),ls='-',lw=1)
			if 'Basin' in kwargs.keys():		self.legend['Cuenca Hidrográfica']	= plt.Line2D((0,1),(0,0),color=(0.0078,0.227,0.26),ls='-',lw=4)
			if 'add_scatter' in kwargs.keys():	self.legend['Estación IDEAM']		= plt.Line2D((0,1),(0,0),ls='',marker='o',markersize=20,mfc=(0.0078,0.227,0.26),mec='w',lw=1,fillstyle='full')
			if 'add_shape' in kwargs.keys():	self.legend[kwargs.get('add_shape_name','Cabecera Urbana')]	= plt.Line2D((0,1),(0,0),ls='',marker='s',markersize=20,mfc=[ 0.7372549 ,  0.99215686,  0.1372549 ],mec=(0.0078,0.227,0.26),lw=.5,fillstyle='full')
			if 'Municipios' in kwargs.keys():
				for i in range(len(kwargs['Municipios'])):	self.legend[kwargs['Municipios'][i]]	= plt.Line2D((0,1),(0,0),ls='',marker='s',markersize=20,mfc=[ 0.96470588,  0.95686275,  0.95294118], mec=(0.0078,0.227,0.26),lw=1,fillstyle='full')

			self.leg		= self.ax[0].legend(self.legend.values(),self.legend.keys(),bbox_to_anchor=(1,.54),fontsize=self.fontsize-2, loc='upper left',title='Convenciones',labelspacing=.8)
			self.leg.get_frame().set_edgecolor('w')
			for text in self.leg.get_texts(): plt.setp(text, color = (0.45, 0.45, 0.45))
			#~ self.leg.get_title().set_fontsize(self.fontsize)
			plt.setp(self.leg.get_title(),fontsize=self.fontsize,weight='bold',color=(0.45, 0.45, 0.45))
		#####################################################################
		#~ # Texto

		if 'title' in kwargs.keys():
			self.ax[1].text(.5,.95,kwargs['title'],ha='center',va='center',fontsize=self.fontsize+2,color=(0.45, 0.45, 0.45),weight='bold')
		if 'add_text1' in kwargs.keys():
			self.ax[1].text(.0,.851,kwargs['add_text1'][0],ha='left',va='bottom',fontsize=self.fontsize-2,color=(0.45, 0.45, 0.45))
			self.ax[1].text(.0,.849,kwargs['add_text1'][1],ha='left',va='top',fontsize=self.fontsize-2,color=(0.45, 0.45, 0.45))
		if 'add_text2' in kwargs.keys():
			self.ax[1].text(.0,.751,kwargs['add_text2'][0],ha='left',va='bottom',fontsize=self.fontsize-2,color=(0.45, 0.45, 0.45))
			self.ax[1].text(.0,.749,kwargs['add_text2'][1],ha='left',va='top',fontsize=self.fontsize-2,color=(0.45, 0.45, 0.45))
		if 'add_text3' in kwargs.keys():
			self.ax[1].text(.0,.651,kwargs['add_text3'][0],ha='left',va='bottom',fontsize=self.fontsize-2,color=(0.45, 0.45, 0.45))
			self.ax[1].text(.0,.649,kwargs['add_text3'][1],ha='left',va='top',fontsize=self.fontsize-2,color=(0.45, 0.45, 0.45))
		if 'add_text4' in kwargs.keys():
			self.ax[1].text(.0,.551,kwargs['add_text4'][0],ha='left',va='bottom',fontsize=self.fontsize-2,color=(0.45, 0.45, 0.45))
			self.ax[1].text(.0,.549,kwargs['add_text4'][1],ha='left',va='top',fontsize=self.fontsize-2,color=(0.45, 0.45, 0.45))
		self.ax[1].text(.5,.00,u'Ubicación Nacional y Regional',ha='center',va='bottom',fontsize=self.fontsize,color=(0.45, 0.45, 0.45),weight='bold')
		################################################################################
		#colores
		#~  Oceano			[ 0.71372549,  0.87058824,  0.88235294];
		#~ Antioquia		[ 0.64705882,  0.97254902,  0.70980392];[ 0.3372549 ,  0.91764706,  0.75294118] ;[ 0.44705882,  0.94901961,  0.68235294]
		#~ Colombia			[ 0.91372549,  0.87843137,  0.87843137]; 
		#~ Valle			[ 0.4745098 ,  0.52941176,  0.80784314];[ 0.36078431,  0.6745098 ,  0.94509804]

		print 'Colombia'
		# Colombia

		self.m 		= Basemap(ax=self.ax[4],projection='merc',llcrnrlat=-5,urcrnrlat=13,llcrnrlon=-81.86,urcrnrlon=-65,resolution='h')
		self.m.drawmapboundary(fill_color=[ 0.69019608,  0.89411765,  1.        ],zorder=1)
		self.m.fillcontinents(color=[ 0.96470588,  0.95686275,  0.95294118],lake_color=[ 0.69019608,  0.89411765,  1.        ],zorder=2)
		self.m.drawcountries(color=(0.0078,0.227,0.26),zorder=3)
		self.m.drawcoastlines(color=(0.0078,0.227,0.26),zorder=4)
		self.m.readshapefile('/home/calidadaire/ModuloAire/Tools/Antioquia','Antioquia',linewidth=0.1,color=(0.0078,0.227,0.26),zorder=5)
		self.patches = []
		for info,shape in zip(self.m.Antioquia_info,self.m.Antioquia):
			self.patches.append( Polygon(np.array(shape),True))

		self.ax[4].add_collection(PatchCollection(self.patches, facecolor=[0.32, 0.71, 0.77], edgecolor=(0.0078,0.227,0.26), linewidths=.1, zorder=6))

		###########################################################################
		print 'Antioquia'
		# Antioquia
		self.m 		= Basemap(ax=self.ax[5],projection='merc',llcrnrlat=5.35,urcrnrlat=8.95,llcrnrlon=-77.18,urcrnrlon=-73.76,resolution='f')
		self.m.drawmapboundary(fill_color=[ 0.69019608,  0.89411765,  1.        ],zorder=1)
		self.m.fillcontinents(color=[ 0.96470588,  0.95686275,  0.95294118],lake_color=[ 0.69019608,  0.89411765,  1.        ],zorder=2)

		self.m.readshapefile('/home/calidadaire/ModuloAire/Tools/Departamentos','Departamentos',linewidth=0.1,color=(0.0078,0.227,0.26),zorder=3)
		self.m.readshapefile('/home/calidadaire/ModuloAire/Tools/Antioquia','Antioquia',linewidth=0.1,color=(0.0078,0.227,0.26),zorder=4)
		self.patches = []
		for info,shape in zip(self.m.Antioquia_info,self.m.Antioquia):
			self.patches.append( Polygon(np.array(shape),True))

		self.ax[5].add_collection(PatchCollection(self.patches, facecolor=[0.32, 0.71, 0.77], edgecolor=(0.0078,0.227,0.26), linewidths=.1,zorder=5 ))

		if 'Basin' in kwargs.keys():
			self.m.readshapefile(kwargs['Basin'],'Area',linewidth=0.5,color=(0.0078,0.227,0.26),zorder=6)
			self.patches = []
			for info,shape in zip(self.m.Area_info,self.m.Area):
				self.patches.append( Polygon(np.array(shape),True))

			self.ax[5].add_collection(PatchCollection(self.patches, facecolor= [ 0.96470588,  0.95686275,  0.95294118], edgecolor=(0.0078,0.227,0.26), linewidths=.1,zorder=7 )) #fc=[0.21,0.60,0.65]

		if 'Arrow' in kwargs.keys():
			self.ax[5].annotate('' , xy=self.m(kwargs['Arrow'][0],kwargs['Arrow'][1]), xytext=self.m(-75.47,7.15),va='center',ha='center',fontsize=self.fontsize,weight='bold',color=(0.0078,0.227,0.26),arrowprops=dict(facecolor=(0.0078,0.227,0.26),edgecolor=(0.0078,0.227,0.26), shrink=0.00,width=.5,headwidth=5),zorder=8) #bbox=dict(facecolor=colors[0], edgecolor='none', boxstyle='round',alpha=.2))

		##############################################################################
		# Logos

		#~ self.ax[7].imshow(plt.imread('/home/jhernandezv/Tools/Logosblanco.png'))

		plt.savefig('%sFiguras/Mapa%s.pdf' %('Informe/' if self.var == 'Ruido' else '',kwargs.get('textsave','')), bbox_inches='tight')
		os.system('scp %sFiguras/Mapa%s.pdf %s' %('Informe/' if self.var == 'Ruido' else '',kwargs.get('textsave',''),self.path))


	def Plot_Mapa(self,*args,**kwargs):

		estaciones		= kwargs.get('estaciones',None)
		textsave		= kwargs.get('textsave',None)
		var = self.var

		title = 'Estaciones de %s' %var if var != 'P_SSR' else ('Estaciones Meteorológicas').decode('utf-8')
		#~ title = 'Estacion'
		if var in ['PM2.5M','PM10M']:
			title = 'Estaciones Manuales'
		plt.close('all')
		fig = plt.figure(figsize=(14.9,15.9),facecolor='w',edgecolor='w')

		ax = fig.add_subplot(111)
		plt.setp(ax.spines.values(), color=(0.45, 0.45, 0.45))
		ax.xaxis.label.set_color((0.45, 0.45, 0.45))
		ax.yaxis.label.set_color((0.45, 0.45, 0.45))
		ax.tick_params(which='both', color=(0.45, 0.45, 0.45))

		m = Basemap(projection='merc',llcrnrlat=5.975,urcrnrlat=6.515,llcrnrlon=-75.725,urcrnrlon=-75.215,resolution='i') # area_thresh=10000, suppress_ticks=False)
		par = m.drawparallels(np.linspace(5.975,6.515,5),labels=[1,0,0,0],fmt="%.1f",color=(0.45, 0.45, 0.45),fontsize=22)
		self.Setcolor(par,(0.45, 0.45, 0.45))
		mer = m.drawmeridians(np.linspace(-75.725,-75.215,5),labels=[0,0,0,1], fmt="%.1f",color=(0.45, 0.45, 0.45),fontsize=22)
		self.Setcolor(mer,(0.45, 0.45, 0.45))
		x0,y0=m([-75.725,-75.215],[5.975,6.515])
		im = m.imshow(plt.imread('/home/calidadaire/ModuloAire/Tools/Valle.png')[::-1], extent=(x0[0], x0[1], y0[0], y0[1]))

		if type(estaciones)==type(None):
			X,Y=m(self.EstR[self.EstR[var]==1]['Longitud'].values,self.EstR[self.EstR[var]==1]['Latitud'].values)
			estaciones=self.EstR[self.EstR[var]==1]['Nombre'].values
		else: 
			x = self.EstR[self.EstR['Nombre'].isin( estaciones)].sort_values(by='Latitud',ascending=False)[['Latitud','Longitud']]
			X,Y=m(x['Longitud'].values,x['Latitud'].values)
		esta = self.EstR[self.EstR['Nombre'].isin(estaciones)]

		m.readshapefile('/home/calidadaire/ModuloAire/Tools/AreaMetropolitana','Area Metropolitana',linewidth=0.5,color=(0.0078,0.227,0.26))
		m.scatter(X,Y,s=1300,facecolor=(0.0078,0.227,0.26),edgecolor=(0.0156,0.486,0.556),lw=1,alpha=1)
		ax.text(m(-75.2,6.5)[0],m(-75.2,6.5)[1],title,ha='left',va='center',fontproperties=prop_2,fontsize=24,color=(0.0078,0.227,0.26),)
			#bbox={'facecolor':(0.32,0.71,0.77), 'alpha':0.2, 'pad':3,'edgecolor':'w'})
		c = 0
		for i in range(len(X)):
			ax.text(X[i],Y[i],'%.f' %esta.index[i], ha='center',va='center',
				fontproperties=prop_2, fontsize=22,color='w') #,bbox={'facecolor':(0.32,0.71,0.77), 'alpha':0.2, 'pad':2,'edgecolor':'w'})
			ax.text(m(-75.2,6.46-c)[0],m(-75.2,6.46-c)[1],'%.f - %s'%(esta.index[i],esta['Nombre'].values[i][:3]),
				ha='left', va='center',color=(0.007,0.32,0.36),fontsize=24,fontproperties=prop_1)
			#arrowprops={'facecolor':(0.007,0.32,0.36),'edgecolor':(0.007,0.32,0.36),'frac':4,'headwidth':4, 'shrink':0.05,'width':1.5,'alpha':0.6},

			ax.text(m(-75.2,6.44075-c)[0],m(-75.2,6.44075-c)[1],'%s'%(esta['Nombre_Estacion'].values[i].decode('utf-8')),
				ha='left', va='center',fontproperties=prop_2,color=(0.007,0.32,0.36),fontsize=22)
			c += 0.0385

		varsave = 'PM25' if var =='PM2.5'else 'PM25M' if var =='PM2.5M' else 'Meteorologia' if var == 'P_SSR' else var

		if type(textsave)==type(None):
			plt.savefig('Figuras/%s/Mapa_%s.pdf' %tuple([varsave]*2),bbox_inches='tight')
			os.system('scp Figuras/%s/Mapa_%s.pdf jhernandezv@siata.gov.co:/var/www/CalidadAire/Figuras/%s' %tuple([varsave]*3))
		else:
			plt.savefig('Figuras/Mapa_%s.pdf' %textsave,bbox_inches='tight')
			os.system('scp Figuras/Mapa_%s.pdf jhernandezv@siata.gov.co:/var/www/CalidadAire/Figuras/' %textsave)

	def Plot_Barbs_EOF(self,*args,**kwargs):

		fontsize		= kwargs.get('fontisze',16)

		figsize			= kwargs.get('figsize',(14,8.5))
		path			= kwargs.get('path','Winds/RWP/EOF/')
		ht				= kwargs.get('ht',78)
		latitud_perfil	= kwargs.get('latitud_perfil', 6.229337) 
		longitud_perfil	= kwargs.get('longitud_perfil',-75.589893)
		ylim			= kwargs.get('ylim',[1400, 5600])
		xlim			= kwargs.get('xlim',[-75.70,-75.35])
		self.letra				= kwargs.get('letra',['a)','b)','c)','d)','e)','f)'])

		plt.close('all')
		fig = plt.figure(figsize=figsize,facecolor='w',edgecolor='w')
		plt.rcParams["xtick.labelsize"]=fontsize
		plt.rcParams["ytick.labelsize"]=fontsize

		ax={}
		ax[0]=fig.add_axes((0.05,0.05,0.9,0.9))		#Relieve
		ax[7]=fig.add_axes((0.05,0.05,0.3,0.9))
		ax[1]= ax[7].twiny()						#EOF U,V
		ax[1].patch.set_visible(False)
		ax[7].patch.set_visible(False)
		ax[6]=fig.add_axes((0.35,0.05,0.12,0.9))
		ax[2]= ax[6].twiny()						#EOF W
		ax[2].patch.set_visible(False)
		ax[6].patch.set_visible(False)

		ax[3]=fig.add_axes((0.65,0.75,0.3,0.2))		# % Varianza
		ax[4]=fig.add_axes((0.65,0.41,0.3,0.3))		#CP1
		ax[5]=fig.add_axes((0.65,0.1,0.3,0.3))		#CP2
		ax[5].patch.set_visible(False)

		#~ ax[i].locator_params(axis='y',nbins=3)
		#~ ax[i].locator_params(axis='x',nbins=3)
		c=0
		for c in [0,1,2,3,4,5,6,7]:
			for spinename, spine in ax[c].spines.iteritems():
				spine.set_visible(False)
			ax[c].tick_params(top='off', right='off',bottom='off',left=('off' if c!=1 else 'on'),which='both',color=(0.45, 0.45, 0.45))

		for c in [0,2,3,4,5]:
			for side in ['left','bottom']:
				if (c not in [0,2]) | ((c==0) & (side=='left')) | ((c==2) & (side=='bottom')):
					ax[c].spines['top' if (c==2) & (side=='bottom') else side].set_visible(True)
					ax[c].spines['top' if (c==2) & (side=='bottom') else side].set_color((0.45, 0.45, 0.45))
				if c not in [0,2] : ax[c].tick_params(left='on',bottom='on' ,color=(0.45, 0.45, 0.45))
		ax[0].tick_params(left='on', which='both', color=(0.45, 0.45, 0.45) )
		ax[2].tick_params(top='on', which='both',direction='inout',length=10, color=(0.45, 0.45, 0.45) )

		ax[0].set_xticklabels([])
		ax[6].set_xticklabels([])
		ax[6].set_yticklabels([])
		ax[7].set_xticklabels([])
		ax[7].set_yticklabels([])
		ax[4].set_xticklabels([])

		self.Read_DEM()
		height	= self.DEM.loc[self.DEM.index[np.abs(self.DEM.index.values-latitud_perfil).argmin()],self.DEM.columns[np.abs(self.DEM.columns.values-longitud_perfil).argmin()]]
		#Perfil
		longmin	= np.abs(self.DEM.columns.values-xlim[0]).argmin()
		longmax	= np.abs(self.DEM.columns.values-(-75.5)).argmin()
		latp= np.abs(self.DEM.index.values-latitud_perfil).argmin()
		Dem		=self.DEM.loc[self.DEM.index[latp],self.DEM.columns[longmin:longmax]]
		ax[0].fill_between(Dem.index.values,np.zeros(Dem.index.size),Dem.values, color=(0.85,0.85,0.85))
		ax[0].set_xlim(xlim[0],xlim[1])
		ax[0].set_ylim(ylim[0],ylim[1])
		ax[0].set_ylabel(r'Altitude $[km]$',fontsize=fontsize,weight='bold',color=(0.45, 0.45, 0.45))
		ax[0].set_yticks(range(ylim[0],ylim[1],100),minor=True)
		ax[0].set_yticks(range(1500,ylim[1],500))
		ax[0].set_yticklabels(np.arange(1.5,ylim[1]/1000.,.5))

		ax[0].text(-75.67,2750+height,'EOF 1',color='b',weight='bold',fontsize=fontsize,ha='center')
		ax[0].text(-75.645,2750+height,'EOF 2',color=[ 0.3,  0.3,  0.3],weight='bold',fontsize=fontsize,ha='center')

		ax[0].text(-75.67,2500+height,'%.1f' %self.varianza[0],color='b',weight='bold',fontsize=fontsize,ha='center')
		ax[0].text(-75.645,2500+height,'%.1f' %self.varianza[1],color=[ 0.3,  0.3,  0.3],weight='bold',fontsize=fontsize,ha='center')
		ax[0].text(-75.6575,3000+height,'Variance [%]',color=(0.45, 0.45, 0.45),weight='bold',fontsize=fontsize,ha='center')

		ax[0].text(-75.605,5800,r'EOF $(u,v)$',fontsize=fontsize,weight='bold',color=(0.45, 0.45, 0.45),ha='center',va='bottom')
		ax[0].text(-75.559,5800,r'EOF $\omega\ [m/s] $',fontsize=fontsize,weight='bold',color=(0.45, 0.45, 0.45),ha='center',va='bottom')

		#EOF U,V
		n=2 # Numero de componentes

		Q1=ax[1].quiver(np.zeros(self.ht[:ht][::n].size),self.ht[:ht][::n]+height,self.eve[:ht,0][::n],self.eve[ht:2*ht,0][::n],color='b',alpha=0.7,scale=1 ,)
		Q2=ax[1].quiver(np.zeros(self.ht[:ht][::n].size)+.05,self.ht[:ht][::n]+height,self.eve[:ht,1][::n],self.eve[ht:2*ht,1][::n],color='k',alpha=0.7,scale=1 ,)

		ax[1].quiverkey(Q1, .3,.85 , 0.1, ' ', color=(0.45, 0.45, 0.45), labelpos='W', coordinates='axes', fontproperties={'weight': 'bold'}) #r'$0.5 \frac{m}{s}$' if i==0 else ''
		ax[0].text(xlim[0]+(xlim[1]-xlim[0])*.12,height+(ylim[1]-ylim[0])*.78, r'0.1 $[m/s]$',fontsize=fontsize,weight='bold',color=(0.45, 0.45, 0.45),ha='center',va='center')
		#~ ax[1].quiverkey(Q2, .5,.8 , 0.1, ' ', color='k', labelpos='W', coordinates='axes', fontproperties={'weight': 'bold'}) #r'$0.5 \frac{m}{s}$' if i==0 else ''

		#~ ax[1].axvline(0,color='k',alpha=0.5)
		#~ ax[1].axvline(0.05,color='k',alpha=0.5)
		ax[1].set_xlim(-.265,.1)
		ax[1].set_ylim(ylim[0],ylim[1])
		#~ plt.setp(ax[1].get_xticklabels(), fontsize=kwargs.get('fontsize','large'),color='w')
		ax[1].set_xticklabels([])

		#EOF W
		ax[2].plot(self.eve[2*ht:,0][::n],self.ht[:ht][::n]+height,lw=1,color='b',marker='o',markersize=3)
		ax[2].plot(self.eve[2*ht:,1][::n],self.ht[:ht][::n]+height,lw=1,color=(0.3,0.3,0.3),marker='o',markersize=3)
		ax[2].set_xlim(self.eve[2*ht:,:2].min() - (self.eve[2*ht:,:n].max() - self.eve[2*ht:,:n].min())*.05 , self.eve[2*ht:,:2].max() + (self.eve[2*ht:,:n].max() - self.eve[2*ht:,:n].min())*.05 )
		ax[2].set_ylim(ylim[0],ylim[1])
		ax[2].locator_params(axis='x',nbins=2)
		plt.setp(ax[2].get_xticklabels(),fontsize=fontsize-2)
		#~ ax[2].set_xticks([-0.01,0,0.01])
		#~ ax[2].set_xticklabels([-0.01,0,0.01])
		ax[2].axvline(0.0,lw=.1,ls='--',color=(0.45, 0.45, 0.45))

		#Varianza %
		ax[3].plot(range(1,self.varianza.size+1),self.varianza,lw=3,color=(0.4, 0.4, 0.4),marker='o',label='Explained Variance')
		leg	= ax[3].legend(loc='best',fontsize=fontsize-2,framealpha=0.3)
		leg.get_frame().set_edgecolor((0.45, 0.45, 0.45))
		for text in leg.get_texts(): plt.setp(text, color = (0.45, 0.45, 0.45))
		ax[3].set_ylim(-3,self.varianza.max()*1.25)
		ax[3].set_xlim(0,20)
		ax[3].set_ylabel('Percentage [%]',fontsize=fontsize,weight='bold',color = (0.45, 0.45, 0.45))
		ax[3].locator_params(axis='y',nbins=5)
		ax[3].locator_params(axis='x',nbins=5)

		#CP
		self.CP['Hora [UTC-5]']=self.CP.index.hour
		self.CP['Mes']=self.CP.index.month
		#~ self.CP.boxplot(column=1,by='Hora [UTC-5]',ax=ax[4],whis=3,notch=True)
		#~ self.CP.boxplot(column=2,by='Hora [UTC-5]',ax=ax[5],whis=3,notch=True)
		#~ ax[5].set_xlabel(r'Hora $[UTC-5]$',fontsize=fontsize)
		self.box = self.CP.boxplot(column=1,by='Mes',ax=ax[4],whis=3,notch=True,patch_artist=True, medianprops={'linewidth': 1.5},whiskerprops={'linestyle': '-'},return_type='dict')[1]

		for boxes,medians in zip(self.box['boxes'],self.box['medians']):
			boxes.set_facecolor([ 0.30196078,  0.30196078,  0.99607843])
			boxes.set_edgecolor([0.0078,0.227,0.26])
			medians.set_color([0.0078,0.227,0.26])

		for whiskers,caps in zip(self.box['whiskers'],self.box['caps']):
			whiskers.set_color([0.0078,0.227,0.26])
			caps.set_color([0.0078,0.227,0.26])

		self.box = self.CP.boxplot(column=2,by='Mes',ax=ax[5],whis=3,notch=True,patch_artist=True, medianprops={'linewidth': 1.5},whiskerprops={'linestyle': '-'},return_type='dict')[2]

		for boxes,medians in zip(self.box['boxes'],self.box['medians']):
			boxes.set_facecolor([ 0.3,  0.3,  0.3])
			boxes.set_edgecolor([0.0078,0.227,0.26])
			medians.set_color([0.0078,0.227,0.26])

		for whiskers,caps in zip(self.box['whiskers'],self.box['caps']):
			whiskers.set_color([0.0078,0.227,0.26])
			caps.set_color([0.0078,0.227,0.26])

		ax[5].set_xlabel(r'Month',fontsize=fontsize,color = (0.45, 0.45, 0.45) )
		ax[5].set_xticklabels(ax[5].get_xticklabels(),fontsize=fontsize)
		ax[4].set_xlabel('')

		#Reestablece CP
		self.CP.drop(['Hora [UTC-5]','Mes'] ,axis=1,inplace=True)

		plt.suptitle('')
		for cp in [4,5]:
			ax[cp].grid()
			ax[cp].set_ylabel('PC %d' %(cp-3),fontsize=fontsize,color='b' if cp ==4 else (0.3,.3,.3) ,weight='bold')
			ax[cp].set_ylim(self.CP[[1,2]].min().min(),self.CP[[1,2]].max().max())
			ax[cp].set_title('')
			ax[cp].axhline(0,color='k',alpha=.5)
			#~ ax[cp].set_xticks(range(1,24,2))

		ax[4].set_xticklabels([])
		#~ ax[5].set_xticklabels(range(0,23,2),fontsize=fontsize)
		c=0
		for i in [1,3,4,5]:
			self.x=[ax[i].get_xlim()[0],ax[i].get_xlim()[-1]]
			self.y=[ax[i].get_ylim()[0],ax[i].get_ylim()[-1]]
			print self.x, self.y
			ax[i].text(self.x[0]+(self.x[1]-self.x[0])*.05,self.y[0]+(self.y[1]-self.y[0])*.94,self.letra[c],ha='center',va='center',fontsize=fontsize,color=(0.45, 0.45, 0.45),weight='bold')
			c += 1

		plt.savefig('Figuras/Barbs_EOF%s.pdf' %(kwargs.get('textsave','')),bbox_inches='tight')
		os.system('scp Figuras/Barbs_EOF%s.pdf jhernandezv@siata.gov.co:/var/www/jhernandezv/%s' %(kwargs.get('textsave',''),path))

	def Plot_Boxplot(self,df,*args,**kwargs):

		self.textsave		= kwargs.get('textsave','')
		self.fontsize		= kwargs.get('fontsize','medium')
		self.varsave 		= 'PM25' if (self.var =='PM2.5') else 'PM25M' if (self.var=='PM2.5M') else  self.var
		self.path 			= kwargs.get('path','jhernandezv@siata.gov.co:/var/www/CalidadAire/Figuras/%s/' %self.varsave)
		self.title 			= kwargs.get('title',None)
		self.ylim			= kwargs.get('ylim',None)
		self.ax				= kwargs.get('ax',None)
		self.savefig		= type(self.ax) == type(None)

		if self.savefig:
			plt.close('all')
			self.fig 	= plt.figure(figsize=(10, 3),facecolor='w',edgecolor='w')
			self.ax		= self.fig.add_subplot(111)
			self.ax.spines['top'].set_visible(False)
			self.ax.spines['right'].set_visible(False)
			self.ax.spines['left'].set_color((0.45, 0.45, 0.45))
			self.ax.spines['bottom'].set_color((0.45, 0.45, 0.45))
			self.ax.tick_params(top='off', right='off',bottom='on',left='on',which='both',color=(0.45, 0.45, 0.45),labelsize=self.fontsize)

		self.box = df.boxplot(ax=self.ax,grid=False,whis=3,patch_artist=True, medianprops={'linewidth': 1.5},whiskerprops={'linestyle': '-'},return_type='dict') #,boxprops={'facecolor':[0.61,0.82,0.88],'edgecolor':[0.0078,0.227,0.26]} )# return_type='axes')
		for boxes,medians in zip(self.box['boxes'],self.box['medians']):
			boxes.set_facecolor([0.61,0.82,0.88])
			boxes.set_edgecolor([0.0078,0.227,0.26])
			medians.set_color([0.0078,0.227,0.26])

		for whiskers,caps in zip(self.box['whiskers'],self.box['caps']):
			whiskers.set_color([0.0078,0.227,0.26])
			caps.set_color([0.0078,0.227,0.26])

		if self.savefig:
			self.ax.yaxis.grid(True,alpha=.6,zorder=1,color=(0.45, 0.45, 0.45))
			self.ax.set_ylabel(self.label['Ruido'],fontsize=self.fontsize,color=(0.45, 0.45, 0.45),fontproperties=prop_1)
			self.ax.set_xticklabels([self.ax.get_xticklabels()[j].get_text() for j in range(df.columns.size)],fontsize=self.fontsize,color=(0.45, 0.45, 0.45),fontproperties=prop_1)
			plt.setp(self.ax.get_yticklabels(),fontproperties= prop_1)
			if type(self.title)!= type(None): self.ax.set_title(self.title,fontsize=self.fontsize,color=(0.45, 0.45, 0.45),fontproperties=prop_2,loc ='right')
			if type(self.ylim)!= type(None): self.ax.set_ylim(self.ylim[0],self.ylim[1])

			#~ self.ax.set_yticklabels([self.ax.get_yticklabels()[j].get_text() for j in range( ax[0].get_yticks().size)],fontsize=fontsize,color=(0.45, 0.45, 0.45),fontproperties=prop_1)
			#~ [0.69,0.87,0.93],[0.61,0.82,0.88],[0.32,0.71,0.77],[0.21,0.60,0.65],[0.0156,0.486,0.556],[0.007,0.32,0.36],[0.0078,0.227,0.26]
			plt.savefig('Figuras/%s/Boxplot_%s%s.pdf' %(self.var,self.var,self.textsave),bbox_inches='tight')
			os.system('scp Figuras/%s/Boxplot_%s%s.pdf %s' %(self.var,self.var,self.textsave,self.path))

	def Plot_Mapa_EOF(self,*args,**kwargs):

		self.fontsize			= kwargs.get('fontsize',14)
		self.numero_componentes	= kwargs.get('numero_componentes',2)
		self.color				= kwargs.get('color',['b','k',(0,0.666,0),'c'])
		self.path				= kwargs.get('path','Winds/Vaisala/EOF/')
		self.letra				= kwargs.get('letra',['a)','c)','d)','b)','e)','f)'])

		plt.close('all')
		self.fig = plt.figure(figsize=(14,7),facecolor='w',edgecolor='w')
		plt.subplots_adjust(wspace=.05,hspace=.8,bottom=0.,left=0.,right=1,top=1)

		self.ax			= {}
		self.gs 		= grid.GridSpec(8,13)
		self.ax[0]		= plt.subplot(self.gs[:,:8])
		self.ax[1] 		= plt.subplot(self.gs[2:5,8:])
		self.ax[2] 		= plt.subplot(self.gs[5:,8:])
		self.ax[3] 		= plt.subplot(self.gs[:2,8:])

		for i in [1,2,3]:
			self.ax[i].spines['top'].set_visible(False)
			self.ax[i].spines['right'].set_visible(False)
			self.ax[i].spines['left'].set_color((0.45, 0.45, 0.45))
			self.ax[i].spines['bottom'].set_color((0.45, 0.45, 0.45))
			self.ax[i].tick_params(top='off', right='off',bottom='on',left='on',which='both',color=(0.45, 0.45, 0.45),labelsize=self.fontsize)
			self.ax[i].xaxis.label.set_color((0.45, 0.45, 0.45))
			self.ax[i].yaxis.label.set_color((0.45, 0.45, 0.45))

		plt.setp(self.ax[0].spines.values(), color='w')
		self.ax[1].tick_params(bottom='on',direction='inout',axis='x',length=5,color=(0.45, 0.45, 0.45),labelsize=self.fontsize)

		self.m 			= Basemap(projection='merc',llcrnrlat=5.975,urcrnrlat=6.515,llcrnrlon=-75.725,urcrnrlon=-75.215,resolution='i',ax=self.ax[0]) 
		self.par 		= self.m.drawparallels(np.linspace(6,6.4,5),labels=[1,0,0,0],fmt="%.1f",color=(0.45, 0.45, 0.45),fontsize=self.fontsize,ax=self.ax[0],rotation='vertical',linewidth=0)
		self.Setcolor(self.par,(0.45, 0.45, 0.45))
		self.mer 		= self.m.drawmeridians(np.linspace(-75.6,-75.2,5),labels=[0,0,1,0], fmt="%.1f",color=(0.45, 0.45, 0.45),fontsize=self.fontsize,linewidth=0)
		self.Setcolor(self.mer,(0.45, 0.45, 0.45))

		#~ x0,y0=m([-75.725,-75.215],[5.975,6.515])
		#im = m.imshow(plt.imread('Valle.png')[::-1], extent=(x0[0], x0[1], y0[0], y0[1]))

		print 'DEM'
		self.Read_DEM()
		self.X,self.Y	= np.meshgrid(self.DEM.columns.values,self.DEM.index.values)
		self.Xm,self.Ym	= self.m(self.X,self.Y)

		self.cs 		= self.m.contourf(self.Xm, self.Ym, self.DEM.values, levels=np.linspace(1300,3400,50), cmap=plt.cm.terrain_r,alpha=.35,extend='min')
		self.cs.cmap.set_over('k')
		self.cs.cmap.set_under('w')

		self.cbar		= self.m.colorbar(self.cs,ax=self.ax[0],location='bottom',pad='1%',size='2%',format='%.f')
		self.cbar.set_label(r"Altitude $[km]$",fontsize=self.fontsize,color=(0.45, 0.45, 0.45))
		self.cbar.set_ticks([1500,2000,2500,3000])
		self.cbar.set_ticklabels([1.5,2,2.5,3])
		self.cbar.ax.tick_params(labelsize=self.fontsize,color=(0.45, 0.45, 0.45))
		plt.setp(self.cbar.ax.spines.values(), color=(0.45, 0.45, 0.45))

		self.m.readshapefile('/home/calidadaire/ModuloAire/Tools/AreaMetropolitana','Area',linewidth=0.5,color=(0.0078,0.227,0.26))

		#~ norm=mpl.colors.Normalize(10,32)
		#~ Xe = self.Est[self.Est['Vaisala']==1].sort_index()[['Longitud','Latitud']].values

		print 'Vectores y texto'
		self.Xe 			= self.EstV.loc[self.Winds['U'].columns.values].sort_index()[['Longitud','Latitud']].values
		self.Xeof,self.Yeof = self.m(self.Xe[:,0],self.Xe[:,1])

		self.moveEOF		= 0   if kwargs.get('numero_componentes',2)==2 else .05
		self.X,self.Y		= self.m([-75.4 - self.moveEOF,-75.3 - self.moveEOF,-75.2 - self.moveEOF,-75.35],[6.12,6.08,6.04,6.0])
		for i in range(kwargs.get('numero_componentes',2))[::-1]:
			self.Q			= self.m.quiver(self.Xeof,self.Yeof,self.EOF[i]['U'],self.EOF[i]['V'],color=self.color[i],scale=3,alpha=0.7) #self.EOF['S']
			self.ax[0].text(self.X[i],self.Y[2],'EOF %s' %(i+1),ha='center',va='center',fontsize=self.fontsize,color=self.color[i],weight='bold',alpha=0.7)
			self.ax[0].text(self.X[i],self.Y[3],'%.1f' %self.varianza[i],ha='center',va='center',fontsize=self.fontsize,color=self.color[i],weight='bold',alpha=0.7)

		self.ax[0].quiverkey(self.Q, .65,.32 , 0.5, ' ', color=(0.45, 0.45, 0.45), labelpos='W', coordinates='axes', fontproperties={'weight': 'bold'}) 
		self.ax[0].text(self.X[3],self.Y[0],r'0.5 $\frac{m}{s}$',ha='center',va='center',fontsize=self.fontsize,color=(0.45, 0.45, 0.45),weight='bold')
		self.ax[0].text(self.X[3],self.Y[1],'Variance [%]',ha='center',va='center',fontsize=self.fontsize,color=(0.45, 0.45, 0.45),weight='bold')

		print 'Componentes Principales'
		self.CP['Hour [UTC-5]']		= self.CP.index.hour
		self.box	= self.CP.boxplot(column=1,by='Hour [UTC-5]',ax=self.ax[1],whis=3,notch=True,grid=False,patch_artist=True, medianprops={'linewidth': 1.5},whiskerprops={'linestyle': '-'},return_type='dict')[1]

		for boxes,medians in zip(self.box['boxes'],self.box['medians']):
			boxes.set_facecolor([ 0.30196078,  0.30196078,  0.99607843])
			boxes.set_edgecolor([0.0078,0.227,0.26])
			medians.set_color([0.0078,0.227,0.26])

		for whiskers,caps in zip(self.box['whiskers'],self.box['caps']):
			whiskers.set_color([0.0078,0.227,0.26])
			caps.set_color([0.0078,0.227,0.26])

		self.box 	= self.CP.boxplot(column=2,by='Hour [UTC-5]',ax=self.ax[2],whis=3,notch=True,grid=False,patch_artist=True, medianprops={'linewidth': 1.5},whiskerprops={'linestyle': '-'},return_type='dict')[2]

		for boxes,medians in zip(self.box['boxes'],self.box['medians']):
			boxes.set_facecolor([ 0.3,  0.3,  0.3])
			boxes.set_edgecolor([0.0078,0.227,0.26])
			medians.set_color([0.0078,0.227,0.26])

		for whiskers,caps in zip(self.box['whiskers'],self.box['caps']):
			whiskers.set_color([0.0078,0.227,0.26])
			caps.set_color([0.0078,0.227,0.26])

		self.ax[3].plot(range(1,self.varianza.size+1),self.varianza,lw=2,color=(0.4, 0.4, 0.4),marker='o',label='Explained variance')

		self.leg	= self.ax[3].legend(loc='best',fontsize=self.fontsize-2,framealpha=0.3)
		self.leg.get_frame().set_edgecolor((0.45, 0.45, 0.45))
		for text in self.leg.get_texts(): plt.setp(text, color = (0.45, 0.45, 0.45))

		self.ax[3].set_ylim(-3,self.varianza.max()*1.25)
		self.ax[3].locator_params(axis='y',nbins=5)
		self.ax[3].set_xlim(-1,self.CP.columns.size)
		self.ax[3].set_ylabel('Percentage [%]',fontsize=self.fontsize-2,weight='bold')
		self.ax[3].set_xticks(range(1,self.varianza.size+1,5))

		self.ax[1].set_xlabel('')
		self.ax[2].set_xlabel(r'Hora $[UTC-5]$',fontsize=self.fontsize)

		plt.suptitle('')
		for cp in range(1,3):
			#~ self.ax[cp].grid()
			self.ax[cp].set_ylabel('PC%d' %cp,fontsize=self.fontsize,color=self.color[cp-1],weight='bold',alpha=.7)
			#~ ax[cp].set_ylabel('Coeficiente',fontsize=fontsize,color=color[cp-1])
			self.ax[cp].set_ylim(self.CP[range(kwargs.get('numero_componentes',2))].min().min()*1.05,self.CP[range(kwargs.get('numero_componentes',2))].max().max()*1.05)
			self.ax[cp].set_title('')
			self.ax[cp].axhline(0,color='k',alpha=.5)
			self.ax[cp].set_xticks(range(1,24,2))
		self.ax[1].set_xticklabels([])
		self.ax[2].set_xticklabels(range(0,23,2),fontsize=self.fontsize)

		for i in range(1,4):
			self.x=[self.ax[i].get_xlim()[0],self.ax[i].get_xlim()[-1]]
			self.y=[self.ax[i].get_ylim()[0],self.ax[i].get_ylim()[-1]]
			print self.x, self.y
			self.ax[i].text(self.x[0]+(self.x[1]-self.x[0])*.05,self.y[0]+(self.y[1]-self.y[0])*.94,self.letra[i],ha='center',va='center',fontsize=self.fontsize,color=(0.45, 0.45, 0.45),weight='bold')

		self.x,self.y	= self.m([-75.725-(-75.725--75.215)*.05],[5.975+(6.515-5.975)*.95])
		self.ax[0].text(self.x[0],self.y[0],self.letra[0],ha='center',va='center',fontsize=self.fontsize,color=(0.45, 0.45, 0.45),weight='bold')

		plt.savefig('Figuras/Mapa_EOF%s.pdf' %(kwargs.get('textsave','')),bbox_inches='tight')
		os.system('scp Figuras/Mapa_EOF%s.pdf jhernandezv@siata.gov.co:/var/www/jhernandezv/%s' %(kwargs.get('textsave',''),self.path))

		self.CP.drop('Hour [UTC-5]',inplace=True,axis=1)

	def Plot_WindRose_Map(self,D,S,*args,**kwargs):

		self.fontsize		= kwargs.get('fontsize',14)
		self.velocidad		= kwargs.get('velocidad',6)

		self.S 	= S
		self.D	= D

		if kwargs.get('daily_cycle',False):
			self.color=mpl.cm.jet(np.linspace(0.,1,24))
			for est in self.S.columns.values:

				print self.EstV['Nombre_Estacion'][est]
				self.WindRose(self.D[est][self.D.index.hour==0],self.S[est][self.S.index.hour==0],kind='contour',color=[list(self.color[0][:3]),list(self.color[0][:3])],transparent=True,figsize=(4,4),ylim=(0,30),yticks=np.arange(0,31,10),scp=False,yticklabels=[],xticklabels=[],savefig=False)

				for i in range(1,24,2):
					self.WindRose(self.D[est][self.D.index.hour==i],self.S[est][self.S.index.hour==i],ax=self.ax,kind='contour',color=[list(self.color[i][:3]),list(self.color[i][:3])],transparent=True,figsize=(4,4),ylim=(0,30),yticks=np.arange(0,31,10),scp=False,yticklabels=[],xticklabels=[],savefig= (i==23))
		else:
			for est in self.S.columns.values:
				print self.EstV['Nombre_Estacion'][est] if kwargs.get('Vaisala',True) else est
				self.WindRose(self.D[est],self.S[est],transparent=True,figsize=kwargs.get('figsizeroses',(4,4)),ylim=(0,30),yticks=np.arange(0,31,10),scp=kwargs.get('scproses',False),yticklabels=[],xticklabels=[])

		self.WindRose_Convention()

		plt.close('all')
		self.fig 			= plt.figure(figsize=(11,11),facecolor='w',edgecolor='w')
		plt.rcParams['legend.numpoints']=1

		#figure.subplot.left    : 0.125 # the left side of the subplots of the figure
		#figure.subplot.right   : 0.9    # the right side of the subplots of the figure
		#figure.subplot.bottom  : 0.11    # the bottom of the subplots of the figure
		#figure.subplot.top     : 0.88

		self.ax			= self.fig.add_axes((0.125,0.11,0.775,.77))
		self.ax1		= self.fig.add_axes((0.125,0.0792,.565,.0154))
		self.ax2		= self.fig.add_axes((0.31,0.1485,.232,.0154))
		#~ self.ax2.patch.set_visible(False)
		plt.setp(self.ax2.spines.values(), color=(0.45, 0.45, 0.45))
		self.ax2.tick_params(top='off', right='off',bottom='on',left='off',which='both',labelleft='off',labelbottom='off')

		self.ax.tick_params(top='off', right='off',bottom='off',left='off',which='both',color=(0.45, 0.45, 0.45),labelsize=self.fontsize)
		plt.setp(self.ax.spines.values(), color='w')
		self.georef=[5.92,6.67,-75.87,-75.12]

		self.m 				= Basemap(projection='merc',llcrnrlat=self.georef[0],urcrnrlat=self.georef[1],llcrnrlon=self.georef[2],urcrnrlon=self.georef[3],resolution='i',ax=self.ax) 
		if kwargs.get('daily_cycle',False):
			#Colorbar Hora
			self.norm			= mpl.colors.Normalize(0,24)
			self.s_m			= mpl.cm.ScalarMappable(cmap=plt.get_cmap('jet', 24), norm=self.norm)
			self.s_m.set_array([])

			self.cbar 			= plt.colorbar(self.s_m,cax=self.ax1,format='%.f',norm=self.norm,orientation='horizontal')
			self.cbar.set_label(r"Hour $[UTC-5]$",fontsize=self.fontsize,color=(0.45, 0.45, 0.45))
			self.cbar.set_ticks(np.arange(0.5,24,2))
			self.cbar.set_ticklabels(range(0,24,2))
			self.cbar.ax.tick_params(labelsize=self.fontsize,color=(0.45, 0.45, 0.45))

		else:
			#Colorbar Velocidad
			self.norm			= mpl.colors.Normalize(0,self.velocidad)
			self.s_m			= mpl.cm.ScalarMappable(cmap=plt.get_cmap('jet', self.velocidad), norm=self.norm)
			self.s_m.set_array([])

			self.cbar 			= plt.colorbar(self.s_m,cax=self.ax1,format='%.f',extend='max',norm=self.norm,orientation='horizontal')
			self.cbar.set_ticks(np.arange(0.5,self.velocidad,1))
			self.cbar.set_ticklabels(['%.1f : %.1f' %(c,c+.9) if c <(self.velocidad-1) else r'$\geq$ %.1f' %c for c in range(self.velocidad)])
			self.cbar.ax.tick_params(labelsize=self.fontsize-2,color=(0.45, 0.45, 0.45))
			self.cbar.set_label(r'Velocidad del Viento $[m/s]$' if kwargs.get('spanish',False) else r"Wind Speed $[m/s]$",fontsize=self.fontsize,color = (0.45, 0.45, 0.45))

			#~ self.cb.locator		= mpl.ticker.FixedLocator(np.arange(0.5,self.velocidad,1))
			#~ self.label 			= ['%.1f : %.1f' %(c,c+.9) if c <(self.velocidad-1) else r'$\geq$ %.1f' %c for c in range(self.velocidad)]
			#~ self.cb.formatter   = mpl.ticker.FixedFormatter(self.label)
			#~ self.cb.update_ticks()

		if kwargs.get('add_DEM',True):
		#~ if True:

			self.Read_DEM(path='/home/calidadaire/ModuloAire/Tools/AMVA-DEM.tif')
			self.X,self.Y		= np.meshgrid(self.DEM.columns.values,self.DEM.index.values)
			self.Xm,self.Ym		= self.m(self.X,self.Y)
			self.cs				= self.m.contourf(self.Xm, self.Ym, self.DEM.values, levels=np.linspace(1300,3400,50), cmap=plt.cm.terrain_r,alpha=.35,extend='min')
			self.cs.cmap.set_under('w')

			self.cbar			= plt.colorbar(self.cs,cax=self.ax2,orientation='horizontal',format='%.f')
			self.cbar.set_label(r"Altitud%s $[km]$" %('' if kwargs.get('spanish',False) else 'e'),fontsize=self.fontsize,color=(0.45, 0.45, 0.45))
			self.cbar.set_ticks([1500,2000,2500,3000])
			self.cbar.set_ticklabels([1.5,2,2.5,3])
			self.cbar.ax.tick_params(labelsize=self.fontsize,color=(0.45, 0.45, 0.45))

			#For the imshow we need to adjust the dimension figure into the basemap limits
			self.DEM 					= self.DEM.reindex( np.concatenate((np.arange(self.DEM.index[0]-self.GeoTransform[-1],self.georef[1]-self.GeoTransform[-1],-self.GeoTransform[-1])[::-1],self.DEM.index.values,np.arange(self.DEM.index[-1]+self.GeoTransform[-1],self.georef[0]+self.GeoTransform[-1],self.GeoTransform[-1]))) ) #complet missing latitude

			self.DEM					= self.DEM.T[ (self.DEM.columns > self.georef[2]) & (self.DEM.columns < self.georef[3]) ].T # removing excess longitude
			self.m.imshow(LightSource(azdeg=38, altdeg=25).hillshade(self.DEM.values, vert_exag=1), cmap='gray',origin='upper',alpha=.6) 

			#~ plt.savefig('Figuras/ej_azdeg-%d.pdf' %(azdeg),bbox_inches='tight')
			#~ os.system('scp Figuras/ej_azdeg-%d.pdf jhernandezv@siata.gov.co:/var/www/jhernandezv/Winds/' %(azdeg))

		else:
			self.m.readshapefile('/home/calidadaire/ModuloAire/Tools/AreaMetropolitana','Area',linewidth=0.5,color=(0.0078,0.227,0.26))

		self.nx,self.ny		= 5,5
		self.dx				= (self.georef[3]-self.georef[2])/self.nx
		self.dy				= (self.georef[1]-self.georef[0])/self.ny
		self.locs=[]
		#os.system('cd Informe')
		for i in range(self.ny):
			self.l=[]
			for j in range(self.nx):
				self.l.extend([(self.georef[2]+self.dx/2.+self.dx*j,self.georef[1]-self.dy/2.-self.dy*i)])
			self.locs.append(self.l)

		#########################################################################################
		#Scatter Estaciones
		if kwargs.get('Vaisala',True):
			self.estaciones 	= self.EstV[self.EstV['Nombre'].isin( self.S.columns.values)].sort_values(by='Latitud',ascending=False)['Nombre'].values
			for est in self.estaciones:
				print est
				self.Xe,self.Ye			= self.m(self.EstV['Longitud'][est],self.EstV['Latitud'][est])
				if est in [201,203]:
					self.newp			= {201:(self.EstV['Longitud'][est]-.05,self.EstV['Latitud'][est]+.05),203:(self.EstV['Longitud'][est]-0.03,self.EstV['Latitud'][est]+.07)}
					self.xx,self.yy		= self.m(self.newp[est][0],self.newp[est][1])
					self.ax.annotate('%d' %est, xy=(self.Xe, self.Ye), xytext=(self.xx,self.yy),va='center',ha='center',fontsize=self.fontsize,fontproperties=prop,color= (0.1, 0.1, 0.1),	arrowprops=dict(facecolor='none', edgecolor=(0.1, 0.1, 0.1),shrink=0.00,width=.1,headwidth=5),)
					self.m.scatter(self.xx,self.yy,s=1000,facecolor='none',edgecolor=(0.1, 0.1, 0.1),lw=1,alpha=1)
				else:
					self.m.scatter(self.Xe,self.Ye,s=1000,facecolor='none',edgecolor=(0.1, 0.1, 0.1),lw=1,alpha=1)
					self.ax.text(self.Xe,self.Ye,'%d' %est,ha='center',va='center',fontsize=self.fontsize,color=(0., 0.05, 0.05),fontproperties=prop)

		else:
			if 'estaciones' not in kwargs.keys():
				self.estaciones		= self.S.columns.values
				self.X,self.Y		= self.m(self.EstR[self.EstR['Nombre'].isin (self.estaciones) ]['Longitud'].values,self.EstR[self.EstR['Nombre'].isin(self.estaciones)]['Latitud'].values)

			else:
				self.estaciones = kwargs['estaciones']
				self.x			= self.EstR[self.EstR['Nombre'].isin( self.estaciones)].sort_values(by='Latitud',ascending=False)[['Latitud','Longitud']]
				self.X,self.Y	= self.m(self.x['Longitud'].values,self.x['Latitud'].values)
			self.esta 		= self.EstR[self.EstR['Nombre'].isin(self.estaciones)]
			self.m.scatter(self.X,self.Y,s=600,facecolor='none',edgecolor=(0.1,0.1,0.1),lw=1,alpha=1)

			for i in range(len(self.X)):
				self.ax.text(self.X[i],self.Y[i],'%.f' %self.esta.index[i], ha='center',va='center', fontsize=self.fontsize,color=(0.1,0.1,0.1),fontproperties=prop_2)
		plt.savefig('Informe/Figuras/Plantilla_Mapa.pdf',bbox_inches='tight')

		################################################
		#~ os.system('ln -s /home/jhernandezv/Tools/AvenirL* .')
		barcode_font = r"/home/calidadaire/ModuloAire/Tools/AvenirLTStd-Heavy.ttf"
		pdfmetrics.registerFont(TTFont("AvenirHeavy", barcode_font))

		imgTemp = StringIO()
		imgDoc  = canvas.Canvas(imgTemp)

		#self.pos = {105:(5,60),206:(5,185),84:(5,310),83:(5,435),201:(5,560),203:(130,560),73:(255,560),204:(380,560),82:(505,560),207:(505,310),68:(380,310),202:(380,185),59:(505,185),205:(255+15,60+58)} if kwargs.get('Vaisala',True) else { 'CAL-LASA':(5,60),'EST-METR':(5,185), 'ITA-CONC':(5,310), 'ITA-CJUS':(5,435),'MED-UDEM':(5,560),'BEL-USBV':(130,560),'GIR-SOSN':(255,560),'GIR-IECO':(380,560),'BAR-PDLA':(505,560),'MED-MANT':(505,310),'MED-UNNV':(380,310),'MED-PJIC':(380,185),'MED-LAYE':(505,185)}
		#self.pos = {105:(5,60),206:(5,185),84:(5,310),83:(5,435),201:(5,560),203:(130,560),73:(255,560),204:(380,560),82:(505,560),207:(505,310),68:(380,310),202:(380,185),59:(505,185),205:(255+15,60+58)} if kwargs.get('Vaisala',True) else { 'SAB-SEMS':(5,60),'SUR-TRAF':(5,185), 'ITA-CONC':(5,310), 'ITA-CJUS':(5,435),'MED-UDEM':(5,560),'BEL-USBV':(130,560),'GIR-SOSN':(255,560),'GIR-IECO':(380,560),'BAR-PDLA':(505,560),'CEN-TRAF':(505,310),'MED-UNNV':(380,310),'MED-PJIC':(380,185),'MED-LAYE':(505,185)}
		#self.pos = {105:(5,60),206:(5,185),84:(5,310),83:(5,435),201:(5,560),203:(130,560),73:(255,560),204:(380,560),82:(505,560),207:(505,310),68:(380,310),202:(380,185),59:(505,185),205:(255+15,60+58)} if kwargs.get('Vaisala',True) else { 'SAB-SEMS':(5,240),'MED-ZOOL':(5,560),'GIR-BOTJ':(340,560),'CEN-TRAF':(505,560),'MED-SIAT':(170,560),'MED-PJIC':(5,400),'ITA-CODI':(5,80),'ITA-SAMA':()}
		self.pos = {105:(5,60),206:(5,185),84:(5,310),83:(5,435),201:(5,560),203:(130,560),73:(255,560),204:(380,560),82:(505,560),207:(505,310),68:(380,310),202:(380,185),59:(505,185),205:(255+15,60+58)} if kwargs.get('Vaisala',True) else { 'SAB-SEMS':(5,240),'MED-ZOOL':(5,560),'GIR-BOTJ':(340,560),'CEN-TRAF':(505,560),'MED-SIAT':(170,560),'MED-PJIR':(5,400),'ITA-ACUA':(505,80),'ITA-SAMA':(5,80)} #'ITA-CODI':(5,80),'ITA-SAMA':(505,80)} 

		imgDoc.setFillColorRGB(0.1, 0.1, 0.1)
		imgDoc.setFont("AvenirHeavy", 14)
		for pos in self.estaciones:
			imagenPDF = PdfImageSIATA ("Informe/Figuras/windrose_%s.pdf" %('%d' %pos if kwargs.get('Vaisala',True) else pos), width = 130, height = 130)
			imagenPDF.drawOn (imgDoc, self.pos[pos][0],self.pos[pos][1])

			imgDoc.drawString(self.pos[pos][0]+10,self.pos[pos][1]+60,'%.f' %(pos if kwargs.get('Vaisala',True) else self.EstR[self.EstR['Nombre']==pos].index.values[0]) )

		imagenPDF = PdfImageSIATA ("Informe/Figuras/windrose_convention.pdf" ,width = 140, height = 140)
		imagenPDF.drawOn (imgDoc, 400,240)
		#imagenPDF.drawOn (imgDoc, 475,5)

		imgDoc.setFillColorRGB(0.45, 0.45, 0.45)
		imgDoc.drawString(430,385,'Convención' if kwargs.get('spanish',False) else 'Conventions' )
		#imgDoc.drawString(505,150,'Convención' if kwargs.get('spanish',False) else 'Conventions' )
		imgDoc.drawString(488,168,'' if kwargs.get('spanish',False) else 'Winds Flow From')
		if 'add_Text' in kwargs.keys():
			imgDoc.setFont("AvenirHeavy", 18)
			imgDoc.drawString(380,80,kwargs['add_Text'])

		#~ # Plantilla
		imgDoc.save()
		page	= PdfFileReader(file("%s/Informe/Figuras/Plantilla_Mapa.pdf" %os.getcwd(),"rb")).getPage(0)
		overlay = PdfFileReader(StringIO(imgTemp.getvalue())).getPage(0)
		page.mergePage(overlay)


		#~ #Save the result
		output = PdfFileWriter()
		output.addPage(page)
		#~ output.addPage(page_1)
		output.write(file("Informe/Figuras/Windrose_Map%s.pdf" %kwargs.get('textsave',''),"w"))
		if kwargs.get('scp',True): os.system('scp Informe/Figuras/Windrose_Map%s.pdf nroldan@siata.gov.co:/var/www/%s' %(kwargs.get('textsave',''),kwargs.get('path','jhernandezv/Winds/Vaisala')))
		if kwargs.get('Vaisala',True) == False:
			os.system('pwd') 
			os.system('mv Informe/Figuras/Windrose_Map%s.pdf Informe/Figuras/Meteorologia/Windrose_Map%s.pdf' %(kwargs.get('textsave',''),kwargs.get('textsave','')) )
			os.system('rm Figuras/*.pdf')


	def Plot_Mapa_ICA(self,*args,**kwargs):

		self.Plot_Mapa4(Enumeracion=True)
		self.Plot_ICA(textsave='_Semanal',add_code=True)

		barcode_font = r"/home/calidadaire/ModuloAire/Tools/AvenirLTStd-Heavy.ttf"
		pdfmetrics.registerFont(TTFont("AvenirHeavy", barcode_font))

		imgTemp = StringIO()
		imgDoc  = canvas.Canvas(imgTemp)
		#~ imgDoc.setPageSize((654, 400))

		imagenPDF = PdfImageSIATA ('Figuras/%s/Mapa_%s.pdf' %(self.varsave,self.varsave), width = 952, height = 1000)
		imagenPDF.drawOn (imgDoc, 10,150)
		
		imagenPDF = PdfImageSIATA ('Figuras/%s/ICA_%s%s.pdf' %(self.varsave,self.varsave2,self.textsave), width = 750, height = 1000)
		imagenPDF.drawOn (imgDoc, 952,150)

		imgDoc.setFillColorRGB(1, 1, 1)
		imgDoc.setFont("AvenirHeavy", 30)
		imgDoc.drawString(680,1175,'%s - %s' %(self.Contaminante.index[0].strftime('%d/%m/%Y'),self.Contaminante.index[-1].strftime('%d/%m/%Y')))

		#~ imagenPDF = PdfImageSIATA (,width = 140, height = 140)
		#~ imagenPDF.drawOn (imgDoc, 475,5)

		#~ imgDoc.setFillColorRGB(0.45, 0.45, 0.45)
		#~ imgDoc.drawString(505,150,'Conventions')
		#~ imgDoc.drawString(488,168,'Winds Flow From')
		#~ if type(self.Hourly) != type(None):
			#~ imgDoc.setFont("AvenirHeavy", 18)
			#~ imgDoc.drawString(380,80,'Hour %s' %self.Hourly)

		#~ # Plantilla
		imgDoc.save()
		page	= PdfFileReader(file("/home/calidadaire/ModuloAire/Tools/ReporteICASemanal.pdf" ,"rb")).getPage(0)
		overlay = PdfFileReader(StringIO(imgTemp.getvalue())).getPage(0)
		page.mergePage(overlay)


		#~ #Save the result
		output = PdfFileWriter()
		output.addPage(page)
		#~ output.addPage(page_1)
		output.write(file("Figuras/XMapa_ICA_%s%s.pdf" %(self.varsave,kwargs.get('textsave','')),"w"))
		#os.system('scp Figuras/Mapa_ICA_%s%s.pdf jhernandezv@siata.gov.co:/var/www/CalidadAire/Figuras/%s/' %(self.varsave,kwargs.get('textsave',''),self.varsave))

	def Plot_Perfil_Vientos(self,df,*args,**kwargs):

		#----------------Ciclo diurno en latitud especifica---------------------
		self.fontsize	= kwargs.get('fontsize',16)
		self.ylim		= kwargs.get('ylim',[1400, 5590])
		self.ylimp		= kwargs.get('ylimp',[512, 861])
		self.xlim		= kwargs.get('ylim',[-75.75, -75.35])
		self.alt		= kwargs.get('altitud',np.array([1023,1262,1508,1708,1913,2121,2334,2552,2774,3001,3234,3472,3715,4352,5034,5768])) #+50
		
		
		if kwargs.get('daily_cycle',False): 
			df 		= df.groupby(lambda x: x.hour).mean() 
		
		#~ self.u 			= df['U'].T.values #loc[idx[:],idx['U','U']].T.values 
		#~ self.v			= df['V'].T.values #.loc[idx[:],idx[:,'V']].T.values
		#~ self.w 			= df['W'].T.values #.loc[idx[:],idx[:,'W']].T.values
		#~ self.adv		= (self.u**2+self.v**2)**0.5
		#--------------------------Plot-----------------------------------------

		if 'ax' not in kwargs.keys():
			plt.close('all')
			self.fig 		= plt.figure(figsize=(15,8.5),facecolor=(.7,.7,.7))
			self.ax0			= self.fig.add_axes((0.125,0.11,0.775,.77)) #self.fig.add_subplot(111)
			if kwargs.get('Barbas',True): 		self.ax1		= self.fig.add_axes((0.265,0.03,0.5,0.025))
			if kwargs.get('Conveccion',True):	self.ax2		= self.fig.add_axes((0.965,.2,0.015,0.59))
			
			for spinename, spine in self.ax0.spines.iteritems():
				spine.set_visible(False)
			
			#~ self.ax0.spines['top'].set_visible(False)
			#~ self.ax0.spines['right'].set_visible(False)
			#~ self.ax0.spines['left'].set_color((0.45, 0.45, 0.45))
			#~ self.ax0.spines['bottom'].set_color((0.45, 0.45, 0.45))
			self.ax0.tick_params(top='off', right='off',bottom='on',left='on',which='major',length=8,color=(0.45, 0.45, 0.45),labelsize=self.fontsize)
			self.ax0.tick_params(top='off', right='off',bottom='on',left='on',which='minor',length=4,color=(0.45, 0.45, 0.45),labelsize=self.fontsize)
			self.ax0.xaxis.label.set_color((0.45, 0.45, 0.45))
			self.ax0.yaxis.label.set_color((0.45, 0.45, 0.45))
		else:
			self.ax0 		= kwargs['ax']
		
		
		#~ self.ax0.patch.set_facecolor((.75,.75,.75))
		self.divider 	= make_axes_locatable(self.ax0)
		self.ax		= self.ax0.twinx()
		self.ax.tick_params(top='off', right='on',bottom='off',left='off',which='major',length=8,color=(0.45, 0.45, 0.45),labelsize=self.fontsize)
		self.ax.tick_params(top='off', right='on',bottom='off',left='off',which='minor',length=4,color=(0.45, 0.45, 0.45),labelsize=self.fontsize)
		for spinename, spine in self.ax.spines.iteritems():
				spine.set_visible(False)
		
		self.ax0.set_ylim(self.ylim[0],self.ylim[1]) #CLA+HGT
		self.ax0.set_yticks(range(self.ylim[0],self.ylim[1],100),minor=True)
		self.ax0.set_yticks(range(1500,self.ylim[1],500))
		self.ax0.set_xlim(self.xlim[0],self.xlim[1])
		self.ax0.set_yticklabels(np.arange(1.5,self.ylim[1]/1000.,.5) )
		self.ax0.set_ylabel(r'Altitude $[km]$',fontsize=self.fontsize,weight='bold',color=(0.45, 0.45, 0.45))
		#~ self.ax0.set_ylabel(r'Longitude ',fontsize=self.fontsize,weight='bold',color=(0.45, 0.45, 0.45))
		
		self.ax.set_yticks([1508,2017,2552,3117,3715,4352, 5034, 5768])
		self.ax.set_yticklabels([850,800,750,700,650,600,550,500])
		self.ax.set_ylim(self.ylim[0],self.ylim[1])
		self.ax.set_ylabel(r'Pressure $[hPa]$',fontsize=self.fontsize, weight='bold',color=(0.45, 0.45, 0.45))
		
		#W
		self.X, self.Y	= np.meshgrid(df.columns.levels[1].values,self.alt[::-1])

		if kwargs.get('Conveccion',True): 
			self.custom_cmap = [[ 0.4275,  0.0078,  0.1255], [ 0.6745,  0.0863,  0.1647], [ 0.8   ,  0.298 ,  0.2667], [ 0.8824,  0.4706,  0.3765],  [ 0.949 ,  0.6314,  0.498 ], [ 0.9686,  0.9686,  0.9686],  [ 0.5529,  0.7608,  0.8627],  [ 0.3725,  0.6471,  0.8039], [ 0.2275,  0.5294,  0.7412], [ 0.1176,  0.3804,  0.6471], [ 0.0275,  0.2039,  0.4039]] # [ 1.,  0.5765,  0.4549], n, [ 0.9608,  0.6745,  0.5451],medio,[ 0.6078,  0.7882,  0.8784], n,[ 0.4941,  0.7216,  0.8431]
			
			self.cf		= self.ax0.contourf(self.X,self.Y,df.W, cmap = clr.LinearSegmentedColormap.from_list('custom96',self.custom_cmap if  kwargs.get('custom_cmap',True) else self.custom_cmap[6:])  ,levels=np.linspace(kwargs.get('wlim',[-1.5,1.5])[0],kwargs.get('wlim',[-1.5,1.5])[1],40 if  kwargs.get('custom_cmap',True) else 20),alpha=1,extend='both' if kwargs.get('custom_cmap',True) else 'neither',zorder=1)
			self.cf.cmap.set_over([ 0.02745098,  0.20392157,  0.40392157]  )
			self.cf.cmap.set_under([ 0.42745098,  0.00784314,  0.1254902 ])
			
			if ('ax' not in kwargs.keys()) | (kwargs.get('add_colorbar',False)): 
				self.cbar1		= plt.colorbar(self.cf,cax=self.divider.append_axes("right", size="2%", pad='1%') if 'ax' in kwargs.keys() else self.ax2,format='%.2f')
				self.cbar1.set_label(r"$\omega\ [m/s]$", fontsize=self.fontsize,color=(0.45, 0.45, 0.45))
				self.cbar1.ax.tick_params(labelsize=self.fontsize,color=(0.45, 0.45, 0.45))
				self.cbar1.set_ticks(np.arange(kwargs.get('wlim',[-1.5,1.5])[0],kwargs.get('wlim',[-1.5,1.5])[1]*1.005,.5 if  kwargs.get('custom_cmap',True) else .3))
				
		#Barbs
		if kwargs.get('Barbas',True):
			self.img		= self.ax0.barbs(self.X, self.Y, df.U, df.V, (df.U**2+df.V**2)**0.5, cmap = mpl.cm.gist_earth if kwargs.get('Daltonic',False) else  clr.LinearSegmentedColormap.from_list('custom69',[(.0,.0,.0),[ 0.0706,  0.302 ,  0.4863],[ 0.    ,  0.5529,  0.4431],[ 0.251 ,  0.6588,  0.2902],[ 0.6471,  0.7255,  0.3451],[ 0.7882,  0.8314,  0.2039]] ) , length=5,norm=mpl.colors.Normalize(kwargs.get('advlim',[0,12])[0],kwargs.get('advlim',[0,12])[1]) ,fill_empty=True, rounding=True, sizes=dict(emptybarb=0.2, spacing=0.0, height=0.3,width=.5),zorder=2,barb_increments={'half':0.514444,'full':1.02889,'flag':244.3611}) 
			
			self.img.cmap.set_over([ 0.7882,  0.8314,  0.2039])
			self.img.set_clim(kwargs.get('advlim',[0,12])[0],kwargs.get('advlim',[0,12])[1])
			
		if kwargs.get('Quiver',False):
			self.img		= self.ax0.quiver(self.X, self.Y, df.U, df.V, self.adv , cmap= mpl.cm.gist_earth if kwargs.get('Daltonic',False) else  clr.LinearSegmentedColormap.from_list('custom69',[(.0,.0,.0),[ 0.0706,  0.302 ,  0.4863],[ 0.    ,  0.5529,  0.4431],[ 0.251 ,  0.6588,  0.2902],[ 0.6471,  0.7255,  0.3451],[ 0.7882,  0.8314,  0.2039]] ), norm=mpl.colors.Normalize(kwargs.get('advlim',[0,12])[0],kwargs.get('advlim',[0,12])[1]) ,zorder=3)
			#qk = plt.quiverkey(img, 0.1, 0.2, 5, r'$5 \frac{m}{s}$', labelpos='E', coordinates='figure',  fontproperties={'weight': 'bold'})
			self.img.cmap.set_over([ 0.7882,  0.8314,  0.2039])
			self.img.set_clim(kwargs.get('advlim',[0,12])[0],kwargs.get('advlim',[0,12])[1])
		
		if ('ax' not in kwargs.keys()) | (kwargs.get('add_colorbar',False)) | kwargs.get('Quiver',False) | kwargs.get('Barbas',True): 
			self.cbar2		= plt.colorbar(self.img,cax= self.divider.append_axes("bottom", size="3%", pad='12%') if 'ax' in kwargs.keys() else self.ax1, orientation='horizontal',extend='max' if  kwargs.get('custom_cmap',True) else 'neither')
			self.cbar2.set_label(r"Wind Speed $[m/s]$", fontsize=self.fontsize,color=(0.45, 0.45, 0.45))
			self.cbar2.ax.tick_params(labelsize=self.fontsize,color=(0.45, 0.45, 0.45))
		
		if 'ht' in kwargs.keys(): 
			self.ax0.fill_between(kwargs['ht'].index.values,kwargs['ht'].values,np.zeros(kwargs['ht'].size),color='darkgrey',alpha=1,zorder=4)

		if 'Dem' in kwargs.keys():
			self.ax0.plot(kwargs['Dem'].index.values,kwargs['Dem'].values,'k',lw=0.5,zorder=5)	

		if 'add_text' in kwargs.keys():
			self.ax.text(self.xlim[0],900,kwargs['add_text'],ha='center',va='center',color=(0.45, 0.45, 0.45),fontsize=self.fontsize,weight='bold')

		
		plt.savefig('Figuras/Wind_Profile%s.pdf' %kwargs.get('textsave',''),bbox_inches='tight')
		if kwargs.get('scp',True):	os.system("scp Figuras/Wind_Profile%s.pdf jhernandezv@siata.gov.co:/var/www/jhernandezv/%s" %(kwargs.get('textsave',''),kwargs.get('path','Winds/Climatologia/')))
		

		
	def Plot_WindRose_Perfil(self,U,V,*args,**kwargs):
		barcode_font = r"/home/jhernandezv/Tools/AvenirLTStd-Roman.ttf"
		pdfmetrics.registerFont(TTFont("Avenir", barcode_font))
		imgTemp = StringIO()
		imgDoc = canvas.Canvas(imgTemp)
		imgDoc.drawImage('/home/jhernandezv/Tools/Verde.png', 0, 710, 650, 90)
		imgDoc.drawImage('/home/jhernandezv/Tools/Verde_SIATA.png', 500, 710, 100, 75)
		imgDoc.drawImage('/home/jhernandezv/Tools/Verde_SIATA.png', 500, 710, 100, 75)
		imgDoc.drawImage('/home/jhernandezv/Tools/Verde.png', 0, 0, 650, 55)
		imgDoc.drawImage('/home/jhernandezv/Tools/Verde_Logos.png', 180, 0, 265, 50)
		
		imgDoc.setFillColorRGB(1,1,1)
		imgDoc.setFont("Avenir", 12)
		imgDoc.drawString(12, 714, U.index[0].strftime('%B de %Y'))

		
		X=np.array([30,142,254,366,478])
		Y=np.array([540,400,260,120])#np.array([120, 260, 400, 540]) 
		
		imgDoc.setFillColorRGB(0.,0.43529412,0.48235294)
		posicion=kwargs.get('posiciones',range(0,76,4))
		pas = posicion[1]
		for ht in posicion: #[4,12,23,32,53]:
			D = (270 - np.arctan2(V[self.ht[ht]],U[self.ht[ht]])*180/np.pi )%360 
			S = (U[self.ht[ht]]**2+V[self.ht[ht]]**2)**.5
			legend=(ht == posicion[-1])
			self.WindRose(D,S,textsave='RWP%.fm' %(self.ht[ht]),bins=range(0,13,2),ylim=(0,40),yticks=range(10,41,10),yticklabels=range(10,41,10),
				legend=legend, legend_fontsize='xx-large' ,scp=False)
			imgDoc.drawImage('Figuras/windrose_RWP%.fm.pdf' %(self.ht[ht]),X[(ht/pas)%X.shape[0]] , Y[(ht/pas)/X.shape[0]], 177 if legend else 105, 105)
			imgDoc.drawString(X[(ht/pas)%X.shape[0]]+15, Y[(ht/pas)/X.shape[0]]+115,'Altura = %.fm' %self.ht[ht])
			#~ print X[(ht/pas)%X.shape[0]],(ht/pas)%X.shape[0],Y[(ht/pas)/X.shape[0]],(ht/pas)/X.shape[0], 'ht=',ht
			print self.ht[ht]
 
		# Plantilla
		imgDoc.save()
		page = PdfFileReader(file("/home/jhernandezv/Tools/Plantilla_Blanco.pdf","rb")).getPage(0)
		overlay = PdfFileReader(StringIO(imgTemp.getvalue())).getPage(0)
		page.mergePage(overlay)

		#Save the result
		output = PdfFileWriter()
		output.addPage(page)
		textsave = kwargs.get('textsave','')
		output.write(file("Figuras/Windrose_RWP_%s.pdf" %textsave,"w"))
		#os.system('scp Figuras/Windrose_RWP_%s.pdf jhernandezv@siata.gov.co:/var/www/jhernandezv/Winds/RWP/' %textsave)



	def WindRose(self,wd,ws,*args,**kwargs):
		
		self.figsize 	= kwargs.get('figsize',(4,4))
		if 'ax' not in kwargs.keys():
			plt.close('all')
			self.fig 		= plt.figure(figsize=self.figsize, facecolor='w',linewidth=0.1)
			plt.rc('legend',fontsize='xx-small')
			self.rect = [0.1, 0.1, 0.8, 0.8]
			self.ax 		= WindroseAxes(self.fig, self.rect, axisbg='w')
			self.fig.add_axes(self.ax)
		else:
			self.ax = kwargs['ax']
		if 'bar' == kwargs.get('kind','bar'):
			self.ax.bar(wd, ws,normed=True, edgecolor='w',opening=0.95,bins=kwargs.get('bins',range(7)), cmap=plt.cm.jet,lw=0.01)
		elif 'contour' == kwargs.get('kind','bar'):
			#~ ax.contourf(wd, ws, normed=True,bins=range(0,13,1), cmap=plt.cm.jet)
			self.ax.contour(wd, ws, normed=True,bins=kwargs.get('bins',[0,ws.max()]),color=kwargs.get('colors','k'),lw=0.5,alpha=.9)

		plt.setp(self.ax.get_xticklabels(), fontsize=kwargs.get('fontsize','large'))
		plt.setp(self.ax.get_yticklabels(), fontsize=kwargs.get('fontsize','large'))
		if kwargs.get('legend',False):
			self.leg	= self.ax.legend(bbox_to_anchor=(1.05,.5),loc='center left',title=r'Velocidad $[m/s]$',)#prop=kwargs.get('prop',36))
			#~ leg.get_frame().set_edgecolor(('w'))
			plt.setp(self.leg.get_texts(), fontsize=kwargs.get('legend_fontsize','large'),)
		if 'ylim' in kwargs.keys(): 		self.ax.set_ylim(kwargs['ylim'])
		if 'yticks' in kwargs.keys(): 		self.ax.set_yticks(kwargs['yticks'])
		if 'yticklabels' in kwargs.keys(): 	self.ax.set_yticklabels(kwargs['yticklabels'])
		if 'xticklabels' in kwargs.keys(): 	self.ax.set_xticklabels(kwargs['xticklabels'])
		if 'title' in kwargs.keys(): 		self.ax.set_title(kwargs['title'],fontsize=kwargs.get('fontsize','large'),y=1.1,weight='bold',fontproperties=prop)

		self.ax.grid(alpha=0.7,color=(0.45,0.45,0.45),lw=0.5,ls='--')
		self.ax.tick_params(top='off', right='off',bottom='off',left='off',which='both',color=(0.45, 0.45, 0.45))
		plt.setp(self.ax.spines.values(), color=(0.45, 0.45, 0.45))

		if kwargs.get('savefig',True):
			if kwargs.get('InformeMensual',False):
					plt.savefig('Informe/Figuras/Meteorologia/windrose_%s.pdf' %(kwargs.get('textsave','')), bbox_inches="tight",transparent=kwargs.get('transparent',False))
					os.system('scp Informe/Figuras/Meteorologia/windrose_%s.pdf nroldan@siata.gov.co:/var/www/CalidadAire/Figuras/Meteorologia/' %(kwargs.get('textsave','')))
			else:
				plt.savefig('Informe/Figuras/windrose_%s%s.pdf' %(str(wd.name),kwargs.get('textsave','')), bbox_inches="tight",transparent=kwargs.get('transparent',False))
				if kwargs.get('scp',True): 
					os.system('scp Figuras/windrose_%s%s.pdf nroldan@siata.gov.co:/var/www/jhernandezv/Winds/Vaisala/' %(str(wd.name),kwargs.get('textsave','')))

		
	def WindRose_Convention(self,*args,**kwargs):
		
		self.figsize 	= kwargs.get('figsize',(4,4)) 
		
		plt.close('all')
		
		self.fig 		= plt.figure(figsize=self.figsize, facecolor='w',linewidth=0.1)
		self.rect 		= [0.1, 0.1, 0.8, 0.8]
		self.ax 		= WindroseAxes(self.fig, self.rect, axisbg='w')
		self.fig.add_axes(self.ax)
		self.cmap		= mpl.colors.ListedColormap(['w']*6)
		self.wd			= np.random.random(50)*6
		self.ws			= np.random.random(50)*6
		self.ax.bar(self.wd, self.ws,normed=True, edgecolor='w',opening=0.95,bins=range(0,7,1), cmap=self.cmap,lw=0.00)
		self.ax.set_ylim(0,30)
		self.ax.set_yticks(np.arange(0,31,10))
		self.ax.set_yticklabels(np.arange(0,31,10),fontsize=24)
		#~ plt.setp(ax.get_xticklabels(), fontsize='small')
		plt.setp(self.ax.get_xticklabels(), fontsize=24)
		self.ax.grid(alpha=0.7,color=(0.45,0.45,0.45),lw=0.5,ls='--')
		
		self.ax.tick_params(top='off', right='off',bottom='off',left='off',which='both',color=(0.45, 0.45, 0.45))
		self.ax.tick_params(axis='x',which='both',pad=kwargs.get('pad',15))
		plt.setp(self.ax.spines.values(), color=(0.45, 0.45, 0.45))
		
		plt.savefig('Informe/Figuras/windrose_convention.pdf' , bbox_inches="tight",transparent=True)
		
	def EOF_Maker(self,df,*args,**kwargs):
		
		self.textsave			= kwargs.get('textsave','')
		self.numero_componentes	= kwargs.get('numero_componentes',2)
		
		
		if kwargs.get('UseCorrelation',False):
			self.COR				= st.spearmanr(df.dropna(),axis=0)
			self.eva,self.eve		= np.linalg.eig(self.COR.correlation)
		else:
			self.COV 				= df.dropna().T.dot(df.dropna())
			self.eva,self.eve		= np.linalg.eig(self.COV)
		self.varianza			= self.eva/float(sum(self.eva))*100
		self.CP 				= df.dropna().dot(self.eve)
		self.EOF = {}
		
		if kwargs.get('Mapa_EOF',False): 
			for i in range(self.numero_componentes):
				self.EOF[i] = {'U':self.eve[:self.eve.shape[0]/2,i],'V':self.eve[self.eve.shape[0]/2:,i],
				'S':(self.eve[:self.eve.shape[0]/2,i]**2+self.eve[self.eve.shape[0]/2:,i]**2)**.5}
			self.Plot_Mapa_EOF(textsave=self.textsave,numero_componentes=self.numero_componentes)
			if kwargs.get('Restore',False): self.EOF_Restore(kind='WindRose',columns=df.columns) if 'apply' not in kwargs.keys() else self.EOF_Restore(kind='WindRose',columns= df.columns,apply=kwargs['apply'])
		
		if kwargs.get('Barbs_EOF',False):
			self.Plot_Barbs_EOF(textsave=self.textsave)
			if kwargs.get('Restore',False): self.EOF_Restore(kind='Barbs',columns=df.columns) if 'apply' not in kwargs.keys() else self.EOF_Restore(kind='Barbs',columns=df.columns,apply=kwargs['apply'])
		
	def EOF_Restore(self,*args,**kwargs):
		
		
		self.Restore = {}
		for nc in range(self.numero_componentes):
			print nc
			self.Restore[nc]		= np.empty((self.CP.shape[0],self.CP.shape[1])) 
			for i in range(self.CP.shape[0]): 
				self.Restore[nc][i,:]	= self.CP[nc+1].iloc[i]*self.eve[:,nc]
			
			self.Restore[nc]		= pd.DataFrame(self.Restore[nc],index=self.CP.index,columns=kwargs['columns'])
		self.R = pd.DataFrame()
		for nc in range(self.numero_componentes):
			if nc == 0: 	self.R = self.Restore[nc]
			else: 			self.R += self.Restore[nc]
		if 'apply' in kwargs.keys() : self.R = self.R.apply(kwargs['apply'])
		
		
		if kwargs.get('kind','WindRose') == 'WindRose':
			
			self.RR	= self.Get_SD(self.R.U,self.R.V)
			self.Plot_WindRose_Map(D=self.RR.D,S=self.RR.S,textsave='_Restore%s' %self.textsave,path='Winds/Vaisala/EOF/')
			self.Plot_WindRose_Map(D=self.RR.D,S=self.RR.S,path='Winds/Vaisala/EOF/',Vaisala=True,daily_cycle=True,textsave='_DC_Restore%s'%self.textsave)
			
			for i in range(0,24):
				self.Plot_WindRose_Map(D=self.RR.D[self.RR.index.hour==i],S=self.RR.S[self.RR.index.hour==i], textsave='%s_H%s' %(self.textsave,self.RR[self.RR.index.hour==i].index[0].strftime('%H')),path='Winds/Vaisala/EOF/',scp=False,add_Text=self.RR[self.RR.index.hour==i].index[0].strftime('Hour %H'))
			
			os.system('pdftk Figuras/Windrose_Map%s_H*.pdf cat output Figuras/Windrose_Map_Restore_Hourly%s.pdf' %(self.textsave,self.textsave))
			os.system('convert -delay 20 Figuras/Windrose_Map_Restore_Hourly%s.pdf Figuras/Windrose_Map_Restore_Hourly%s.gif' %(self.textsave,self.textsave))
			os.system('scp Figuras/Windrose_Map_Restore_Hourly%s.gif jhernandezv@siata.gov.co:/var/www/jhernandezv/Winds/Vaisala/EOF/' %(self.textsave))
			os.system('rm Figuras/Windrose_Map%s_H*' %self.textsave)
		
		elif kwargs.get('kind','WindRose') == 'Barbs':
			self.Plot_Barbs(df=self.R,textsave='_Restore%s' %self.textsave,path='jhernandezv/Winds/RWP/EOF/',daily_cycle=True,height=4000)
			self.Plot_Barbs_MonthlyDC(df=self.R,textsave='_Restore%s' %self.textsave,path='jhernandezv/Winds/RWP/EOF/',height=4000,scp=False)
	
	def Get_SD(self,U,V):
		return  pd.concat({'D':(270-np.arctan2(V,U)*180/np.pi)%360,'S':(U**2+V**2)**.5},axis=1)

			
	def Fourier_Maker(self,df,*args,**kwargs):
		periodo = kwargs.get('periodo',1)
		axis	= kwargs.get('axis',1)
		
		self.fft=np.fft.fftshift(np.fft.fft(df,axis=axis))
		self.freq=np.fft.fftshift(np.fft.fftfreq(df.shape[axis-1],d=periodo))
		
		
		
	def to_csv(self,estacion,*args,**kwargs):
		
		print estacion
		self.estacion 	= estacion
		self.textsave	= kwargs.get('textsave','')
		
		self.x				= self.Contaminante.xs(estacion,axis=1,level=1)  
		self.x.columns 		= map(lambda x: '%s [%s]' %(x,self.unidadesC[x]),self.x.columns.values)
		
		self.y				= self.Dica.xs(self.estacion,axis=1,level=1) #  .stack(0).loc[self.idx[:,parametros],self.idx[estacion]].unstack(1)
		self.parametros		= list(self.y.columns.values)
		try: self.parametros.remove('PM2.5')
		except:pass
		try: self.parametros.remove('PM10')
		except:pass
		self.y				= self.y[self.parametros]*1000
		self.y.columns		= map(lambda x: '%s [%s]' %(x,self.unidadesC2[x]),self.y.columns.values)
		self.d 				= pd.concat([self.x,self.y],axis=1) #.T.drop_duplicates().T.sort_values(by=axis=1)
		self.d 				= self.d.reindex(pd.date_range(self.Contaminante.index[0],self.Contaminante.index[-1],freq='1h'))
		self.d.index.name	= 'Fechas'
		self.d.index 		= self.d.index + dt.timedelta(hours=1)
		self.d.sort(axis=1).to_csv('Datos/%s_Contaminantes%s.txt' %(self.estacion,self.textsave),na_rep=-9999) #sep='\t'

		try: 
			self.x			= self.Meteo.xs(self.estacion,axis=1,level=1)  
			self.x.columns 	= map(lambda x: '%s [%s]' %(x,self.unidadesMeteo[x]),self.x.columns.values)
			self.x			= self.x.reindex(pd.date_range(self.Meteo.index[0],self.Meteo.index[-1],freq='1h'))
			self.x.index.name= 'Fechas'
			self.x.index 	=self.x.index + dt.timedelta(hours=1)
			self.x.sort(axis=1).to_csv('Datos/%s_Meteorologia%s.txt' %(self.estacion,self.textsave),na_rep=-9999)
		except: pass

	
	def to_xls(self,parametros,estaciones,*args,**kwargs):
		
		self.textsave 		= kwargs.get('textsave','')
		self.Historia 		= kwargs.get('Historia',False)
		Ruido 			= kwargs.get('Ruido',True)
		df 			= kwargs.get('df',None)

		self.parametros = parametros
		self.estaciones	= estaciones
		self.noxls		= {}
		if df == None:
			df=self.Dica[var][esta] if (var in self.unidadesC2) else self.Meteo[var][esta]

		for var in self.parametros:
			print var
			print '%s posee las siguientes estaciones %s' %(var, self.EstR[self.EstR[var]==1]['Nombre'].values)
			for esta in self.estaciones:
				print esta

				#~ try:
				self.und			= self.unidadesC2[var] if (var in self.unidadesC2) else 'dB' if Ruido else 'null'
				self.variable		= var if (var in self.unidadesC2) else var if Ruido else 'null'
				self.concentra		= df[var][esta]

				if var in ['NO2','NO','NOx','SO2','Ozono']:
					self.concentra 		= self.concentra*1000.
				self.concentra.index 	= self.concentra.index + dt.timedelta(hours=1)
				self.msfl				= 'null' if (var in self.unidadesC2) else var
				self.concentra			= self.concentra.reindex(pd.date_range(self.Fechai,self.Fechaf,freq='H')).fillna('null')
				self.fechai				= map(lambda x: x.strftime('%d/%m/%Y %I:%M:%S %P'),self.concentra.index)
				self.fechaf				= map(lambda x: x.strftime('%d/%m/%Y %I:%M:%S %P'),self.concentra.index+dt.timedelta(hours=1))
				
				if (var in self.unidadesC2):
					self.fechac 		= self.FechaumC[var][esta].reindex(pd.date_range(self.Fechai,self.Fechaf,freq='H')) 
				else:
					self.fechaMeteo 	= self.FechaumM[var][esta].reindex(pd.date_range(self.Fechai,self.Fechaf,freq='H')) 
				
				self.fecham 			= map((lambda x:  x.strftime('%d/%m/%Y %I:%M:%S %P') if not pd.isnull(x) else 'null'), self.fechac if (var in self.unidadesC2) else self.fechaMeteo)
				
				self.yy					= pd.DataFrame({'NombreEstacion':esta,'Variable':self.variable,'Unidad':self.und,'FechaInicio':self.fechai,'FechaFin':self.fechaf,'Concentracion':self.concentra})  
				#self.yy					= pd.DataFrame({'NombreEstacion':esta,'Variable':self.variable,'Unidad':self.und,'FechaInicio':self.fechai,'FechaFin':self.fechaf,'FechaModificacion':self.fecham,'Concentracion':self.concentra,'MSFLCode':self.msfl})  
				try :
					print '%s-%s%s.xls' %(var,esta,self.textsave)
					if self.Historia:
						print "Generando Historia de los datos"
						self.yy.to_excel(excel_writer='Datos_Sisaire/%s_%s%s.xls' %(var,esta,self.textsave),index=False,columns=['NombreEstacion','Variable','Unidad','FechaInicio','FechaFin','FechaModificacion','Concentracion','MSFLCode'])
					else:
						self.yy.to_excel(excel_writer='Datos/%s_%s%s.xls' %(var,esta,self.textsave),index=False,columns=['NombreEstacion','Variable','Unidad','FechaInicio','FechaFin','FechaModificacion','Concentracion','MSFLCode'])
						os.system('scp Datos/%s_%s%s.xls jhernandezv@siata.gov.co:Consulta/' %(var,esta,self.textsave)) #julian@192.168.1.255:XLS/
					
				except:
					self.noxls[var+esta]= self.yy
	#				pass
		#~ print self.noxls

		
	def Copy_from_iguana(self,*args,**kwargs):
		
		path_iguana	= kwargs.get('path_iguana','/mnt/data1/mzapata/datos_tesis/control/')
		path		= kwargs.get('path','/home/jhernandezv/Winds/Climatologia_Mauro/P_INTERP/')
		freq		= kwargs.get('freq','M')
		cut			= kwargs.get('cut',[5.4,7.2,-76.4,-74.6])
		
		os.chdir(path)
		print os.getcwd()

		date=pd.date_range(self.Fechai,self.Fechaf,freq=freq)
		
		PBL, TS, US, VS, U, V, W, SW ={},{},{},{},{},{},{},{}

		error,no_interp=[],[]

		for i in range(date.size):
			
			files = date[i].strftime('wrfout_d01_%Y-%m-%d_%H:00:00')
			
			try:
				print 'scp iguana '+ files
				os.system("scp jhernandezv@192.168.1.109:%s%s %scopy" %(path_iguana,files,path))
				
				#os.system("rsync -azhe jhernandezv@192.168.1.109:"+path_iguana+folder+"/wrfout_d03_"+str(indexa[j])[:10]+"_"+str(indexa[j])[11:]+".gz "+path+"copy.gz")
				try: 
					print '============================Interpolando================================='
					os.system("./pinterp.out")
					os.system("rm copy")
					os.system("mv *PLEV copy") #Pendiente try
					os.system("rm *PLEV")
					nc_fid=Dataset('copy','r')
					
					print '=================================Getting variables================================='
					
					if (i==0): 
						#getting longitud cut
						#Longitud
						lon		= nc_fid.variables['XLONG'][0,0,:]
						plon	= [np.where(lon>cut[2])[0][0],np.where(lon<cut[3])[0][-1]+1]
						lon		= lon[plon[0]:plon[1]]
						#longitud U
						lonu	= nc_fid.variables['XLONG_U'][0,0,:]
						plonu	= [np.where(lonu<lon[0])[0][-1],np.where(lonu>lon[-1])[0][0]+1]
						lonu	= lonu[plonu[0]:plonu[1]]
						#Latitud
						lat		= nc_fid.variables['XLAT'][0,:,0]
						plat	= [np.where(lat>cut[0])[0][0],np.where(lat<cut[1])[0][-1]+1]
						lat		= lat[plat[0]:plat[1]]
						#latitud V
						latv	= nc_fid.variables['XLAT_V'][0,:,0]
						platv	= [np.where(latv<lat[0])[0][-1],np.where(latv>lat[-1])[0][0]+1]
						latv	= latv[platv[0]:platv[1]]
						#Altura y niveles de presion
						h		= nc_fid.variables['HGT'][0,plat[0]:plat[1],plon[0]:plon[1]]
						pres	= nc_fid.variables['PRES'][0,:,0,0]
					
					#UTC a Local
					indexa = date[i]-dt.timedelta(hours=5)
					
					print 'PBL'
					PBL[indexa]=pd.DataFrame(nc_fid.variables['PBLH'][0,plat[0]:plat[1],plon[0]:plon[1]],index=lat,columns=lon)
					PBL[indexa].columns.name='LON'
					print 'TS'
					TS[indexa]=pd.DataFrame(nc_fid.variables['T2'][0,plat[0]:plat[1],plon[0]:plon[1]],index=lat,columns=lon)
					TS[indexa].columns.name='LON'
					print 'US'
					US[indexa]=pd.DataFrame(nc_fid.variables['V10'][0,plat[0]:plat[1],plon[0]:plon[1]],index=lat,columns=lon)
					US[indexa].columns.name='LON'
					print 'VS'
					VS[indexa]=pd.DataFrame(nc_fid.variables['U10'][0,plat[0]:plat[1],plon[0]:plon[1]],index=lat,columns=lon)
					VS[indexa].columns.name='LON'
					print 'SW'			
					SW[indexa]=pd.DataFrame(nc_fid.variables['SWDOWN'][0,plat[0]:plat[1],plon[0]:plon[1]],index=lat,columns=lon)
					SW[indexa].columns.name='LON'
					
					print '=================================Getting U, V, W================================='
					u,v,w={},{},{}
					for j in range(pres.size):
						u[pres[j]]=pd.DataFrame(nc_fid.variables['UU'][0,j,plat[0]:plat[1],plonu[0]:plonu[1]],index=lat,columns=lonu)
						#~ u[pres[j]].index.name='LAT'
						u[pres[j]].columns.name='LONU'
						v[pres[j]]=pd.DataFrame(nc_fid.variables['VV'][0,j,platv[0]:platv[1],plon[0]:plon[1]],index=latv,columns=lon)
						#~ v[pres[j]].index.name='LATV'
						v[pres[j]].columns.name='LON'
						w[pres[j]]=pd.DataFrame(nc_fid.variables['W'][0,j,plat[0]:plat[1],plon[0]:plon[1]],index=lat,columns=lon)
						#~ w[pres[j]].index.name='LAT'
						w[pres[j]].columns.name='LON'
					
					print 'U'
					U[indexa]=pd.concat(u)
					#~ U[indexa].index.names=['PRES','LAT']
					print 'V'
					V[indexa]=pd.concat(v)
					#~ V[indexa].index.names=['PRES','LATV']
					print 'W'
					W[indexa]=pd.concat(w)
					#~ W[indexa].index.names=['PRES','LAT']
					
					os.system("rm copy")
				except:
					no_interp.append(index)
					os.system("rm copy")
					pass
			except:
				os.system("rm copy")
				pass
		print '================================= Finish to make pickle ================================='
		try:
			PBL=pd.concat(PBL)
			PBL.index.names=['dates','LAT']
			TS=pd.concat(TS)
			TS.index.names=['dates','LAT']
			US=pd.concat(US)
			US.index.names=['dates','LAT']
			VS=pd.concat(VS)
			VS.index.names=['dates','LAT']
			SW=pd.concat(SW)
			SW.index.names=['dates','LAT']
			U=pd.concat(U)
			U.index.names=['dates','PRES','LAT']
			V=pd.concat(V)
			V.index.names=['dates','PRES','LATV']
			W=pd.concat(W)
			W.index.names=['dates','PRES','LAT']
		except: pass
		
		DIC={'XLONG':lon,'XLAT':lat,'XLAT_V':latv,'XLONG_U':lonu,'PRES':pres,'PBLH':PBL,'U10':US,'V10':VS,'T2':TS,'HGT':h,'U':U,'V':V,'W':W,'SWDOWN':SW,'no_interp':no_interp}
		#DIC={'XLONG':lon,'XLAT':lat,'XLAT_V':latv,'XLONG_U':lonu,'PRES':pres,'HGT':h,'UU':UU,'VV':VV,'W':WW,'SWDOWN':SW,'error':error,'no_interp':no_interp}
		
		make_pickle('/home/jhernandezv/Winds/Climatologia_Mauro/','WRF_PLEV_%s' %indexa.strftime('%m'),DIC)

print 'corrio toitico'


